@@ -19,11 +19,12 @@ import (
 
 	"github.com/openshift/console/pkg/auth"
 	"github.com/openshift/console/pkg/bridge"
+	"github.com/openshift/console/pkg/crypto"
 	"github.com/openshift/console/pkg/helm/chartproxy"
+	"github.com/openshift/console/pkg/knative"
 	"github.com/openshift/console/pkg/proxy"
 	"github.com/openshift/console/pkg/server"
 	"github.com/openshift/console/pkg/serverconfig"
-	oscrypto "github.com/openshift/library-go/pkg/crypto"
 )
 
 var (
@@ -87,6 +88,7 @@ func main() {
 	fK8sAuth := fs.String("k8s-auth", "service-account", "service-account | bearer-token | oidc | openshift")
 	fK8sAuthBearerToken := fs.String("k8s-auth-bearer-token", "", "Authorization token to send with proxied Kubernetes API requests.")
 
+	fRedirectPort := fs.Int("redirect-port", 0, "Port number under which the console should listen for custom hostname redirect.")
 	fLogLevel := fs.String("log-level", "", "level of logging information by package (pkg=level).")
 	fPublicDir := fs.String("public-dir", "./frontend/public/dist", "directory containing static web assets.")
 	fTlSCertFile := fs.String("tls-cert-file", "", "TLS certificate. If the certificate is signed by a certificate authority, the certFile should be the concatenation of the server's certificate followed by the CA's certificate.")
@@ -285,9 +287,10 @@ func main() {
 		if !rootCAs.AppendCertsFromPEM(k8sCertPEM) {
 			log.Fatalf("No CA found for the API server")
 		}
-		tlsConfig := oscrypto.SecureTLSConfig(&tls.Config{
-			RootCAs: rootCAs,
-		})
+		tlsConfig := &tls.Config{
+			RootCAs:      rootCAs,
+			CipherSuites: crypto.DefaultCiphers(),
+		}
 
 		bearerToken, err := ioutil.ReadFile(k8sInClusterBearerToken)
 		if err != nil {
@@ -302,7 +305,7 @@ func main() {
 
 		k8sAuthServiceAccountBearerToken = string(bearerToken)
 
-		// If running in an OpenShift cluster, set up a proxy to the prometheus-k8s serivce running in the openshift-monitoring namespace.
+		// If running in an OpenShift cluster, set up a proxy to the prometheus-k8s service running in the openshift-monitoring namespace.
 		if *fServiceCAFile != "" {
 			serviceCertPEM, err := ioutil.ReadFile(*fServiceCAFile)
 			if err != nil {
@@ -312,9 +315,10 @@ func main() {
 			if !serviceProxyRootCAs.AppendCertsFromPEM(serviceCertPEM) {
 				log.Fatalf("no CA found for Kubernetes services")
 			}
-			serviceProxyTLSConfig := oscrypto.SecureTLSConfig(&tls.Config{
-				RootCAs: serviceProxyRootCAs,
-			})
+			serviceProxyTLSConfig := &tls.Config{
+				RootCAs:      serviceProxyRootCAs,
+				CipherSuites: crypto.DefaultCiphers(),
+			}
 			srv.PrometheusProxyConfig = &proxy.Config{
 				TLSClientConfig: serviceProxyTLSConfig,
 				HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
@@ -340,13 +344,15 @@ func main() {
 				HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
 				Endpoint:        &url.URL{Scheme: "https", Host: openshiftMeteringHost, Path: "/api"},
 			}
+			srv.TerminalProxyTLSConfig = serviceProxyTLSConfig
 		}
 
 	case "off-cluster":
 		k8sEndpoint = bridge.ValidateFlagIsURL("k8s-mode-off-cluster-endpoint", *fK8sModeOffClusterEndpoint)
-		serviceProxyTLSConfig := oscrypto.SecureTLSConfig(&tls.Config{
+		serviceProxyTLSConfig := &tls.Config{
 			InsecureSkipVerify: *fK8sModeOffClusterSkipVerifyTLS,
-		})
+			CipherSuites:       crypto.DefaultCiphers(),
+		}
 		srv.K8sProxyConfig = &proxy.Config{
 			TLSClientConfig: serviceProxyTLSConfig,
 			HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
@@ -396,6 +402,8 @@ func main() {
 			}
 		}
 
+		srv.TerminalProxyTLSConfig = serviceProxyTLSConfig
+
 	default:
 		bridge.FlagFatalf("k8s-mode", "must be one of: in-cluster, off-cluster")
 	}
@@ -530,9 +538,9 @@ func main() {
 		bridge.FlagFatalf("k8s-mode", "must be one of: service-account, bearer-token, oidc, openshift")
 	}
 
-	srv.MonitoringDashboardConfigMapLister = &server.ResourceLister{
-		BearerToken: resourceListerToken,
-		RequestURL: &url.URL{
+	srv.MonitoringDashboardConfigMapLister = server.NewResourceLister(
+		resourceListerToken,
+		&url.URL{
 			Scheme: k8sEndpoint.Scheme,
 			Host:   k8sEndpoint.Host,
 			Path:   "/api/v1/namespaces/openshift-config-managed/configmaps",
@@ -540,13 +548,31 @@ func main() {
 				"labelSelector": {"console.openshift.io/dashboard=true"},
 			}.Encode(),
 		},
-
-		Client: &http.Client{
+		&http.Client{
 			Transport: &http.Transport{
 				TLSClientConfig: srv.K8sProxyConfig.TLSClientConfig,
 			},
 		},
-	}
+		nil,
+	)
+
+	srv.KnativeEventSourceCRDLister = server.NewResourceLister(
+		resourceListerToken,
+		&url.URL{
+			Scheme: k8sEndpoint.Scheme,
+			Host:   k8sEndpoint.Host,
+			Path:   "/apis/apiextensions.k8s.io/v1/customresourcedefinitions",
+			RawQuery: url.Values{
+				"labelSelector": {"duck.knative.dev/source=true"},
+			}.Encode(),
+		},
+		&http.Client{
+			Transport: &http.Transport{
+				TLSClientConfig: srv.K8sProxyConfig.TLSClientConfig,
+			},
+		},
+		knative.EventSourceFilter,
+	)
 
 	listenURL := bridge.ValidateFlagIsURL("listen", *fListen)
 	switch listenURL.Scheme {
@@ -565,6 +591,28 @@ func main() {
 		Handler: srv.HTTPHandler(),
 		// Disable HTTP/2, which breaks WebSockets.
 		TLSNextProto: make(map[string]func(*http.Server, *tls.Conn, http.Handler)),
+		TLSConfig: &tls.Config{
+			CipherSuites: crypto.DefaultCiphers(),
+		},
+	}
+
+	if *fRedirectPort != 0 {
+		go func() {
+			// Listen on passed port number to be redirected to the console
+			redirectServer := http.NewServeMux()
+			redirectServer.HandleFunc("/", func(res http.ResponseWriter, req *http.Request) {
+				redirectURL := &url.URL{
+					Scheme:   srv.BaseURL.Scheme,
+					Host:     srv.BaseURL.Host,
+					RawQuery: req.URL.RawQuery,
+					Path:     req.URL.Path,
+				}
+				http.Redirect(res, req, redirectURL.String(), http.StatusMovedPermanently)
+			})
+			redirectPort := fmt.Sprintf(":%d", *fRedirectPort)
+			log.Infof("Listening on %q for custom hostname redirect...", redirectPort)
+			log.Fatal(http.ListenAndServe(redirectPort, redirectServer))
+		}()
 	}
 
 	log.Infof("Binding to %s...", httpsrv.Addr)
