@@ -1,6 +1,6 @@
 import * as React from 'react';
 import { shallow, ShallowWrapper } from 'enzyme';
-
+import { TextInput } from '@patternfly/react-core';
 import {
   TextFilter,
   ListPageWrapper_,
@@ -8,7 +8,6 @@ import {
   MultiListPage,
 } from '../../../public/components/factory/list-page';
 import { Firehose, PageHeading } from '../../../public/components/utils';
-import { CheckBoxes } from '../../../public/components/row-filter';
 
 describe(TextFilter.displayName, () => {
   let wrapper: ShallowWrapper;
@@ -24,7 +23,7 @@ describe(TextFilter.displayName, () => {
   });
 
   it('renders text input', () => {
-    const input: ShallowWrapper<React.InputHTMLAttributes<any>> = wrapper.find('input');
+    const input: ShallowWrapper<any> = wrapper.find(TextInput);
 
     expect(input.props().type).toEqual('text');
     expect(input.props().placeholder).toEqual(`Filter ${label}...`);
@@ -41,8 +40,8 @@ describe(FireMan_.displayName, () => {
     wrapper = shallow(<FireMan_.WrappedComponent resources={resources} />);
   });
 
-  it('renders `PageHeading` if given `title`', () => {
-    expect(wrapper.find(PageHeading).exists()).toBe(false);
+  it('renders `title` if given `title`', () => {
+    expect(wrapper.find(PageHeading).props().title).toBe(undefined);
 
     const title = 'My pods';
     wrapper.setProps({ title });
@@ -55,7 +54,12 @@ describe(FireMan_.displayName, () => {
 
     const createProps = { foo: 'bar' };
     const button = wrapper
-      .setProps({ canCreate: true, createProps, createButtonText: 'Create Me!' })
+      .setProps({
+        canCreate: true,
+        createProps,
+        createButtonText: 'Create Me!',
+        title: 'Nights Watch',
+      })
       .find('#yaml-create');
 
     expect(
@@ -69,14 +73,6 @@ describe(FireMan_.displayName, () => {
       expect(createProps[key] === button.props()[key]).toBe(true);
     });
   });
-
-  it('renders `TextFilter` with given props', () => {
-    const filterLabel = 'My filter';
-    wrapper.setProps({ filterLabel });
-    const filter = wrapper.find(TextFilter);
-
-    expect(filter.props().label).toEqual(filterLabel);
-  });
 });
 
 describe(ListPageWrapper_.displayName, () => {
@@ -96,7 +92,6 @@ describe(ListPageWrapper_.displayName, () => {
     const rowFilters = [
       {
         type: 'app-type',
-        selected: ['database'],
         reducer: (item) => item.kind,
         items: [
           { id: 'database', title: 'Databases' },
@@ -105,15 +100,8 @@ describe(ListPageWrapper_.displayName, () => {
       },
     ];
     wrapper.setProps({ rowFilters });
-    const checkboxes = wrapper.find(CheckBoxes) as any;
-
-    expect(checkboxes.length).toEqual(rowFilters.length);
-    checkboxes.forEach((checkbox, i) => {
-      expect(checkbox.props().items).toEqual(rowFilters[i].items);
-      expect(checkbox.props().numbers).toEqual({ Pod: 2, Node: 1 });
-      expect(checkbox.props().selected).toEqual(rowFilters[i].selected);
-      expect(checkbox.props().type).toEqual(rowFilters[i].type);
-    });
+    const dropdownFilter = wrapper.find('FilterToolbar') as any;
+    expect(dropdownFilter.props().rowFilters).toEqual(rowFilters);
   });
 
   it('renders given `ListComponent`', () => {
