@@ -11,6 +11,7 @@ export const listPageHeading = $('.co-m-pane__heading');
 export const createButton = $('.co-m-pane__filter-bar-group button');
 
 // Details pages
+export const actionButton = $('.co-m-nav-title .pf-m-primary.co-action-buttons__btn');
 export const detailsHeading = $('.co-m-nav-title .co-resource-item');
 export const detailsHeadingAlertIcon = $('.co-m-nav-title .co-m-resource-alert');
 export const detailsHeadingRuleIcon = $('.co-m-nav-title .co-m-resource-alertrule');
@@ -25,6 +26,12 @@ export const firstAlertsListLink = $$('.co-resource-list__item a.co-resource-ite
 // Silence form
 export const matcherNameInput = $('input[placeholder=Name]');
 export const matcherValueInput = $('input[placeholder=Value]');
+export const silenceStartNowCheckbox = $('input[type=checkbox]');
+export const silenceStartsAtInput = $$('[data-test-id="datetime"]').get(0);
+export const silenceEndsAtInput = $$('[data-test-id="datetime"]').get(1);
+export const silenceDurationMenuButton = $('[data-test-id="dropdown-button"]');
+export const silenceDurationOption = (duration: string) =>
+  $(`[data-test-dropdown-menu="${duration}"]`);
 export const commentTextarea = $('textarea');
 export const saveButton = $('button[type=submit]');
 
@@ -33,7 +40,6 @@ export const modalConfirmButton = $('#confirm-action');
 
 // YAML form
 export const successAlert = $('.pf-m-success');
-export const helpText = $('.co-help-text');
 
 // Configuration Overview
 export const alertRoutingHeader = $('[data-test-section-heading="Alert Routing"]');
@@ -66,19 +72,40 @@ export const getFirstRowAsText = () => {
 };
 
 export const saveAsDefault = firstElementByTestID('save-as-default');
-
+export const sendResolvedAlerts = firstElementByTestID('send-resolved-alerts');
+export const showAdvancedConfiguration = $('button.pf-c-expandable__toggle');
 export const defaultAlertmanagerYaml = Base64.encode(`"global":
   "resolve_timeout": "5m"
+"inhibit_rules":
+- "equal":
+  - "namespace"
+  - "alertname"
+  "source_match":
+    "severity": "critical"
+  "target_match_re":
+    "severity": "warning|info"
+- "equal":
+  - "namespace"
+  - "alertname"
+  "source_match":
+    "severity": "warning"
+  "target_match_re":
+    "severity": "info"
 "receivers":
-- "name": "null"
+- "name": "Default"
+- "name": "Watchdog"
+- "name": "Critical"
 "route":
   "group_by":
-  - "job"
+  - "namespace"
   "group_interval": "5m"
   "group_wait": "30s"
-  "receiver": "null"
+  "receiver": "Default"
   "repeat_interval": "12h"
   "routes":
   - "match":
       "alertname": "Watchdog"
-    "receiver": "null"`);
+    "receiver": "Watchdog"
+  - "match":
+      "severity": "critical"
+    "receiver": "Critical"`);
