@@ -1,14 +1,15 @@
 import * as React from 'react';
-import * as _ from 'lodash';
 import { match } from 'react-router';
 import { k8sGet } from '@console/internal/module/k8s';
 import { ClusterServiceVersionModel } from '@console/operator-lifecycle-manager';
 import { BreadCrumbs } from '@console/internal/components/utils';
+import { getAnnotations } from '@console/shared/src/selectors/common';
 import { Radio, Title } from '@patternfly/react-core';
-import { checkForIndependentSupport } from '../independent-mode/utils';
+import { getRequiredKeys, createDownloadFile } from '../independent-mode/utils';
 import { OCSServiceModel } from '../../models';
 import InstallExternalCluster from '../independent-mode/install';
 import { CreateOCSServiceForm } from './create-form';
+import { OCS_SUPPORT_ANNOTATION } from '../../constants';
 import './install-page.scss';
 
 enum MODES {
@@ -24,8 +25,11 @@ const InstallCluster: React.FC<InstallClusterProps> = ({ match }) => {
   } = match;
 
   const [isIndependent, setIsIndependent] = React.useState(false);
+  const [independentReqdKeys, setIndependentReqdKeys] = React.useState<{ [key: string]: string[] }>(
+    null,
+  );
+  const [downloadFile, setDownloadFile] = React.useState(null);
   const [mode, setMode] = React.useState(MODES.CONVERGED);
-  const [sample, setSample] = React.useState(null);
   const [clusterServiceVersion, setClusterServiceVersion] = React.useState(null);
 
   const handleModeChange = (_checked: boolean, event: React.FormEvent<HTMLInputElement>) => {
@@ -36,11 +40,25 @@ const InstallCluster: React.FC<InstallClusterProps> = ({ match }) => {
   React.useEffect(() => {
     k8sGet(ClusterServiceVersionModel, appName, ns)
       .then((clusterServiceVersionObj) => {
-        setIsIndependent(checkForIndependentSupport(clusterServiceVersionObj));
-        try {
-          setSample(
-            JSON.parse(_.get(clusterServiceVersionObj.metadata.annotations, 'alm-examples'))[0],
+        const isIndependentSupported = getAnnotations(clusterServiceVersionObj)[
+          OCS_SUPPORT_ANNOTATION
+        ].includes('external');
+        if (isIndependentSupported) {
+          setIsIndependent(true);
+          const { configMaps = [], secrets = [], storageClasses = [] } = getRequiredKeys(
+            clusterServiceVersionObj,
           );
+          setIndependentReqdKeys({ configMaps, secrets, storageClasses });
+          setDownloadFile(
+            createDownloadFile(
+              getAnnotations(clusterServiceVersionObj)?.[
+                'external.features.ocs.openshift.io/export-script'
+              ],
+            ),
+          );
+        }
+
+        try {
           setClusterServiceVersion(clusterServiceVersionObj);
         } catch (e) {
           setClusterServiceVersion(null);
@@ -65,10 +83,8 @@ const InstallCluster: React.FC<InstallClusterProps> = ({ match }) => {
             />
           )}
         </div>
-        <h1 className="co-m-pane__heading co-m-pane__heading--baseline">
-          <div className="co-m-pane__name">Create a new storage cluster</div>
-        </h1>
-        <p className="co-m-pane__explanation">
+        <h1 className="co-create-operand__header-text">Create Storage Cluster</h1>
+        <p className="help-block">
           OCS runs as a cloud-native service for optimal integration with applications in need of
           storage, and handles the scenes such as provisioning and management.
         </p>
@@ -86,6 +102,7 @@ const InstallCluster: React.FC<InstallClusterProps> = ({ match }) => {
                 isChecked={mode === MODES.CONVERGED}
                 onChange={handleModeChange}
                 id="radio-1"
+                className="ceph-install--no-margin"
                 label="Converged"
                 name="converged-mode"
               />
@@ -98,21 +115,21 @@ const InstallCluster: React.FC<InstallClusterProps> = ({ match }) => {
                 id="radio-2"
                 label="Independent - For external storage"
                 name="independent-mode"
+                className="ceph-install--no-margin"
               />
             </div>
           </div>
         )}
-        {(isIndependent === false || mode === MODES.CONVERGED) &&
-          clusterServiceVersion &&
-          sample && (
-            <CreateOCSServiceForm
-              namespace={ns}
-              operandModel={OCSServiceModel}
-              sample={sample}
-              clusterServiceVersion={clusterServiceVersion !== null && clusterServiceVersion}
-            />
-          )}
-        {mode === MODES.INDEPENDENT && <InstallExternalCluster match={match} />}
+        {(isIndependent === false || mode === MODES.CONVERGED) && (
+          <CreateOCSServiceForm match={match} />
+        )}
+        {mode === MODES.INDEPENDENT && (
+          <InstallExternalCluster
+            match={match}
+            minRequiredKeys={independentReqdKeys}
+            downloadFile={downloadFile}
+          />
+        )}
       </div>
     </>
   );
