@@ -10,3 +10,6 @@ export const BY_USED = 'By Used Capacity';
 export const BY_REQUESTED = 'By Requested Capacity';
 export const OCS_OPERATOR = 'ocs-operator';
 export const OCS_INDEPENDENT_CR_NAME = 'ocs-independent-storagecluster';
+export const OCS_CONVERGED_CR_NAME = 'ocs-storagecluster';
+export const NO_PROVISIONER = 'kubernetes.io/no-provisioner';
+export const OCS_SUPPORT_ANNOTATION = 'features.ocs.openshift.io/enabled';
