@@ -1,14 +1,19 @@
 import * as React from 'react';
+import * as _ from 'lodash';
 import { CogsIcon } from '@patternfly/react-icons';
 import { FLAGS } from '@console/shared/src/constants';
+import { FLAG_DEVWORKSPACE } from './consts';
 import {
   Plugin,
   Perspective,
+  ModelFeatureFlag,
+  ModelDefinition,
   DashboardsOverviewResourceActivity,
   DashboardsOverviewHealthURLSubsystem,
   DashboardsOverviewHealthPrometheusSubsystem,
   DashboardsOverviewInventoryItem,
   DashboardsOverviewHealthOperator,
+  ReduxReducer,
 } from '@console/plugin-sdk';
 import {
   ClusterVersionModel,
@@ -40,16 +45,34 @@ import {
   getClusterUpdateTimestamp,
   isClusterUpdateActivity,
 } from './components/dashboards-page/activity';
+import reducer from './redux/reducer';
+import * as models from './models';
 
 type ConsumedExtensions =
   | Perspective
+  | ModelDefinition
+  | ModelFeatureFlag
   | DashboardsOverviewResourceActivity
   | DashboardsOverviewHealthURLSubsystem<any>
   | DashboardsOverviewHealthPrometheusSubsystem
   | DashboardsOverviewInventoryItem
-  | DashboardsOverviewHealthOperator<ClusterOperator>;
+  | DashboardsOverviewHealthOperator<ClusterOperator>
+  | ReduxReducer;
 
 const plugin: Plugin<ConsumedExtensions> = [
+  {
+    type: 'ModelDefinition',
+    properties: {
+      models: _.values(models),
+    },
+  },
+  {
+    type: 'FeatureFlag/Model',
+    properties: {
+      model: models.WorkspaceModel,
+      flag: FLAG_DEVWORKSPACE,
+    },
+  },
   {
     type: 'Perspective',
     properties: {
@@ -78,7 +101,9 @@ const plugin: Plugin<ConsumedExtensions> = [
         import(
           './components/dashboards-page/ClusterUpdateActivity' /* webpackChunkName: "console-app" */
         ).then((m) => m.default),
-      required: FLAGS.CLUSTER_VERSION,
+    },
+    flags: {
+      required: [FLAGS.CLUSTER_VERSION],
     },
   },
   {
@@ -109,6 +134,7 @@ const plugin: Plugin<ConsumedExtensions> = [
           './components/dashboards-page/ControlPlaneStatus' /* webpackChunkName: "console-app" */
         ).then((m) => m.default),
       popupTitle: 'Control Plane status',
+      disallowedProviders: ['IBMCloud'],
     },
   },
   {
@@ -157,7 +183,16 @@ const plugin: Plugin<ConsumedExtensions> = [
           './components/dashboards-page/OperatorStatus' /* webpackChunkName: "console-app" */
         ).then((c) => c.default),
       viewAllLink: '/settings/cluster/clusteroperators',
-      required: FLAGS.CLUSTER_VERSION,
+    },
+    flags: {
+      required: [FLAGS.CLUSTER_VERSION],
+    },
+  },
+  {
+    type: 'ReduxReducer',
+    properties: {
+      namespace: 'console',
+      reducer,
     },
   },
 ];
