@@ -7,10 +7,14 @@ export { default as MultiColumnField } from './multi-column-field/MultiColumnFie
 export { default as NSDropdownField } from './NSDropdownField';
 export { default as NumberSpinnerField } from './NumberSpinnerField';
 export { default as RadioButtonField } from './RadioButtonField';
+export { default as RadioGroupField } from './RadioGroupField';
 export { default as ResourceDropdownField } from './ResourceDropdownField';
 export { default as ResourceLimitField } from './ResourceLimitField';
 export { default as SwitchField } from './SwitchField';
 export { default as TextAreaField } from './TextAreaField';
 export { default as YAMLEditorField } from './YAMLEditorField';
+export { default as ItemSelectorField } from './item-selector-field/ItemSelectorField';
+export { default as InputGroupField } from './InputGroupField';
+export { default as TextColumnField } from './TextColumnField';
 export * from './field-utils';
 export * from './field-types';
