@@ -1,6 +1,14 @@
 import * as React from 'react';
 import * as _ from 'lodash';
-import { DeploymentConfigModel, DeploymentModel, DaemonSetModel } from '@console/internal/models';
+import {
+  DeploymentConfigModel,
+  DeploymentModel,
+  DaemonSetModel,
+  StatefulSetModel,
+  ReplicationControllerModel,
+  ReplicaSetModel,
+  PodModel,
+} from '@console/internal/models';
 import { ChartLabel } from '@patternfly/react-charts';
 import {
   K8sResourceKind,
@@ -8,16 +16,33 @@ import {
   SelfSubjectAccessReviewKind,
 } from '@console/internal/module/k8s';
 import { useSafetyFirst } from '@console/internal/components/safety-first';
-import { RevisionModel } from '@console/knative-plugin';
 import { PodRCData, PodRingResources, PodRingData, ExtPodKind } from '../types';
-import { TransformResourceData } from './resource-utils';
-import { checkPodEditAccess } from './pod-utils';
+import { checkPodEditAccess, getPodStatus } from './pod-utils';
+import { RevisionModel } from '@console/knative-plugin';
+import {
+  getPodsForDeploymentConfigs,
+  getPodsForDeployments,
+  getPodsForStatefulSets,
+  getPodsForDaemonSets,
+} from './resource-utils';
+import { AllPodStatus } from '../constants';
+
+import './pod-ring-text.scss';
 
 type PodRingLabelType = {
   subTitle: string;
   title: string;
   titleComponent: React.ReactElement;
-  subTitleComponent: React.ReactElement;
+};
+
+export const podRingFirehoseProps = {
+  [PodModel.kind]: 'pods',
+  [ReplicaSetModel.kind]: 'replicaSets',
+  [ReplicationControllerModel.kind]: 'replicationControllers',
+  [DeploymentModel.kind]: 'deployments',
+  [DeploymentConfigModel.kind]: 'deploymentConfigs',
+  [StatefulSetModel.kind]: 'statefulSets',
+  [DaemonSetModel.kind]: 'daemonSets',
 };
 
 const applyPods = (podsData: PodRingData, dc: PodRCData) => {
@@ -49,46 +74,56 @@ const isPendingPods = (
 ): boolean =>
   (pods?.length === 1 && pods[0].status?.phase === 'Pending') ||
   (!currentPodCount && !!desiredPodCount);
+
+export const getFailedPods = (pods: ExtPodKind[]): number => {
+  return pods.reduce((acc, currValue) => {
+    if ([AllPodStatus.CrashLoopBackOff, AllPodStatus.Failed].includes(getPodStatus(currValue))) {
+      return acc + 1;
+    }
+    return acc;
+  }, 0);
+};
+
 const getTitleAndSubtitle = (
   isPending: boolean,
   currentPodCount: number,
   desiredPodCount: number,
 ) => {
   let titlePhrase;
-  let subTitlePhrase;
+  let subTitlePhrase = '';
+  let longSubtitle = false;
 
-  // handles the intial state when the first pod is coming up and the state for no pods(scaled to zero)
+  // handles the initial state when the first pod is coming up and the state for no pods(scaled to zero)
   if (!currentPodCount) {
     titlePhrase = isPending ? '0' : `Scaled to 0`;
-    subTitlePhrase = desiredPodCount ? `scaling to ${desiredPodCount}` : '';
+    if (desiredPodCount) {
+      subTitlePhrase = `scaling to ${desiredPodCount}`;
+      longSubtitle = true;
+    }
   }
 
   // handles the idle state or scaling to desired no. of pods
   if (currentPodCount) {
     titlePhrase = currentPodCount.toString();
-    subTitlePhrase =
-      currentPodCount === desiredPodCount
-        ? pluralizeString(currentPodCount, 'pod')
-        : `scaling to ${desiredPodCount}`;
+    if (currentPodCount === desiredPodCount) {
+      subTitlePhrase = pluralizeString(currentPodCount, 'pod');
+    } else {
+      subTitlePhrase = `scaling to ${desiredPodCount}`;
+      longSubtitle = true;
+    }
   }
 
-  return { title: titlePhrase, subTitle: subTitlePhrase };
+  return { title: titlePhrase, subTitle: subTitlePhrase, longSubtitle };
 };
 
-const getTitleAndSubtitleComponent = (
-  isPending: boolean,
-  currentPodCount: number,
-  kind: string,
-) => ({
-  titleComponent:
-    !currentPodCount && !isPending
-      ? React.createElement(ChartLabel, { style: { fontSize: '14px' } })
-      : undefined,
-  subTitleComponent:
-    kind === 'Revision'
-      ? React.createElement(ChartLabel, { style: { fontSize: '14px' } })
-      : undefined,
-});
+const getTitleComponent = (longSubtitle: boolean = false, reversed: boolean = false) =>
+  React.createElement(ChartLabel, {
+    dy: longSubtitle ? -5 : 0,
+    style: { lineHeight: '11px' },
+    className: `pf-chart-donut-title ${
+      reversed ? 'pod-ring__center-text--reversed' : 'pod-ring__center-text'
+    }`,
+  });
 
 export const podRingLabel = (
   obj: K8sResourceKind,
@@ -100,23 +135,34 @@ export const podRingLabel = (
   let title;
   let subTitle;
   let isPending;
+  let titleData;
+  const failedPodCount = getFailedPods(pods);
   switch (ownerKind) {
     case DaemonSetModel.kind:
-      currentPodCount = obj.status?.currentNumberScheduled;
+      currentPodCount = (obj.status?.currentNumberScheduled || 0) + failedPodCount;
+      desiredPodCount = obj.status?.desiredNumberScheduled;
       desiredPodCount = obj.status?.desiredNumberScheduled;
       isPending = isPendingPods(pods, currentPodCount, desiredPodCount);
+      titleData = getTitleAndSubtitle(isPending, currentPodCount, desiredPodCount);
       return {
-        ...getTitleAndSubtitle(isPending, currentPodCount, desiredPodCount),
-        ...getTitleAndSubtitleComponent(isPending, currentPodCount, ownerKind),
+        title: titleData.title,
+        subTitle: titleData.subTitle,
+        titleComponent: getTitleComponent(titleData.longSubtitle),
       };
     case RevisionModel.kind:
-      currentPodCount = obj.status?.readyReplicas;
+      currentPodCount = (obj.status?.readyReplicas || 0) + failedPodCount;
       desiredPodCount = obj.spec?.replicas;
       isPending = isPendingPods(pods, currentPodCount, desiredPodCount);
       if (!isPending && !desiredPodCount) {
         title = 'Autoscaled';
         subTitle = 'to 0';
-      } else if (isPending) {
+        return {
+          title,
+          subTitle,
+          titleComponent: getTitleComponent(false, true),
+        };
+      }
+      if (isPending) {
         title = '0';
         subTitle = `scaling to ${desiredPodCount}`;
       } else {
@@ -126,15 +172,17 @@ export const podRingLabel = (
       return {
         title,
         subTitle,
-        ...getTitleAndSubtitleComponent(isPending, currentPodCount, ownerKind),
+        titleComponent: getTitleComponent(),
       };
     default:
-      currentPodCount = obj.status?.readyReplicas;
+      currentPodCount = (obj.status?.readyReplicas || 0) + failedPodCount;
       desiredPodCount = obj.spec?.replicas;
       isPending = isPendingPods(pods, currentPodCount, desiredPodCount);
+      titleData = getTitleAndSubtitle(isPending, currentPodCount, desiredPodCount);
       return {
-        ...getTitleAndSubtitle(isPending, currentPodCount, desiredPodCount),
-        ...getTitleAndSubtitleComponent(isPending, currentPodCount, ownerKind),
+        title: titleData.title,
+        subTitle: titleData.subTitle,
+        titleComponent: getTitleComponent(titleData.longSubtitle),
       };
   }
 };
@@ -167,32 +215,33 @@ export const usePodScalingAccessStatus = (
 };
 
 export const transformPodRingData = (resources: PodRingResources, kind: string): PodRingData => {
-  const deploymentKinds = {
-    [DeploymentModel.kind]: 'deployments',
-    [DeploymentConfigModel.kind]: 'deploymentConfigs',
-  };
+  const targetResource = podRingFirehoseProps[kind];
 
-  const targetDeployment = deploymentKinds[kind];
-  const transformResourceData = new TransformResourceData(resources);
-
-  if (!targetDeployment) {
-    throw new Error(`Invalid target deployment resource: (${targetDeployment})`);
+  if (!targetResource) {
+    throw new Error(`Invalid target resource: (${targetResource})`);
   }
-  if (_.isEmpty(resources[targetDeployment].data)) {
+  if (_.isEmpty(resources[targetResource].data)) {
     return {};
   }
 
   const podsData: PodRingData = {};
-  const resourceData = resources[targetDeployment].data;
+  const resourceData = resources[targetResource].data;
 
   if (kind === DeploymentConfigModel.kind) {
-    return transformResourceData
-      .getPodsForDeploymentConfigs(resourceData)
-      .reduce(applyPods, podsData);
+    return getPodsForDeploymentConfigs(resourceData, resources).reduce(applyPods, podsData);
   }
 
   if (kind === DeploymentModel.kind) {
-    return transformResourceData.getPodsForDeployments(resourceData).reduce(applyPods, podsData);
+    return getPodsForDeployments(resourceData, resources).reduce(applyPods, podsData);
   }
+
+  if (kind === StatefulSetModel.kind) {
+    return getPodsForStatefulSets(resourceData, resources).reduce(applyPods, podsData);
+  }
+
+  if (kind === DaemonSetModel.kind) {
+    return getPodsForDaemonSets(resourceData, resources).reduce(applyPods, podsData);
+  }
+
   return podsData;
 };
