@@ -19,30 +19,35 @@ export interface HelmRelease {
 
 export interface HelmChart {
   files: { name: string; data: string }[];
-  metadata: {
-    name: string;
-    version: string;
-    description: string;
-    apiVersion: string;
-    appVersion: string;
-    keywords?: string[];
-    home?: string;
-    icon?: string;
-    sources?: string[];
-    maintainers?: object[];
-    dependencies?: object[];
-    type?: string;
-  };
+  metadata: HelmChartMetaData;
   templates: object[];
   values: object;
   lock?: object;
   schema?: string;
 }
 
+export interface HelmChartMetaData {
+  name: string;
+  version: string;
+  description: string;
+  apiVersion: string;
+  appVersion: string;
+  keywords?: string[];
+  home?: string;
+  icon?: string;
+  sources?: string[];
+  maintainers?: object[];
+  dependencies?: object[];
+  type?: string;
+  urls: string[];
+}
+
 export interface HelmReleaseResourcesData {
   releaseName: string;
+  releaseVersion: number | string;
   chartIcon: string;
   manifestResources: K8sResourceKind[];
+  releaseNotes: string;
 }
 
 export interface HelmReleaseResourcesMap {
@@ -55,7 +60,22 @@ export enum HelmReleaseStatus {
   Other = 'other',
 }
 
-export enum HelmFilterType {
-  Row = 'row',
-  Text = 'text',
+export enum HelmActionType {
+  Install = 'Install',
+  Upgrade = 'Upgrade',
+  Rollback = 'Rollback',
+}
+
+export interface HelmActionConfigType {
+  title: string;
+  subTitle: string;
+  helmReleaseApi: string;
+  fetch: (url: string, json: any, options?: {}, timeout?: number) => Promise<any>;
+  redirectURL: string;
+}
+
+export enum HelmActionOrigins {
+  details = 'details',
+  list = 'list',
+  topology = 'topology',
 }
