@@ -8,19 +8,19 @@ import {
   RoleBindingModel,
 } from '@console/internal/models';
 import { k8sCreate, K8sResourceKind, K8sVerb, k8sUpdate } from '@console/internal/module/k8s';
+import { ServiceModel as KnServiceModel } from '@console/knative-plugin';
+import { getKnativeServiceDepResource } from '@console/knative-plugin/src/utils/create-knative-utils';
+import { getRandomChars } from '@console/shared/src/utils';
 import {
-  getKnativeServiceDepResource,
-  ServiceModel as KnServiceModel,
-} from '@console/knative-plugin';
-import { getAppLabels, getPodLabels, mergeData } from '../../utils/resource-label-utils';
-import {
-  createRoute,
-  createService,
-  annotations,
-  dryRunOpt,
-  getRandomChars,
-} from '../../utils/shared-submit-utils';
-import { RegistryType } from '../../utils/imagestream-utils';
+  getAppLabels,
+  getPodLabels,
+  mergeData,
+  getCommonAnnotations,
+  getTriggerAnnotation,
+} from '../../utils/resource-label-utils';
+import { createRoute, createService, dryRunOpt } from '../../utils/shared-submit-utils';
+import { getProbesData } from '../health-checks/create-health-checks-probe-utils';
+import { RegistryType, getRuntime } from '../../utils/imagestream-utils';
 import { AppResources } from '../edit-application/edit-application-types';
 import { DeployImageFormData, Resources } from './import-types';
 
@@ -80,7 +80,7 @@ export const createOrUpdateImageStream = (
         {
           name: tag,
           annotations: {
-            ...annotations,
+            ...getCommonAnnotations(),
             'openshift.io/imported-from': isiName,
           },
           from: {
@@ -105,10 +105,10 @@ const getMetadata = (formData: DeployImageFormData) => {
     name,
     isi: { image },
     labels: userLabels,
-    imageStream: { image: imgName, tag: imgTag, namespace: imgNamespace },
+    imageStream: { tag: imgTag, namespace: imgNamespace },
   } = formData;
-
-  const defaultLabels = getAppLabels(name, application, imgName || undefined, imgTag, imgNamespace);
+  const imgStreamName = getRuntime(image.metadata?.labels);
+  const defaultLabels = getAppLabels(name, application, imgStreamName, imgTag, imgNamespace);
   const labels = { ...defaultLabels, ...userLabels };
   const podLabels = getPodLabels(name);
 
@@ -150,22 +150,19 @@ export const createOrUpdateDeployment = (
     labels: userLabels,
     limits: { cpu, memory },
     imageStream: { image: imgName, namespace: imgNamespace },
+    healthChecks,
   } = formData;
 
+  const annotations = getCommonAnnotations();
   const defaultAnnotations = {
     ...annotations,
     'alpha.image.policy.openshift.io/resolve-names': '*',
-    'image.openshift.io/triggers': JSON.stringify([
-      {
-        from: {
-          kind: 'ImageStreamTag',
-          name: `${imgName || name}:${imageStreamTag}`,
-          namespace: imgNamespace || namespace,
-        },
-        fieldPath: `spec.template.spec.containers[?(@.name=="${name}")].image`,
-        pause: `${!imageChange}`,
-      },
-    ]),
+    ...getTriggerAnnotation(
+      imgName || name,
+      imgNamespace || namespace,
+      imageChange,
+      imageStreamTag,
+    ),
   };
 
   const { labels, podLabels, volumes, volumeMounts } = getMetadata(formData);
@@ -219,6 +216,7 @@ export const createOrUpdateDeployment = (
                   },
                 }),
               },
+              ...getProbesData(healthChecks),
             },
           ],
         },
@@ -247,9 +245,11 @@ export const createOrUpdateDeploymentConfig = (
     labels: userLabels,
     limits: { cpu, memory },
     imageStream: { image: imgName, namespace: imgNamespace },
+    healthChecks,
   } = formData;
 
   const { labels, podLabels, volumes, volumeMounts } = getMetadata(formData);
+  const annotations = getCommonAnnotations();
   const newDeploymentConfig = {
     kind: 'DeploymentConfig',
     apiVersion: 'apps.openshift.io/v1',
@@ -290,6 +290,7 @@ export const createOrUpdateDeploymentConfig = (
                   },
                 }),
               },
+              ...getProbesData(healthChecks),
             },
           ],
         },
@@ -353,11 +354,15 @@ export const createOrUpdateDeployImageResources = async (
   const {
     name,
     registry,
+    project: { name: namespace },
     route: { create: canCreateRoute, disable },
     isi: { ports, tag: imageStreamTag, image },
-    imageStream: { image: internalImageName, namespace: internalImageNamespace },
+    imageStream: { image: internalImageStreamName, namespace: internalImageStreamNamespace },
+    deployment: {
+      triggers: { image: imageChange },
+    },
   } = formData;
-
+  const internalImageName = getRuntime(image.metadata?.labels);
   const requests: Promise<K8sResourceKind>[] = [];
   if (registry === RegistryType.Internal) {
     formData.imageStream.grantAccess &&
@@ -407,12 +412,16 @@ export const createOrUpdateDeployImageResources = async (
     let imageStreamUrl: string = image?.dockerImageReference;
     if (registry === RegistryType.External) {
       let generatedImageStreamName: string = '';
-      if (imageStreamList && imageStreamList.length && verb === 'update') {
-        const originalImageStreamTag = _.find(originalImageStream?.status?.tags, [
-          'tag',
-          imageStreamTag,
-        ]);
-        if (!_.isEmpty(originalImageStreamTag)) {
+      if (verb === 'update') {
+        if (imageStreamList && imageStreamList.length) {
+          const originalImageStreamTag = _.find(originalImageStream?.status?.tags, [
+            'tag',
+            imageStreamTag,
+          ]);
+          if (!_.isEmpty(originalImageStreamTag)) {
+            generatedImageStreamName = `${name}-${getRandomChars()}`;
+          }
+        } else {
           generatedImageStreamName = `${name}-${getRandomChars()}`;
         }
       }
@@ -427,14 +436,23 @@ export const createOrUpdateDeployImageResources = async (
       imageStreamUrl = imageStreamTag ? `${imageStreamRepo}:${imageStreamTag}` : imageStreamRepo;
     }
     const originalAnnotations = appResources?.editAppResource?.data?.metadata?.annotations || {};
-    const newAnnotations = { ...originalAnnotations, ...annotations };
+    const triggerAnnotations = getTriggerAnnotation(
+      internalImageStreamName || name,
+      internalImageStreamNamespace || namespace,
+      imageChange,
+      imageStreamTag,
+    );
+    const annotations = {
+      ...originalAnnotations,
+      ...triggerAnnotations,
+    };
     const knDeploymentResource = getKnativeServiceDepResource(
       formData,
       imageStreamUrl,
       internalImageName || name,
       imageStreamTag,
-      internalImageNamespace,
-      newAnnotations,
+      internalImageStreamNamespace,
+      annotations,
       _.get(appResources, 'editAppResource.data'),
     );
     requests.push(
