@@ -1,8 +1,11 @@
 import { ValidatedOptions } from '@patternfly/react-core';
 import { K8sResourceKind, ContainerPort } from '@console/internal/module/k8s';
+import { DeploymentModel, DeploymentConfigModel } from '@console/internal/models';
 import { LazyLoader } from '@console/plugin-sdk';
 import { NameValuePair, NameValueFromPair } from '@console/shared';
+import { ServiceModel } from '@console/knative-plugin/src/models';
 import { NormalizedBuilderImages } from '../../utils/imagestream-utils';
+import { HealthCheckProbe } from '../health-checks/health-checks-types';
 
 export interface DeployImageFormProps {
   builderImages?: NormalizedBuilderImages;
@@ -70,6 +73,7 @@ export interface DeployImageFormData {
   image: ImageStreamImageData;
   isSearchingForImage: boolean;
   resources: Resources;
+  resourceTypesNotValid?: Resources[];
   serverless?: ServerlessData;
   pipeline?: PipelineData;
   labels: { [name: string]: string };
@@ -78,6 +82,7 @@ export interface DeployImageFormData {
   build: BuildData;
   deployment: DeploymentData;
   limits: LimitsData;
+  healthChecks: HealthChecksData;
 }
 
 export interface GitImportFormData {
@@ -92,10 +97,12 @@ export interface GitImportFormData {
   image: ImageData;
   route: RouteData;
   resources: Resources;
+  resourceTypesNotValid?: Resources[];
   build: BuildData;
   deployment: DeploymentData;
   labels: { [name: string]: string };
   limits: LimitsData;
+  healthChecks: HealthChecksData;
 }
 
 export interface ApplicationData {
@@ -227,6 +234,12 @@ export enum Resources {
   KnativeService = 'knative',
 }
 
+export const ReadableResourcesNames = {
+  [Resources.OpenShift]: DeploymentConfigModel.label,
+  [Resources.Kubernetes]: DeploymentModel.label,
+  [Resources.KnativeService]: `Knative ${ServiceModel.label}`,
+};
+
 export interface ImportData {
   type: ImportTypes;
   title: string;
@@ -281,4 +294,11 @@ export enum ImportOptions {
   CATALOG = 'CATALOG',
   DOCKERFILE = 'DOCKERFILE',
   DATABASE = 'DATABASE',
+  EVENTSOURCE = 'EVENTSOURCE',
+}
+
+export interface HealthChecksData {
+  readinessProbe: HealthCheckProbe;
+  livenessProbe: HealthCheckProbe;
+  startupProbe?: HealthCheckProbe;
 }
