@@ -1,41 +1,27 @@
 import * as React from 'react';
 import { Status } from '@console/shared';
-import { TableRow, TableData } from '@console/internal/components/factory';
-import { Kebab, ResourceLink, Timestamp, ResourceKebab } from '@console/internal/components/utils';
+import { TableRow, TableData, RowFunction } from '@console/internal/components/factory';
+import { ResourceLink, Timestamp } from '@console/internal/components/utils';
 import { referenceForModel } from '@console/internal/module/k8s';
 import { pipelineFilterReducer } from '../../../utils/pipeline-filter-reducer';
 import { Pipeline } from '../../../utils/pipeline-augment';
 import { PipelineModel, PipelineRunModel } from '../../../models';
-import {
-  rerunPipelineAndRedirect,
-  startPipeline,
-  handlePipelineRunSubmit,
-  editPipeline,
-} from '../../../utils/pipeline-actions';
 import LinkedPipelineRunTaskStatus from '../../pipelineruns/status/LinkedPipelineRunTaskStatus';
 import { tableColumnClasses } from './pipeline-table';
+import PipelineRowKebabActions from './PipelineRowKebabActions';
 
 const pipelineReference = referenceForModel(PipelineModel);
 const pipelinerunReference = referenceForModel(PipelineRunModel);
 
-interface PipelineRowProps {
-  obj: Pipeline;
-  index: number;
-  key?: string;
-  style: object;
-}
-
-const PipelineRow: React.FC<PipelineRowProps> = ({ obj, index, key, style }) => {
-  const menuActions = [
-    () => startPipeline(PipelineModel, obj, handlePipelineRunSubmit),
-    ...(obj.latestRun && obj.latestRun.metadata
-      ? [() => rerunPipelineAndRedirect(PipelineRunModel, obj.latestRun)]
-      : []),
-    editPipeline,
-    Kebab.factory.Delete,
-  ];
+const PipelineRow: RowFunction<Pipeline> = ({ obj, index, key, style }) => {
   return (
-    <TableRow id={obj.metadata.uid} index={index} trKey={key} style={style}>
+    <TableRow
+      id={obj.metadata.uid}
+      data-test-id={`${obj.metadata.namespace}-${obj.metadata.name}`}
+      index={index}
+      trKey={key}
+      style={style}
+    >
       <TableData className={tableColumnClasses[0]}>
         <ResourceLink
           kind={pipelineReference}
@@ -75,7 +61,7 @@ const PipelineRow: React.FC<PipelineRowProps> = ({ obj, index, key, style }) =>
           '-'}
       </TableData>
       <TableData className={tableColumnClasses[6]}>
-        <ResourceKebab actions={menuActions} kind={pipelineReference} resource={obj} />
+        <PipelineRowKebabActions pipeline={obj} />
       </TableData>
     </TableRow>
   );
