@@ -1,13 +1,13 @@
 import { action, ActionType } from 'typesafe-actions';
-import { TopologyFilters } from '../filters/filter-utils';
-import { TOPOLOGGY_FILTERS_LOCAL_STORAGE_KEY } from './const';
+import { TopologyFilters } from '../filters/filter-types';
+import { TOPOLOGY_DISPLAY_FILTERS_LOCAL_STORAGE_KEY } from './const';
 
 export enum Actions {
   topologyFilters = 'topologyFilters',
 }
 
 export const setTopologyFilters = (filters: TopologyFilters) => {
-  localStorage.setItem(TOPOLOGGY_FILTERS_LOCAL_STORAGE_KEY, JSON.stringify(filters));
+  localStorage.setItem(TOPOLOGY_DISPLAY_FILTERS_LOCAL_STORAGE_KEY, JSON.stringify(filters.display));
   return action(Actions.topologyFilters, { filters });
 };
 
