@@ -75,7 +75,7 @@ export const PipelineResourceModel: K8sKind = {
   id: 'pipelineresource',
   labelPlural: 'Pipeline Resources',
   crd: true,
-  badge: BadgeType.DEV,
+  badge: BadgeType.TECH,
   color,
 };
 
@@ -108,3 +108,63 @@ export const ConditionModel: K8sKind = {
   badge: BadgeType.DEV,
   color,
 };
+
+export const TriggerBindingModel: K8sKind = {
+  apiGroup: 'triggers.tekton.dev',
+  apiVersion: 'v1alpha1',
+  label: 'Trigger Binding',
+  plural: 'triggerbindings',
+  abbr: 'TB',
+  namespaced: true,
+  kind: 'TriggerBinding',
+  id: 'triggerbinding',
+  labelPlural: 'Trigger Bindings',
+  crd: true,
+  badge: BadgeType.TECH,
+  color,
+};
+
+export const ClusterTriggerBindingModel: K8sKind = {
+  apiGroup: 'triggers.tekton.dev',
+  apiVersion: 'v1alpha1',
+  label: 'Cluster Trigger Binding',
+  plural: 'clustertriggerbindings',
+  abbr: 'CTB',
+  namespaced: false,
+  kind: 'ClusterTriggerBinding',
+  id: 'clustertriggerbinding',
+  labelPlural: 'Cluster Trigger Bindings',
+  crd: true,
+  badge: BadgeType.TECH,
+  color,
+};
+
+export const TriggerTemplateModel: K8sKind = {
+  apiGroup: 'triggers.tekton.dev',
+  apiVersion: 'v1alpha1',
+  label: 'Trigger Template',
+  plural: 'triggertemplates',
+  abbr: 'TT',
+  namespaced: true,
+  kind: 'TriggerTemplate',
+  id: 'triggertemplate',
+  labelPlural: 'Trigger Templates',
+  crd: true,
+  badge: BadgeType.TECH,
+  color,
+};
+
+export const EventListenerModel: K8sKind = {
+  apiGroup: 'triggers.tekton.dev',
+  apiVersion: 'v1alpha1',
+  label: 'Event Listener',
+  plural: 'eventlisteners',
+  abbr: 'EL',
+  namespaced: true,
+  kind: 'EventListener',
+  id: 'eventlistener',
+  labelPlural: 'Event Listeners',
+  crd: true,
+  badge: BadgeType.TECH,
+  color,
+};
