@@ -1,11 +1,13 @@
 import * as React from 'react';
 import * as _ from 'lodash';
+import { CodeIcon, BoltIcon, DatabaseIcon, CatalogIcon } from '@patternfly/react-icons';
 import {
   Plugin,
   ModelDefinition,
   ModelFeatureFlag,
   KebabActions,
   HrefNavItem,
+  SeparatorNavItem,
   ResourceNSNavItem,
   ResourceClusterNavItem,
   ResourceListPage,
@@ -19,9 +21,19 @@ import {
   ReduxReducer,
 } from '@console/plugin-sdk';
 import { NamespaceRedirect } from '@console/internal/components/utils/namespace-redirect';
-import { CodeIcon } from '@patternfly/react-icons';
 import { FLAGS } from '@console/shared/src/constants';
 import { referenceForModel } from '@console/internal/module/k8s';
+import {
+  BuildConfigModel,
+  ImageStreamModel,
+  DeploymentConfigModel,
+  SecretModel,
+  RouteModel,
+  ServiceModel,
+  ImageStreamImportsModel,
+  ConfigMapModel,
+} from '@console/internal/models';
+import * as helmIcon from '@console/internal/imgs/logos/helm.svg';
 import * as models from './models';
 import { getKebabActionsForKind } from './utils/kebab-actions';
 import {
@@ -37,6 +49,11 @@ import {
   newClusterTaskTemplate,
 } from './templates';
 import reducer from './utils/reducer';
+import { AddAction } from './extensions/add-actions';
+import * as yamlIcon from './images/yaml.svg';
+import * as importGitIcon from './images/from-git.svg';
+import * as dockerfileIcon from './images/dockerfile.svg';
+import * as pipelineIcon from './images/pipeline.svg';
 
 const {
   ClusterTaskModel,
@@ -45,6 +62,9 @@ const {
   PipelineRunModel,
   TaskModel,
   TaskRunModel,
+  EventListenerModel,
+  TriggerTemplateModel,
+  TriggerBindingModel,
 } = models;
 
 type ConsumedExtensions =
@@ -52,6 +72,7 @@ type ConsumedExtensions =
   | ModelFeatureFlag
   | HrefNavItem
   | ResourceClusterNavItem
+  | SeparatorNavItem
   | ResourceNSNavItem
   | ResourceListPage
   | ResourceDetailsPage
@@ -62,7 +83,8 @@ type ConsumedExtensions =
   | OverviewResourceTab
   | OverviewCRD
   | YAMLTemplate
-  | OverviewTabSection;
+  | OverviewTabSection
+  | AddAction;
 
 const plugin: Plugin<ConsumedExtensions> = [
   {
@@ -124,6 +146,26 @@ const plugin: Plugin<ConsumedExtensions> = [
       required: [FLAGS.OPENSHIFT],
     },
   },
+  {
+    type: 'NavItem/Href',
+    properties: {
+      perspective: 'dev',
+      componentProps: {
+        name: 'Search',
+        href: '/search',
+        testID: 'search-header',
+      },
+    },
+  },
+  {
+    type: 'NavItem/Separator',
+    properties: {
+      perspective: 'dev',
+      componentProps: {
+        testID: 'dev-separator',
+      },
+    },
+  },
   {
     type: 'NavItem/ResourceNS',
     properties: {
@@ -155,19 +197,6 @@ const plugin: Plugin<ConsumedExtensions> = [
   {
     type: 'NavItem/Href',
     properties: {
-      section: 'More',
-      perspective: 'dev',
-      componentProps: {
-        name: 'Search',
-        href: '/search',
-        testID: 'more-search-header',
-      },
-    },
-  },
-  {
-    type: 'NavItem/Href',
-    properties: {
-      section: 'More',
       perspective: 'dev',
       componentProps: {
         name: 'Helm',
@@ -180,32 +209,19 @@ const plugin: Plugin<ConsumedExtensions> = [
     },
   },
   {
-    type: 'NavItem/ResourceCluster',
+    type: 'NavItem/Href',
     properties: {
-      section: 'More',
       perspective: 'dev',
       componentProps: {
-        name: 'Project Details',
-        resource: 'projects',
-        testID: 'more-project-header',
+        name: 'Project',
+        href: '/project-details',
+        testID: 'project-details-header',
       },
     },
     flags: {
       required: [FLAGS.OPENSHIFT],
     },
   },
-  {
-    type: 'NavItem/Href',
-    properties: {
-      section: 'More',
-      perspective: 'dev',
-      componentProps: {
-        name: 'Project Access',
-        href: '/project-access',
-        testID: 'more-project-access-header',
-      },
-    },
-  },
   {
     type: 'Overview/CRD',
     properties: {
@@ -312,7 +328,7 @@ const plugin: Plugin<ConsumedExtensions> = [
     type: 'Overview/Resource',
     properties: {
       name: 'Monitoring',
-      key: 'events',
+      key: 'isMonitorable',
       loader: () =>
         import(
           './components/monitoring/overview/MonitoringTab' /* webpackChunkName: "monitoring-overview" */
@@ -355,6 +371,42 @@ const plugin: Plugin<ConsumedExtensions> = [
         ).default,
     },
   },
+  {
+    type: 'Page/Resource/Details',
+    properties: {
+      model: EventListenerModel,
+      loader: async () =>
+        (
+          await import(
+            './components/pipelines/EventListenerPage' /* webpackChunkName: "eventlistener-details" */
+          )
+        ).default,
+    },
+  },
+  {
+    type: 'Page/Resource/Details',
+    properties: {
+      model: TriggerTemplateModel,
+      loader: async () =>
+        (
+          await import(
+            './components/pipelines/TriggerTemplatePage' /* webpackChunkName: "trigger-template-details" */
+          )
+        ).default,
+    },
+  },
+  {
+    type: 'Page/Resource/Details',
+    properties: {
+      model: TriggerBindingModel,
+      loader: async () =>
+        (
+          await import(
+            './components/pipelines/TriggerBindingPage' /* webpackChunkName: "trigger-binding-details" */
+          )
+        ).default,
+    },
+  },
   {
     type: 'Page/Resource/List',
     properties: {
@@ -385,6 +437,7 @@ const plugin: Plugin<ConsumedExtensions> = [
       id: 'dev',
       name: 'Developer',
       icon: <CodeIcon />,
+      defaultPins: [ConfigMapModel.kind, SecretModel.kind],
       getLandingPageURL: () => '/topology',
       getK8sLandingPageURL: () => '/add',
       getImportRedirectURL: (project) => `/topology/ns/${project}`,
@@ -399,7 +452,7 @@ const plugin: Plugin<ConsumedExtensions> = [
         '/import',
         '/topology',
         '/deploy-image',
-        '/project-access',
+        '/project-details',
         '/dev-monitoring',
         '/helm-releases',
       ],
@@ -435,19 +488,6 @@ const plugin: Plugin<ConsumedExtensions> = [
         ).default,
     },
   },
-  {
-    type: 'Page/Route',
-    properties: {
-      exact: true,
-      path: ['/catalog/helm-install'],
-      loader: async () =>
-        (
-          await import(
-            './components/helm/HelmInstallPage' /* webpackChunkName: "dev-console-helm-install" */
-          )
-        ).default,
-    },
-  },
   {
     type: 'Page/Route',
     properties: {
@@ -487,19 +527,6 @@ const plugin: Plugin<ConsumedExtensions> = [
         ).default,
     },
   },
-  {
-    type: 'Page/Route',
-    properties: {
-      path: ['/helm-releases/ns/:ns/release/:name'],
-      exact: false,
-      loader: async () =>
-        (
-          await import(
-            './components/helm/HelmReleaseDetails' /* webpackChunkName: "dev-console-helmReleaseDetails" */
-          )
-        ).default,
-    },
-  },
   {
     type: 'Page/Route',
     properties: {
@@ -528,7 +555,7 @@ const plugin: Plugin<ConsumedExtensions> = [
           await import(
             './components/pipelines/PipelinesPage' /* webpackChunkName: "pipeline-page" */
           )
-        ).PipelinesPage,
+        ).default,
     },
   },
   {
@@ -590,13 +617,12 @@ const plugin: Plugin<ConsumedExtensions> = [
   {
     type: 'Page/Route',
     properties: {
-      perspective: 'dev',
       exact: true,
-      path: ['/k8s/cluster/projects'],
+      path: ['/catalog/helm-install'],
       loader: async () =>
         (
           await import(
-            './components/projects/details/AllProjectsDetailList' /* webpackChunkName: "all-projects-detail-list" */
+            './components/helm/HelmInstallUpgradePage' /* webpackChunkName: "dev-console-helm-install-upgrade" */
           )
         ).default,
     },
@@ -604,12 +630,25 @@ const plugin: Plugin<ConsumedExtensions> = [
   {
     type: 'Page/Route',
     properties: {
-      perspective: 'dev',
-      path: ['/k8s/cluster/projects/:name'],
+      exact: true,
+      path: [`/helm-releases/ns/:ns/:releaseName/upgrade`],
       loader: async () =>
         (
           await import(
-            './components/projects/details/ProjectDetailsPage' /* webpackChunkName: "project-details" */
+            './components/helm/HelmInstallUpgradePage' /* webpackChunkName: "dev-console-helm-install-upgrade" */
+          )
+        ).default,
+    },
+  },
+  {
+    type: 'Page/Route',
+    properties: {
+      exact: true,
+      path: [`/helm-releases/ns/:ns/:releaseName/rollback`],
+      loader: async () =>
+        (
+          await import(
+            './components/helm/HelmReleaseRollbackPage' /* webpackChunkName: "dev-console-helm-rollback" */
           )
         ).default,
     },
@@ -622,7 +661,7 @@ const plugin: Plugin<ConsumedExtensions> = [
       loader: async () =>
         (
           await import(
-            './components/helm/HelmReleasePage' /* webpackChunkName: "dev-console-helm-releases" */
+            './components/helm/HelmReleaseListPage' /* webpackChunkName: "dev-console-helm-releases-list" */
           )
         ).default,
     },
@@ -630,12 +669,26 @@ const plugin: Plugin<ConsumedExtensions> = [
   {
     type: 'Page/Route',
     properties: {
-      exact: true,
-      path: ['/project-access/all-namespaces', '/project-access/ns/:ns'],
+      path: ['/helm-releases/ns/:ns/release/:name'],
+      exact: false,
       loader: async () =>
         (
           await import(
-            './components/project-access/ProjectAccessPage' /* webpackChunkName: "dev-console-projectAccess" */
+            './components/helm/HelmReleaseDetailsPage' /* webpackChunkName: "dev-console-helm-release-details" */
+          )
+        ).default,
+    },
+  },
+  {
+    type: 'Page/Route',
+    properties: {
+      perspective: 'dev',
+      exact: false,
+      path: ['/project-details/all-namespaces', '/project-details/ns/:ns'],
+      loader: async () =>
+        (
+          await import(
+            './components/projects/details/ProjectDetailsPage' /* webpackChunkName: "dev-console-projectDetails" */
           )
         ).default,
     },
@@ -653,6 +706,47 @@ const plugin: Plugin<ConsumedExtensions> = [
         ).default,
     },
   },
+  {
+    type: 'Page/Route',
+    properties: {
+      exact: true,
+      path: ['/k8s/ns/:ns/:kind/:name/containers/:containerName/health-checks'],
+      loader: async () =>
+        (
+          await import(
+            './components/health-checks/HealthChecksPage' /* webpackChunkName: "dev-console-healthCheck" */
+          )
+        ).default,
+    },
+  },
+  {
+    type: 'Page/Route',
+    properties: {
+      perspective: 'dev',
+      exact: false,
+      path: ['/k8s/all-namespaces/import'],
+      loader: async () =>
+        (
+          await import(
+            '@console/internal/components/import-yaml' /* webpackChunkName: "import-yaml" */
+          )
+        ).ImportYamlPage,
+    },
+  },
+  {
+    type: 'Page/Route',
+    properties: {
+      perspective: 'dev',
+      exact: false,
+      path: ['/k8s/all-namespaces/:plural'],
+      loader: async () =>
+        (
+          await import(
+            './components/ProjectSelectPage' /* webpackChunkName: "dev-console-projectselectpage" */
+          )
+        ).default,
+    },
+  },
   {
     type: 'ReduxReducer',
     properties: {
@@ -701,6 +795,143 @@ const plugin: Plugin<ConsumedExtensions> = [
       template: newClusterTaskTemplate,
     },
   },
+  {
+    type: 'AddAction',
+    properties: {
+      id: 'import-from-git',
+      url: '/import',
+      label: 'From Git',
+      description: 'Import code from your git repository to be built and deployed',
+      icon: importGitIcon,
+      accessReview: [
+        BuildConfigModel,
+        ImageStreamModel,
+        DeploymentConfigModel,
+        SecretModel,
+        RouteModel,
+        ServiceModel,
+      ].map((model) => ({
+        group: model.apiGroup || '',
+        resource: model.plural,
+        verb: 'create',
+      })),
+    },
+  },
+  {
+    type: 'AddAction',
+    properties: {
+      id: 'deploy-image',
+      url: '/deploy-image',
+      label: 'Container Image',
+      description: 'Deploy an existing image from an image registry or image stream tag',
+      iconClass: 'pficon-image',
+      accessReview: [
+        BuildConfigModel,
+        ImageStreamModel,
+        DeploymentConfigModel,
+        ImageStreamImportsModel,
+        SecretModel,
+        RouteModel,
+        ServiceModel,
+      ].map((model) => ({
+        group: model.apiGroup || '',
+        resource: model.plural,
+        verb: 'create',
+      })),
+    },
+  },
+  {
+    type: 'AddAction',
+    properties: {
+      id: 'import-from-dockerfile',
+      url: '/import?importType=docker',
+      label: 'From Dockerfile',
+      description: 'Import your Dockerfile from your git repo to be built and deployed',
+      icon: dockerfileIcon,
+      accessReview: [
+        BuildConfigModel,
+        ImageStreamModel,
+        DeploymentConfigModel,
+        SecretModel,
+        RouteModel,
+        ServiceModel,
+      ].map((model) => ({
+        group: model.apiGroup || '',
+        resource: model.plural,
+        verb: 'create',
+      })),
+    },
+  },
+  {
+    type: 'AddAction',
+    properties: {
+      id: 'import-yaml',
+      url: '/k8s/ns/:namespace/import',
+      label: 'YAML',
+      description: 'Create resources from their YAML or JSON definitions',
+      icon: yamlIcon,
+    },
+  },
+  {
+    type: 'AddAction',
+    properties: {
+      id: 'dev-catalog',
+      url: '/catalog',
+      label: 'From Catalog',
+      description: 'Browse the catalog to discover, deploy and connect to services',
+      icon: <CatalogIcon />,
+    },
+  },
+  {
+    type: 'AddAction',
+    properties: {
+      id: 'dev-catalog-databases',
+      url: '/catalog?category=databases',
+      label: 'Database',
+      description: 'Browse the catalog to discover database services to add to your application',
+      icon: <DatabaseIcon />,
+    },
+  },
+  {
+    type: 'AddAction',
+    properties: {
+      id: 'operator-backed',
+      url: '/catalog?kind=%5B"ClusterServiceVersion"%5D',
+      label: 'Operator Backed',
+      description: 'Browse the catalog to discover and deploy operator managed services',
+      icon: <BoltIcon />,
+    },
+  },
+  {
+    type: 'AddAction',
+    properties: {
+      id: 'helm',
+      url: '/catalog?kind=%5B"HelmChart"%5D',
+      label: 'Helm Chart',
+      description: 'Browse the catalog to discover and install Helm Charts',
+      icon: helmIcon,
+    },
+  },
+  {
+    type: 'AddAction',
+    flags: {
+      required: [FLAG_OPENSHIFT_PIPELINE],
+    },
+    properties: {
+      id: 'pipeline',
+      url: `/k8s/ns/:namespace/${referenceForModel(PipelineModel)}/~new/builder`,
+      label: 'Pipeline',
+      description: 'Create a Tekton Pipeline to automate delivery of your application',
+      icon: pipelineIcon,
+      accessReview: [
+        {
+          group: PipelineModel.apiGroup,
+          resource: PipelineModel.plural,
+          verb: 'create',
+        },
+      ],
+    },
+  },
 ];
 
 export default plugin;
