@@ -23,27 +23,17 @@ import {
   DaemonSetModel,
   StatefulSetModel,
 } from '@console/internal/models';
-import {
-  ClusterServiceVersionKind,
-  ClusterServiceVersionModel,
-} from '@console/operator-lifecycle-manager';
+import { ClusterServiceVersionModel } from '@console/operator-lifecycle-manager';
 import {
   ServiceModel as KnativeServiceModel,
   RouteModel as KnativeRouteModel,
-  EventSourceCronJobModel,
-  EventSourceContainerModel,
-  EventSourceApiServerModel,
-  EventSourceCamelModel,
-  EventSourceKafkaModel,
 } from '@console/knative-plugin';
+import { isDynamicEventResourceKind } from '@console/knative-plugin/src/utils/fetch-dynamic-eventsources-utils';
 import { checkAccess } from '@console/internal/components/utils';
-import {
-  OperatorBackedServiceKindMap,
-  TopologyDataObject,
-} from '../components/topology/topology-types';
-import { detectGitType } from '../components/import/import-validation-utils';
-import { GitTypes } from '../components/import/import-types';
+import { getOperatorBackedServiceKindMap } from '@console/shared';
 import { CREATE_APPLICATION_KEY, UNASSIGNED_KEY } from '../const';
+import { TopologyDataObject, ConnectsToData } from '../components/topology/topology-types';
+import { detectGitType } from '../components/import/import-validation-utils';
 import { ServiceBindingRequestModel } from '../models';
 
 export const sanitizeApplicationValue = (
@@ -59,8 +49,8 @@ export const sanitizeApplicationValue = (
   }
 };
 
-export const edgesFromAnnotations = (annotations): string[] => {
-  let edges: string[] = [];
+export const edgesFromAnnotations = (annotations): (string | ConnectsToData)[] => {
+  let edges: (string | ConnectsToData)[] = [];
   if (_.has(annotations, ['app.openshift.io/connects-to'])) {
     try {
       edges = JSON.parse(annotations['app.openshift.io/connects-to']);
@@ -204,8 +194,9 @@ export const updateResourceApplication = (
 // Updates the item to add an new connect's to value replacing an old value if provided
 const updateItemAppConnectTo = (
   item: K8sResourceKind,
-  connectValue: string,
-  oldValue: string = undefined,
+  connections: (string | ConnectsToData)[],
+  connectValue: ConnectsToData,
+  oldValueIndex: number,
 ) => {
   const model = modelFor(referenceFor(item) || item.kind);
 
@@ -218,20 +209,18 @@ const updateItemAppConnectTo = (
 
   const existingTag = _.find(tags, (tag) => tag[0] === 'app.openshift.io/connects-to');
   if (existingTag) {
-    const connections = edgesFromAnnotations(item.metadata.annotations);
     if (connections.includes(connectValue)) {
       return Promise.resolve();
     }
 
-    const index = connections.indexOf(oldValue);
     if (!connectValue) {
-      _.remove(connections, (connection) => connection === oldValue);
-    } else if (index >= 0) {
-      connections[index] = connectValue;
+      _.pullAt(connections, [oldValueIndex]);
+    } else if (oldValueIndex >= 0) {
+      connections[oldValueIndex] = connectValue;
     } else {
       connections.push(connectValue);
     }
-    existingTag[1] = connections.join(',');
+    existingTag[1] = _.size(connections) && JSON.stringify(connections);
 
     if (!existingTag[1]) {
       _.remove(tags, (tag) => tag === existingTag);
@@ -245,7 +234,10 @@ const updateItemAppConnectTo = (
       return Promise.resolve();
     }
 
-    const connectionTag: [string, string] = ['app.openshift.io/connects-to', connectValue];
+    const connectionTag: [string, string] = [
+      'app.openshift.io/connects-to',
+      JSON.stringify([connectValue]),
+    ];
     tags.push(connectionTag);
   }
 
@@ -304,6 +296,34 @@ export const removeServiceBinding = (sbr: K8sResourceKind): Promise<any> => {
   return k8sKill(ServiceBindingRequestModel, sbr);
 };
 
+// Get the index of the replaced target of the visual connector
+const getReplacedTargetIndex = (
+  replacedTarget: K8sResourceKind,
+  connections: (string | ConnectsToData)[],
+): number => {
+  if (replacedTarget) {
+    const replaceTargetName = replacedTarget.metadata?.name;
+    const replaceTargetKind = replacedTarget.kind;
+    const replaceTargetApiVersion = replacedTarget.apiVersion;
+    const replaceValue = {
+      apiVersion: replaceTargetApiVersion,
+      kind: replaceTargetKind,
+      name: replaceTargetName,
+    };
+    const replaceTargetInstanceName =
+      replacedTarget.metadata?.labels?.['app.kubernetes.io/instance'];
+    let index = _.findIndex(connections, replaceValue);
+    if (index === -1) {
+      index = _.findIndex(
+        connections,
+        (connection) => connection === (replaceTargetInstanceName || replaceTargetName),
+      );
+    }
+    return index;
+  }
+  return -1;
+};
+
 // Create a connection from the source to the target replacing the connection to replacedTarget if provided
 export const createResourceConnection = (
   source: K8sResourceKind,
@@ -314,20 +334,23 @@ export const createResourceConnection = (
     return Promise.reject();
   }
 
-  const connectValue =
-    _.get(target, ['metadata', 'labels', 'app.kubernetes.io/instance']) || target.metadata.name;
+  const connectTargetName = target.metadata?.name;
+  const connectTargetKind = target.kind;
+  const connectTargetApiVersion = target.apiVersion;
+  const connectValue = {
+    apiVersion: connectTargetApiVersion,
+    kind: connectTargetKind,
+    name: connectTargetName,
+  };
+
+  const connections = edgesFromAnnotations(source.metadata?.annotations);
+
+  const replacedTargetIndex = getReplacedTargetIndex(replacedTarget, connections);
 
-  const replaceValue =
-    replacedTarget &&
-    _.get(
-      replacedTarget.metadata,
-      ['labels', 'app.kubernetes.io/instance'],
-      replacedTarget.metadata.name,
-    );
   const instanceName = _.get(source, ['metadata', 'labels', 'app.kubernetes.io/instance']);
 
   const patches: Promise<K8sResourceKind>[] = [
-    updateItemAppConnectTo(source, connectValue, replaceValue),
+    updateItemAppConnectTo(source, connections, connectValue, replacedTargetIndex),
   ];
 
   // If there is no instance label, only update this item
@@ -339,7 +362,7 @@ export const createResourceConnection = (
   return listInstanceResources(source.metadata.namespace, instanceName).then((listsValue) => {
     _.forEach(listsValue, (list) => {
       _.forEach(list, (item) => {
-        patches.push(updateItemAppConnectTo(item, connectValue, replaceValue));
+        patches.push(updateItemAppConnectTo(item, connections, connectValue, replacedTargetIndex));
       });
     });
 
@@ -355,13 +378,15 @@ export const removeResourceConnection = (
   if (!source || !target || source === target) {
     return Promise.reject();
   }
+  const connections = edgesFromAnnotations(source.metadata?.annotations);
 
-  const replaceValue =
-    _.get(target, ['metadata', 'labels', 'app.kubernetes.io/instance']) || target.metadata.name;
+  const replacedTargetIndex = getReplacedTargetIndex(target, connections);
 
   const instanceName = _.get(source, ['metadata', 'labels', 'app.kubernetes.io/instance']);
 
-  const patches: Promise<any>[] = [updateItemAppConnectTo(source, '', replaceValue)];
+  const patches: Promise<any>[] = [
+    updateItemAppConnectTo(source, connections, null, replacedTargetIndex),
+  ];
 
   // If there is no instance label, only update this item
   if (!instanceName) {
@@ -372,7 +397,7 @@ export const removeResourceConnection = (
   return listInstanceResources(source.metadata.namespace, instanceName).then((listsValue) => {
     _.forEach(listsValue, (list) => {
       _.forEach(list, (item) => {
-        patches.push(updateItemAppConnectTo(item, '', replaceValue));
+        patches.push(updateItemAppConnectTo(item, connections, null, replacedTargetIndex));
       });
     });
 
@@ -380,37 +405,65 @@ export const removeResourceConnection = (
   });
 };
 
+const safeKill = async (model: K8sKind, obj: K8sResourceKind) => {
+  const resp = await checkAccess({
+    group: model.apiGroup,
+    resource: model.plural,
+    verb: 'delete',
+    name: obj.metadata.name,
+    namespace: obj.metadata.namespace,
+  });
+  if (resp.status.allowed) {
+    return k8sKill(model, obj);
+  }
+  return null;
+};
+
+const deleteWebhooks = (
+  resource: K8sResourceKind,
+  workload: TopologyDataObject<{ isKnativeResource?: boolean }>,
+) => {
+  const isKnativeResource = workload?.data?.isKnativeResource ?? false;
+  const deploymentsAnnotations = resource.metadata?.annotations ?? {};
+  const gitType = detectGitType(deploymentsAnnotations['app.openshift.io/vcs-uri']);
+  const buildConfigs = workload?.resources?.buildConfigs;
+  return buildConfigs?.reduce((requests, bc) => {
+    const triggers = bc.spec?.triggers ?? [];
+    const reqs = triggers.reduce((a, t) => {
+      let obj: K8sResourceKind;
+      const webhookType = t.generic ? 'generic' : gitType;
+      const webhookTypeObj = t.generic || (!isKnativeResource && t[gitType]);
+      if (webhookTypeObj) {
+        obj = {
+          ...resource,
+          metadata: {
+            name:
+              webhookTypeObj.secretReference?.name ??
+              `${resource.metadata.name}-${webhookType}-webhook-secret`,
+            namespace: resource.metadata.namespace,
+          },
+        };
+      }
+      return obj ? [...a, safeKill(SecretModel, obj)] : a;
+    }, []);
+    return [...requests, ...reqs];
+  }, []);
+};
+
 export const cleanUpWorkload = (
   resource: K8sResourceKind,
   workload: TopologyDataObject,
 ): Promise<K8sResourceKind[]> => {
   const reqs = [];
-  const webhooks = [];
-  let webhooksAvailable = false;
-  const deleteModels = [BuildConfigModel, ServiceModel, RouteModel];
-  const knativeDeleteModels = [
-    KnativeServiceModel,
-    KnativeRouteModel,
-    BuildConfigModel,
-    ImageStreamModel,
-  ];
-  const deploymentsAnnotations = _.get(resource, 'metadata.annotations', {});
-  const isKnativeResource = _.get(workload, 'data.isKnativeResource', false);
-  const gitType = detectGitType(deploymentsAnnotations['app.openshift.io/vcs-uri']);
+  const isBuildConfigPresent = !_.isEmpty(workload?.resources?.buildConfigs);
+
+  const deleteModels = [ServiceModel, RouteModel];
+  const knativeDeleteModels = [KnativeServiceModel, KnativeRouteModel, ImageStreamModel];
+  if (isBuildConfigPresent) {
+    deleteModels.push(BuildConfigModel);
+    knativeDeleteModels.push(BuildConfigModel);
+  }
   const resourceData = _.cloneDeep(resource);
-  const safeKill = async (model: K8sKind, obj: K8sResourceKind) => {
-    const resp = await checkAccess({
-      group: model.apiGroup,
-      resource: model.plural,
-      verb: 'delete',
-      name: obj.metadata.name,
-      namespace: obj.metadata.namespace,
-    });
-    if (resp.status.allowed) {
-      return k8sKill(model, obj);
-    }
-    return null;
-  };
   const deleteRequest = (model: K8sKind, resourceObj: K8sResourceKind) => {
     const req = safeKill(model, resourceObj);
     req && reqs.push(req);
@@ -418,6 +471,8 @@ export const cleanUpWorkload = (
   const batchDeleteRequests = (models: K8sKind[], resourceObj: K8sResourceKind): void => {
     models.forEach((model) => deleteRequest(model, resourceObj));
   };
+  if (isDynamicEventResourceKind(referenceFor(resource)))
+    deleteRequest(modelFor(referenceFor(resource)), resource);
   switch (resource.kind) {
     case DaemonSetModel.kind:
     case StatefulSetModel.kind:
@@ -428,59 +483,17 @@ export const cleanUpWorkload = (
       deleteRequest(modelFor(resource.kind), resource);
       batchDeleteRequests(deleteModels, resource);
       deleteRequest(ImageStreamModel, resource); // delete imageStream
-      webhooksAvailable = true;
-      break;
-    case EventSourceCronJobModel.kind:
-    case EventSourceApiServerModel.kind:
-    case EventSourceContainerModel.kind:
-    case EventSourceKafkaModel.kind:
-    case EventSourceCamelModel.kind:
-      deleteRequest(modelFor(referenceFor(resource)), resource);
       break;
     case KnativeServiceModel.kind:
       batchDeleteRequests(knativeDeleteModels, resourceData);
-      webhooksAvailable = true;
       break;
     default:
       break;
   }
-  if (webhooksAvailable) {
-    webhooks.push('generic');
-    if (!isKnativeResource && gitType !== GitTypes.unsure) {
-      webhooks.push(gitType);
-    }
-  }
-  webhooks.forEach((hookName) => {
-    const obj = {
-      ...resource,
-      metadata: {
-        name: `${resourceData.metadata.name}-${hookName}-webhook-secret`,
-        namespace: resourceData.metadata.namespace,
-      },
-    };
-    deleteRequest(SecretModel, obj);
-  });
+  isBuildConfigPresent && reqs.push(...deleteWebhooks(resource, workload));
   return Promise.all(reqs);
 };
 
-export const getOperatorBackedServiceKindMap = (
-  installedOperators: ClusterServiceVersionKind[],
-): OperatorBackedServiceKindMap => {
-  let operatorBackedServiceKindMap: OperatorBackedServiceKindMap = {};
-  if (installedOperators) {
-    operatorBackedServiceKindMap = installedOperators.reduce((kindMap, csv) => {
-      (csv?.spec?.customresourcedefinitions?.owned || []).forEach((crd) => {
-        if (!(crd.kind in kindMap)) {
-          kindMap[crd.kind] = csv;
-        }
-      });
-      return kindMap;
-    }, {});
-  }
-
-  return operatorBackedServiceKindMap;
-};
-
 export const doContextualBinding = async (
   resources: K8sResourceKind[],
   contextualSource: string,
