@@ -1,5 +1,6 @@
-import { K8sResourceKind } from '@console/internal/module/k8s';
 import * as _ from 'lodash';
+import { K8sResourceKind } from '@console/internal/module/k8s';
+import { TRIGGERS_ANNOTATION } from '@console/shared';
 
 export const getAppLabels = (
   name: string,
@@ -12,8 +13,10 @@ export const getAppLabels = (
     app: name,
     'app.kubernetes.io/instance': name,
     'app.kubernetes.io/component': name,
-    'app.kubernetes.io/name': imageStreamName,
-    'app.openshift.io/runtime': imageStreamName,
+    ...(imageStreamName && {
+      'app.kubernetes.io/name': imageStreamName,
+      'app.openshift.io/runtime': imageStreamName,
+    }),
   };
 
   if (application && application.trim().length > 0) {
@@ -29,15 +32,35 @@ export const getAppLabels = (
   return labels;
 };
 
-export const getAppAnnotations = (gitURL: string, gitRef: string) => {
+export const getGitAnnotations = (gitURL: string, gitRef?: string) => {
   const ref = gitRef || 'master';
   return {
     'app.openshift.io/vcs-uri': gitURL,
     'app.openshift.io/vcs-ref': ref,
+  };
+};
+
+export const getCommonAnnotations = () => {
+  return {
     'openshift.io/generated-by': 'OpenShiftWebConsole',
   };
 };
 
+export const getTriggerAnnotation = (
+  name: string,
+  namespace: string,
+  imageTrigger: boolean,
+  tag: string = 'latest',
+) => ({
+  [TRIGGERS_ANNOTATION]: JSON.stringify([
+    {
+      from: { kind: 'ImageStreamTag', name: `${name}:${tag}`, namespace },
+      fieldPath: `spec.template.spec.containers[?(@.name=="${name}")].image`,
+      pause: `${!imageTrigger}`,
+    },
+  ]),
+});
+
 export const getPodLabels = (name: string) => {
   return {
     app: name,
@@ -48,12 +71,12 @@ export const getPodLabels = (name: string) => {
 export const mergeData = (originalResource: K8sResourceKind, newResource: K8sResourceKind) => {
   const mergedData = _.merge({}, originalResource || {}, newResource);
   mergedData.metadata.labels = newResource.metadata.labels;
-  if (mergedData.spec?.template?.metadata?.labels) {
-    mergedData.spec.template.metadata.labels = newResource.spec?.template?.metadata?.labels;
-  }
   if (mergedData.metadata.annotations) {
     mergedData.metadata.annotations = newResource.metadata.annotations;
   }
+  if (mergedData.spec?.template?.metadata?.labels) {
+    mergedData.spec.template.metadata.labels = newResource.spec?.template?.metadata?.labels;
+  }
   if (mergedData.spec?.template?.spec?.containers) {
     mergedData.spec.template.spec.containers = newResource.spec.template.spec.containers;
   }
