@@ -2,14 +2,14 @@ import * as React from 'react';
 import { connect } from 'react-redux';
 import { Kebab, LoadingBox } from '@console/internal/components/utils';
 import { ResourceOverviewDetails } from '@console/internal/components/overview/resource-overview-details';
-import { groupVersionFor, K8sKind } from '@console/internal/module/k8s';
+import { groupVersionFor, K8sKind, referenceForModel } from '@console/internal/module/k8s';
 import { RootState } from '@console/internal/redux';
 import { OverviewItem } from '@console/shared';
-import {
-  KNATIVE_SERVING_APIGROUP,
-  KNATIVE_EVENT_SOURCE_APIGROUP,
-  KNATIVE_EVENT_SOURCE_APIGROUP_DEP,
-} from '../../const';
+import { ModifyApplication } from '@console/dev-console/src/actions/modify-application';
+import { KNATIVE_SERVING_APIGROUP } from '../../const';
+import { RevisionModel } from '../../models';
+import { getRevisionActions } from '../../actions/getRevisionActions';
+import { isDynamicEventResourceKind } from '../../utils/fetch-dynamic-eventsources-utils';
 import OverviewDetailsKnativeResourcesTab from './OverviewDetailsKnativeResourcesTab';
 import KnativeOverview from './KnativeOverview';
 
@@ -48,11 +48,23 @@ export const KnativeResourceOverviewPage: React.ComponentType<KnativeResourceOve
       model.apiGroup === apiInfo.group &&
       model.apiVersion === apiInfo.version,
   );
+
+  const actions = [];
+  if (resourceModel.kind === RevisionModel.kind) {
+    actions.push(...getRevisionActions());
+  } else {
+    actions.push(
+      ModifyApplication,
+      ...Kebab.getExtensionsActionsForKind(resourceModel),
+      ...Kebab.factory.common,
+    );
+  }
+
   return (
     <ResourceOverviewDetails
       item={item}
       kindObj={resourceModel}
-      menuActions={[...Kebab.getExtensionsActionsForKind(resourceModel), ...Kebab.factory.common]}
+      menuActions={actions}
       tabs={tabs}
     />
   );
@@ -66,8 +78,7 @@ const mapStateToProps = (state: RootState): StateProps => {
       .filter(
         (model: K8sKind) =>
           model.apiGroup === KNATIVE_SERVING_APIGROUP ||
-          model.apiGroup === KNATIVE_EVENT_SOURCE_APIGROUP ||
-          model.apiGroup === KNATIVE_EVENT_SOURCE_APIGROUP_DEP,
+          isDynamicEventResourceKind(referenceForModel(model)),
       ),
   };
 };
