@@ -1,8 +1,9 @@
 import * as React from 'react';
 import * as _ from 'lodash';
-import { K8sResourceKind, podPhase, PodKind } from '@console/internal/module/k8s';
+import { podPhase } from '@console/internal/module/k8s';
+import { BuildOverview } from '@console/internal/components/overview/build-overview';
 import { PodModel } from '@console/internal/models';
-import { AllPodStatus } from '@console/shared';
+import { AllPodStatus, OverviewItem, usePluginsOverviewTabSection } from '@console/shared';
 import { PodsOverview } from '@console/internal/components/overview/pods-overview';
 import RevisionsOverviewList from './RevisionsOverviewList';
 import KSRoutesOverviewList from './RoutesOverviewList';
@@ -10,18 +11,11 @@ import KSRoutesOverviewList from './RoutesOverviewList';
 const REVISIONS_AUTOSCALED = 'All Revisions are autoscaled to 0';
 
 type KnativeServiceResourceProps = {
-  obj: K8sResourceKind;
-  revisions: K8sResourceKind[];
-  ksroutes: K8sResourceKind[];
-  pods?: PodKind[];
+  item: OverviewItem;
 };
 
-const KnativeServiceResources: React.FC<KnativeServiceResourceProps> = ({
-  revisions,
-  ksroutes,
-  obj,
-  pods,
-}) => {
+const KnativeServiceResources: React.FC<KnativeServiceResourceProps> = ({ item }) => {
+  const { revisions, ksroutes, obj, pods, buildConfigs } = item;
   const {
     kind: resKind,
     metadata: { name, namespace },
@@ -30,6 +24,7 @@ const KnativeServiceResources: React.FC<KnativeServiceResourceProps> = ({
   const linkUrl = `/search/ns/${namespace}?kind=${PodModel.kind}&q=${encodeURIComponent(
     `serving.knative.dev/${resKind.toLowerCase()}=${name}`,
   )}`;
+  const pluginComponents = usePluginsOverviewTabSection(item);
   return (
     <>
       <PodsOverview
@@ -40,6 +35,10 @@ const KnativeServiceResources: React.FC<KnativeServiceResourceProps> = ({
       />
       <RevisionsOverviewList revisions={revisions} service={obj} />
       <KSRoutesOverviewList ksroutes={ksroutes} resource={obj} />
+      {buildConfigs.length > 0 && <BuildOverview buildConfigs={buildConfigs} />}
+      {pluginComponents.map(({ Component, key }) => (
+        <Component key={key} item={item} />
+      ))}
     </>
   );
 };
