@@ -1,13 +1,9 @@
 export const FLAG_KNATIVE_SERVING_CONFIGURATION = 'KNATIVE_SERVING_CONFIGURATION';
 export const FLAG_KNATIVE_SERVING = 'KNATIVE_SERVING';
+export const FLAG_KNATIVE_EVENTING = 'KNATIVE_EVENTING';
 export const FLAG_KNATIVE_SERVING_REVISION = 'KNATIVE_SERVING_REVISION';
 export const FLAG_KNATIVE_SERVING_ROUTE = 'KNATIVE_SERVING_ROUTE';
 export const FLAG_KNATIVE_SERVING_SERVICE = 'KNATIVE_SERVING_SERVICE';
-export const FLAG_EVENT_SOURCE_CRONJOB = 'EVENT_SOURCE_CRONJOB';
-export const FLAG_EVENT_SOURCE_CONTAINER = 'EVENT_SOURCE_CONTAINER';
-export const FLAG_EVENT_SOURCE_APISERVER = 'EVENT_SOURCE_APISERVER';
-export const FLAG_EVENT_SOURCE_CAMEL = 'EVENT_SOURCE_CAMEL';
-export const FLAG_EVENT_SOURCE_KAFKA = 'EVENT_SOURCE_KAFKA';
 export const KNATIVE_SERVING_LABEL = 'serving.knative.dev/service';
 export const KNATIVE_SERVING_APIGROUP = 'serving.knative.dev';
 export const KNATIVE_EVENT_SOURCE_APIGROUP_DEP = 'sources.eventing.knative.dev';
