@@ -1,25 +1,14 @@
 import * as _ from 'lodash';
-import { List } from 'immutable';
 import {
   asValidationObject,
+  validateEmptyValue,
   ValidationErrorType,
   ValidationObject,
 } from '@console/shared/src/utils/validation';
-import { assureEndsWith, joinGrammaticallyListOfItems, makeSentence } from '@console/shared/src';
 import { VMSettingsField, VMWizardProps, VMWizardTab } from '../../types';
-import {
-  hasVmSettingsChanged,
-  iGetFieldKey,
-  iGetFieldValue,
-  iGetVmSettings,
-  isFieldRequired,
-} from '../../selectors/immutable/vm-settings';
-import {
-  InternalActionType,
-  UpdateOptions,
-  VMSettingsValidationConfig,
-  VmSettingsValidator,
-} from '../types';
+import { hasVmSettingsChanged, iGetVmSettings } from '../../selectors/immutable/vm-settings';
+import { iGetFieldKey, iGetFieldValue } from '../../selectors/immutable/field';
+import { InternalActionType, UpdateOptions, ValidationConfig, Validator } from '../types';
 import { vmWizardInternalActions } from '../internal-actions';
 import {
   validateUserTemplateProvisionSource,
@@ -29,7 +18,7 @@ import {
   VIRTUAL_MACHINE_EXISTS,
   VIRTUAL_MACHINE_TEMPLATE_EXISTS,
 } from '../../../../utils/validations/strings';
-import { getFieldReadableTitle, getFieldTitle } from '../../utils/vm-settings-tab-utils';
+import { getFieldTitle } from '../../utils/renderable-field-utils';
 import { concatImmutableLists, iGet } from '../../../../utils/immutable';
 import {
   checkTabValidityChanged,
@@ -39,14 +28,13 @@ import {
   immutableListToShallowMetadataJS,
 } from '../../selectors/immutable/selectors';
 import { validatePositiveInteger } from '../../../../utils/validations/common';
-import { pluralize } from '../../../../utils/strings';
-import { vmSettingsOrder } from '../initial-state/vm-settings-tab-initial-state';
 import { TemplateValidations } from '../../../../utils/validations/template/template-validations';
 import { combineIntegerValidationResults } from '../../../../utils/validations/template/utils';
-import { getValidationUpdate } from './utils';
+import { getFieldsValidity, getValidationUpdate } from './utils';
 import { getTemplateValidations } from '../../selectors/template';
+import { BinaryUnit, convertToBytes } from '../../../form/size-unit-utils';
 
-const validateVm: VmSettingsValidator = (field, options) => {
+const validateVm: Validator = (field, options) => {
   const { getState, id } = options;
   const state = getState();
 
@@ -72,40 +60,59 @@ const validateVm: VmSettingsValidator = (field, options) => {
   );
 };
 
-const validateUserTemplate: VmSettingsValidator = (field, options) => {
+const validateUserTemplate: Validator = (field, options) => {
   const { getState, id } = options;
   const state = getState();
 
   const userTemplateName = iGetFieldValue(field);
   if (!userTemplateName) {
+    return validateEmptyValue(userTemplateName, {
+      subject: getFieldTitle(iGetFieldKey(field)),
+    });
+  }
+
+  const userTemplatesList = iGetLoadedCommonData(state, id, VMWizardProps.userTemplates);
+  if (!userTemplatesList) {
     return null;
   }
-  const userTemplate = iGetLoadedCommonData(state, id, VMWizardProps.userTemplates, List()).find(
+
+  const userTemplate = userTemplatesList.find(
     (template) => iGetName(template) === userTemplateName,
   );
+  if (!userTemplate) {
+    return asValidationObject(
+      "Can't verify template, template is missing",
+      ValidationErrorType.Error,
+    );
+  }
 
   return validateUserTemplateProvisionSource(userTemplate && userTemplate.toJSON());
 };
 
-export const validateOperatingSystem: VmSettingsValidator = (field) => {
+export const validateOperatingSystem: Validator = (field) => {
   const os = iGetFieldValue(field);
   const guestFullName = iGet(field, 'guestFullName');
 
   if (os || !guestFullName) {
-    return null;
+    return validateEmptyValue(os, {
+      subject: getFieldTitle(iGetFieldKey(field)),
+    });
   }
 
   return asValidationObject(`Select matching for: ${guestFullName}`, ValidationErrorType.Info);
 };
 
-const memoryValidation: VmSettingsValidator = (field, options): ValidationObject => {
-  const memValueGB = iGetFieldValue(field);
-  if (memValueGB == null || memValueGB === '') {
-    return null;
+const memoryValidation: Validator = (field, options): ValidationObject => {
+  const memValue = iGetFieldValue(field);
+  if (memValue == null || memValue === '' || BinaryUnit[memValue]) {
+    return validateEmptyValue(memValue, {
+      subject: getFieldTitle(iGetFieldKey(field)),
+    });
   }
   const { id, getState } = options;
   const state = getState();
-  const memValueBytes = memValueGB * 1024 ** 3;
+  const memValueBytes = convertToBytes(memValue);
+
   const validations = getTemplateValidations(state, id);
   if (validations.length === 0) {
     validations.push(new TemplateValidations()); // add empty validation for positive integer if it is missing one
@@ -123,6 +130,10 @@ const memoryValidation: VmSettingsValidator = (field, options): ValidationObject
     });
   }
 
+  if (memValue.match(/^[0-9.]+B$/)) {
+    return asValidationObject('Memory must be specified at least in KiB units');
+  }
+
   return null;
 };
 
@@ -133,7 +144,7 @@ const asVMSettingsFieldValidator = (
     subject: getFieldTitle(iGetFieldKey(field)),
   });
 
-const validationConfig: VMSettingsValidationConfig = {
+const validationConfig: ValidationConfig = {
   [VMSettingsField.NAME]: {
     detectValueChanges: [VMSettingsField.NAME],
     detectCommonDataChanges: (field, options) => {
@@ -188,59 +199,11 @@ export const validateVmSettings = (options: UpdateOptions) => {
   }
 };
 
-const describeFields = (describe: string, fields: string[]) => {
-  if (fields && fields.length > 0) {
-    const describedFields = _.compact(
-      fields
-        .sort((a, b) => {
-          const aValue = vmSettingsOrder[iGetFieldKey(a)];
-          const bValue = vmSettingsOrder[iGetFieldKey(b)];
-
-          if (bValue == null) {
-            return -1;
-          }
-
-          if (aValue == null) {
-            return 1;
-          }
-
-          return aValue - bValue;
-        })
-        .map((field) => getFieldReadableTitle(iGetFieldKey(field))),
-    );
-    return makeSentence(
-      `${assureEndsWith(describe, ' ')}the following ${pluralize(
-        fields.length,
-        'field',
-      )}: ${joinGrammaticallyListOfItems(describedFields)}.`,
-      false,
-    );
-  }
-  return null;
-};
-
 export const setVmSettingsTabValidity = (options: UpdateOptions) => {
   const { id, dispatch, getState } = options;
   const state = getState();
   const vmSettings = iGetVmSettings(state, id);
-
-  // check if all required fields are defined
-  const emptyRequiredFields = vmSettings
-    .filter(
-      (field) => isFieldRequired(field) && !field.get('skipValidation') && !field.get('value'),
-    )
-    .toArray();
-  let error = describeFields('Please fill in', emptyRequiredFields);
-  const hasAllRequiredFilled = emptyRequiredFields.length === 0;
-
-  // check if fields are valid
-  const invalidFields = vmSettings
-    .filter((field) => field.getIn(['validation', 'type']) === ValidationErrorType.Error)
-    .toArray();
-  if (invalidFields.length > 0) {
-    error = describeFields('Please correct', invalidFields);
-  }
-  const isValid = hasAllRequiredFilled && invalidFields.length === 0;
+  const { hasAllRequiredFilled, isValid, error } = getFieldsValidity(vmSettings);
 
   if (
     checkTabValidityChanged(
