@@ -1,7 +1,8 @@
 import * as React from 'react';
 import * as _ from 'lodash';
 import { Kebab, KebabOption } from '@console/internal/components/utils';
-import { VMWizardStorageType, VMWizardStorageWithWrappers } from '../../types';
+import { RowFunction } from '@console/internal/components/factory';
+import { VMWizardStorage, VMWizardStorageType } from '../../types';
 import { DiskSimpleRow } from '../../../vm-disks/disk-row';
 import {
   VMWizardStorageBundle,
@@ -11,33 +12,36 @@ import {
 import { vmWizardStorageModalEnhanced } from './vm-wizard-storage-modal-enhanced';
 
 const menuActionEdit = (
-  storageWithWrappers: VMWizardStorageWithWrappers,
-  { wizardReduxID, withProgress }: VMWizardStorageRowActionOpts,
+  wizardStorageData: VMWizardStorage,
+  { wizardReduxID, withProgress, isUpdateDisabled }: VMWizardStorageRowActionOpts,
 ): KebabOption => {
   return {
     label: 'Edit',
+    isDisabled: !!isUpdateDisabled,
     callback: () =>
       withProgress(
         vmWizardStorageModalEnhanced({
           blocking: true,
           isEditing: true,
           wizardReduxID,
-          storage: storageWithWrappers,
+          storage: wizardStorageData,
         }).result,
       ),
   };
 };
 
 const menuActionRemove = (
-  { id, type }: VMWizardStorageWithWrappers,
-  { withProgress, removeStorage }: VMWizardStorageRowActionOpts,
+  { id, type }: VMWizardStorage,
+  { withProgress, removeStorage, isDeleteDisabled }: VMWizardStorageRowActionOpts,
 ): KebabOption => ({
   label: 'Delete',
-  isDisabled: [
-    VMWizardStorageType.PROVISION_SOURCE_DISK,
-    VMWizardStorageType.PROVISION_SOURCE_TEMPLATE_DISK,
-    VMWizardStorageType.V2V_VMWARE_IMPORT_TEMP,
-  ].includes(type),
+  isDisabled:
+    isDeleteDisabled ||
+    [
+      VMWizardStorageType.PROVISION_SOURCE_DISK,
+      VMWizardStorageType.PROVISION_SOURCE_TEMPLATE_DISK,
+      VMWizardStorageType.V2V_VMWARE_IMPORT_TEMP,
+    ].includes(type),
   callback: () =>
     withProgress(
       new Promise((resolve) => {
@@ -48,20 +52,24 @@ const menuActionRemove = (
 });
 
 export const getActions = (
-  wizardNetworkData: VMWizardStorageWithWrappers,
+  wizardStorageData: VMWizardStorage,
   opts: VMWizardStorageRowActionOpts,
-) => [menuActionEdit, menuActionRemove].map((a) => a(wizardNetworkData, opts));
+) => [menuActionEdit, menuActionRemove].map((a) => a(wizardStorageData, opts));
 
-export type VMWizardNicRowProps = {
-  obj: VMWizardStorageBundle;
-  customData: VMWizardStorageRowCustomData;
-  index: number;
-  style: object;
-};
-
-export const VmWizardStorageRow: React.FC<VMWizardNicRowProps> = ({
+export const VmWizardStorageRow: RowFunction<
+  VMWizardStorageBundle,
+  VMWizardStorageRowCustomData
+> = ({
   obj: { name, wizardStorageData, ...restData },
-  customData: { isDisabled, columnClasses, removeStorage, withProgress, wizardReduxID },
+  customData: {
+    isDisabled,
+    columnClasses,
+    removeStorage,
+    withProgress,
+    wizardReduxID,
+    isDeleteDisabled,
+    isUpdateDisabled,
+  },
   index,
   style,
 }) => {
@@ -79,7 +87,13 @@ export const VmWizardStorageRow: React.FC<VMWizardNicRowProps> = ({
       style={style}
       actionsComponent={
         <Kebab
-          options={getActions(wizardStorageData, { wizardReduxID, removeStorage, withProgress })}
+          options={getActions(wizardStorageData, {
+            wizardReduxID,
+            removeStorage,
+            withProgress,
+            isDeleteDisabled,
+            isUpdateDisabled,
+          })}
           isDisabled={isDisabled}
           id={`kebab-for-${name}`}
         />
