@@ -8,7 +8,6 @@ import {
   Checkbox,
   FormSelect,
   FormSelectOption,
-  Alert,
 } from '@patternfly/react-core';
 import {
   Firehose,
@@ -22,8 +21,8 @@ import {
   ModalTitle,
   ModalBody,
   ModalComponentProps,
-  ModalFooter,
 } from '@console/internal/components/factory';
+import { ModalFooter } from '../modal/modal-footer';
 import { K8sResourceKind } from '@console/internal/module/k8s';
 import { NamespaceModel, PersistentVolumeClaimModel, ProjectModel } from '@console/internal/models';
 import { getName, getNamespace, ValidationErrorType } from '@console/shared';
@@ -37,7 +36,7 @@ import {
   getVolumeDataVolumeName,
   getVolumePersistentVolumeClaimName,
   getVolumes,
-  isVMRunning,
+  isVMExpectedRunning,
 } from '../../../selectors/vm';
 import { VIRTUAL_MACHINE_EXISTS } from '../../../utils/validations/strings';
 import { Errors } from '../../errors/errors';
@@ -108,6 +107,10 @@ export const CloneVMModal = withHandlePromise((props: CloneVMModalProps) => {
     cancel();
   };
 
+  const vmRunningWarning =
+    isVMExpectedRunning(vm) &&
+    `The VM ${getName(vm)} is still running. It will be powered off while cloning.`;
+
   return (
     <div className="modal-content">
       <ModalTitle>Clone Virtual Machine</ModalTitle>
@@ -132,13 +135,6 @@ export const CloneVMModal = withHandlePromise((props: CloneVMModalProps) => {
             },
           ].filter((err) => err.message)}
         />
-        {isVMRunning(vm) && (
-          <Alert
-            variant="warning"
-            title={`The VM ${getName(vm)} is still running. It will be powered off while cloning.`}
-            className="kubevirt-clone-vm-modal__error-group--end "
-          />
-        )}
         <Form isHorizontal>
           <FormGroup
             label="Name"
@@ -171,16 +167,22 @@ export const CloneVMModal = withHandlePromise((props: CloneVMModalProps) => {
               onChange={(v) => onNamespaceChanged(v)}
               id={asId('namespace')}
             >
-              {getLoadedData(namespaces, []).map((n) => {
-                const namespaceName = getName(n);
-                return (
-                  <FormSelectOption
-                    key={namespaceName}
-                    value={namespaceName}
-                    label={namespaceName}
-                  />
-                );
-              })}
+              {[...getLoadedData(namespaces, [])]
+                .sort((n1, n2) => {
+                  const n1Name = getName(n1);
+                  const n2Name = getName(n2);
+                  return n1Name.localeCompare(n2Name);
+                })
+                .map((n) => {
+                  const namespaceName = getName(n);
+                  return (
+                    <FormSelectOption
+                      key={namespaceName}
+                      value={namespaceName}
+                      label={namespaceName}
+                    />
+                  );
+                })}
             </FormSelect>
           </FormGroup>
           <FormGroup fieldId={asId('start')}>
@@ -202,20 +204,17 @@ export const CloneVMModal = withHandlePromise((props: CloneVMModalProps) => {
           </FormGroup>
         </Form>
       </ModalBody>
-      <ModalFooter inProgress={inProgress} errorMessage={errorMessage}>
-        <button type="button" onClick={onCancelClick} className="btn btn-default">
-          Cancel
-        </button>
-        <button
-          type="button"
-          disabled={!isValid}
-          onClick={submit}
-          className="btn btn-primary"
-          id="confirm-action"
-        >
-          Clone Virtual Machine
-        </button>
-      </ModalFooter>
+      <ModalFooter
+        id="clone-vm"
+        errorMessage={errorMessage}
+        isSimpleError={!!vmRunningWarning && !errorMessage}
+        warningMessage={vmRunningWarning}
+        inProgress={inProgress}
+        isDisabled={!isValid || inProgress}
+        submitButtonText="Clone Virtual Machine"
+        onSubmit={submit}
+        onCancel={onCancelClick}
+      />
     </div>
   );
 });
