@@ -1,8 +1,6 @@
 import * as React from 'react';
 import Dashboard from '@console/shared/src/components/dashboard/Dashboard';
 import DashboardGrid from '@console/shared/src/components/dashboard/DashboardGrid';
-import { K8sResourceKind, PodKind } from '@console/internal/module/k8s';
-import { VMKind, VMIKind } from '../../types';
 import {
   VMDetailsCard,
   VMInventoryCard,
@@ -11,23 +9,43 @@ import {
   VMUtilizationCard,
 } from '../dashboards-page/vm-dashboard';
 import { VMDashboardContext } from './vm-dashboard-context';
-import { asVM, isVMI, isVM } from '../../selectors/vm/vmlike';
+import { asVM } from '../../selectors/vm/vmlike';
+import { VMTabProps } from './types';
+import { getVMStatus } from '../../statuses/vm/vm-status';
+import { isVM, isVMI } from '../../selectors/check-type';
 
 const mainCards = [{ Card: VMStatusCard }, { Card: VMUtilizationCard }];
 const leftCards = [{ Card: VMDetailsCard }, { Card: VMInventoryCard }];
 const rightCards = [{ Card: VMActivityCard }];
 
-export const VMDashboard: React.FC<VMDashboardProps> = (props) => {
-  const { obj: objProp, vm: vmProp, vmi: vmiProp, pods, migrations } = props;
+export const VMDashboard: React.FC<VMTabProps> = (props) => {
+  const {
+    obj: objProp,
+    vm: vmProp,
+    vmis: vmisProp,
+    pods,
+    migrations,
+    dataVolumes,
+    vmImports,
+  } = props;
 
   const vm = asVM(objProp) || (isVM(vmProp) && vmProp);
-  const vmi = (isVMI(objProp) && objProp) || vmiProp;
+  const vmi = (isVMI(objProp) && objProp) || vmisProp[0];
+
+  const vmStatusBundle = getVMStatus({
+    vm,
+    vmi,
+    pods,
+    migrations,
+    dataVolumes,
+    vmImports,
+  });
 
   const context = {
     vm,
     vmi,
     pods,
-    migrations,
+    vmStatusBundle,
   };
 
   return (
@@ -38,11 +56,3 @@ export const VMDashboard: React.FC<VMDashboardProps> = (props) => {
     </VMDashboardContext.Provider>
   );
 };
-
-type VMDashboardProps = {
-  obj?: VMKind;
-  vm?: VMKind;
-  vmi?: VMIKind;
-  pods?: PodKind[];
-  migrations?: K8sResourceKind[];
-};
