@@ -2,4 +2,4 @@ export * from './vm';
 export * from './vm-templates';
 export * from './cdi';
 export * from './namespace';
-export * from './value-enum';
+export * from './object-enum';
