@@ -1,6 +1,6 @@
 /* eslint-disable lines-between-class-members */
 import { getName, getNamespace, K8sEntityMap } from '@console/shared/src';
-import { ValueEnum } from '../value-enum';
+import { ObjectEnum } from '../object-enum';
 import {
   asVM,
   getDataVolumeTemplates,
@@ -22,15 +22,14 @@ type ProvisionSourceDetails = {
   error?: string;
 };
 
-export class ProvisionSource extends ValueEnum<string> {
+export class ProvisionSource extends ObjectEnum<string> {
   static readonly PXE = new ProvisionSource('PXE');
   static readonly CONTAINER = new ProvisionSource('Container');
   static readonly URL = new ProvisionSource('URL');
-  static readonly IMPORT = new ProvisionSource('Import');
   static readonly DISK = new ProvisionSource('Disk');
 
   private static readonly ALL = Object.freeze(
-    ValueEnum.getAllClassEnumProperties<ProvisionSource>(ProvisionSource),
+    ObjectEnum.getAllClassEnumProperties<ProvisionSource>(ProvisionSource),
   );
 
   private static readonly stringMapper = ProvisionSource.ALL.reduce(
@@ -43,9 +42,6 @@ export class ProvisionSource extends ValueEnum<string> {
 
   static getAll = () => ProvisionSource.ALL;
 
-  static fromSerialized = (provisionSource: { value: string }): ProvisionSource =>
-    ProvisionSource.fromString(provisionSource && provisionSource.value);
-
   static fromString = (source: string): ProvisionSource => ProvisionSource.stringMapper[source];
 
   static getProvisionSourceDetails = (
@@ -75,7 +71,7 @@ export class ProvisionSource extends ValueEnum<string> {
           error: 'No Volume has been found.',
         };
       }
-      const volumeWrapper = VolumeWrapper.initialize(volume);
+      const volumeWrapper = new VolumeWrapper(volume);
       let dataVolumeWrapper;
 
       if (volumeWrapper.getType() === VolumeType.DATA_VOLUME) {
@@ -102,7 +98,7 @@ export class ProvisionSource extends ValueEnum<string> {
             error: `Datavolume ${volumeWrapper.getDataVolumeName()} does not exist.`,
           };
         }
-        dataVolumeWrapper = DataVolumeWrapper.initialize(dataVolume);
+        dataVolumeWrapper = new DataVolumeWrapper(dataVolume);
       }
 
       const type = StorageUISource.fromTypes(
