@@ -1,12 +1,13 @@
 import * as _ from 'lodash';
-import { K8sResourceKind } from '@console/internal/module/k8s';
-import { createBasicLookup, getName, getNamespace } from '@console/shared/src';
+import { K8sResourceKind } from '@console/internal/module/k8s/types';
+import { apiVersionForModel } from '@console/internal/module/k8s/k8s';
+import { createBasicLookup, getName, getNamespace, getOwnerReferences } from '@console/shared/src';
 import { FirehoseResult } from '@console/internal/components/utils';
 import { V1Disk } from '../../../types/vm/disk/V1Disk';
 import { V1Volume } from '../../../types/vm/disk/V1Volume';
 import { V1alpha1DataVolume } from '../../../types/vm/disk/V1alpha1DataVolume';
 import { getSimpleName } from '../../../selectors/utils';
-import { VolumeType, DiskType } from '../../../constants/vm/storage';
+import { VolumeType, DiskType, AccessMode, VolumeMode } from '../../../constants/vm/storage';
 import { VMGenericLikeEntityKind } from '../../../types/vmLike';
 import { asVM, getDataVolumeTemplates, isWinToolsImage } from '../../../selectors/vm';
 import { getLoadedData, isLoaded } from '../../../utils';
@@ -17,6 +18,9 @@ import { DataVolumeWrapper } from './data-volume-wrapper';
 import { VolumeWrapper } from './volume-wrapper';
 import { PersistentVolumeClaimWrapper } from './persistent-volume-claim-wrapper';
 import { asVMILikeWrapper } from '../utils/convert';
+import { V1PersistentVolumeClaim } from '../../../types/vm/disk/V1PersistentVolumeClaim';
+import { DataVolumeModel } from '../../../models';
+import { compareOwnerReference } from '@console/shared/src/utils/owner-references';
 
 export class CombinedDisk {
   private readonly dataVolumesLoading: boolean;
@@ -25,6 +29,8 @@ export class CombinedDisk {
 
   private readonly source: StorageUISource;
 
+  readonly id: string;
+
   readonly diskWrapper: DiskWrapper;
 
   readonly volumeWrapper: VolumeWrapper;
@@ -34,6 +40,11 @@ export class CombinedDisk {
   readonly persistentVolumeClaimWrapper?: PersistentVolumeClaimWrapper;
 
   constructor({
+    id,
+    disk,
+    volume,
+    dataVolume,
+    persistentVolumeClaim,
     diskWrapper,
     volumeWrapper,
     dataVolumeWrapper,
@@ -42,24 +53,33 @@ export class CombinedDisk {
     dataVolumesLoading,
     pvcsLoading,
   }: {
-    diskWrapper: DiskWrapper;
-    volumeWrapper: VolumeWrapper;
+    id?: string;
+    disk?: V1Disk;
+    volume?: V1Volume;
+    dataVolume?: V1alpha1DataVolume;
+    persistentVolumeClaim?: V1PersistentVolumeClaim;
+    diskWrapper?: DiskWrapper;
+    volumeWrapper?: VolumeWrapper;
     dataVolumeWrapper?: DataVolumeWrapper;
     persistentVolumeClaimWrapper?: PersistentVolumeClaimWrapper;
     dataVolumesLoading?: boolean;
     pvcsLoading?: boolean;
     isNewPVC?: boolean;
   }) {
-    this.diskWrapper = diskWrapper;
-    this.volumeWrapper = volumeWrapper;
-    this.dataVolumeWrapper = dataVolumeWrapper;
-    this.persistentVolumeClaimWrapper = persistentVolumeClaimWrapper;
+    this.id = id;
+    this.diskWrapper = disk ? new DiskWrapper(disk) : diskWrapper;
+    this.volumeWrapper = volume ? new VolumeWrapper(volume) : volumeWrapper;
+    this.dataVolumeWrapper = dataVolume ? new DataVolumeWrapper(dataVolume) : dataVolumeWrapper;
+    this.persistentVolumeClaimWrapper = persistentVolumeClaim
+      ? new PersistentVolumeClaimWrapper(persistentVolumeClaim)
+      : persistentVolumeClaimWrapper;
     this.dataVolumesLoading = dataVolumesLoading;
     this.pvcsLoading = pvcsLoading;
+
     this.source = StorageUISource.fromTypes(
-      volumeWrapper.getType(),
-      dataVolumeWrapper && dataVolumeWrapper.getType(),
-      !!persistentVolumeClaimWrapper && isNewPVC,
+      this.volumeWrapper?.getType(),
+      this.dataVolumeWrapper?.getType(),
+      !!this.persistentVolumeClaimWrapper && isNewPVC,
     );
   }
 
@@ -69,29 +89,33 @@ export class CombinedDisk {
     if (isEditing) {
       return this.source;
     }
-    return this.diskWrapper.getType() === DiskType.CDROM
+    return this.diskWrapper?.getType() === DiskType.CDROM
       ? StorageUISource.URL
       : StorageUISource.BLANK;
   };
 
   getSourceValue = () => this.source.getValue();
 
-  isEditingSupported = (isTemplate: boolean) => {
-    if (isTemplate) {
-      // plain dataVolume creates dataVolumes on template creation
-      return this.source.isPlainDataVolume(isTemplate) ? this.source.isEditingSupported() : true;
+  isEditingSupported = () => {
+    switch (this.volumeWrapper.getType()) {
+      case VolumeType.DATA_VOLUME:
+        // do not edit already created entities
+        return !(
+          this.dataVolumeWrapper?.getCreationTimestamp() ||
+          this.persistentVolumeClaimWrapper?.getCreationTimestamp()
+        );
+      default:
+        return true;
     }
-
-    return this.source.isEditingSupported();
   };
 
-  getName = () => this.diskWrapper.getName();
+  getName = () => this.diskWrapper?.getName();
 
-  getType = () => this.diskWrapper.getType();
+  getType = () => this.diskWrapper?.getType();
 
-  getTypeValue = () => this.diskWrapper.getTypeValue();
+  getTypeValue = () => this.diskWrapper?.getTypeValue();
 
-  getDiskInterface = () => this.diskWrapper.getReadableDiskBus();
+  getDiskInterface = () => this.diskWrapper?.getReadableDiskBus();
 
   getReadableSize = (): string => {
     let result = this.volumeTypeOperation(
@@ -118,16 +142,27 @@ export class CombinedDisk {
       (dataVolumeWrapper) => dataVolumeWrapper.getStorageClassName(),
     );
 
-  getPVCName = (source?: StorageUISource) => {
-    const resolvedSource = source || this.source;
-    if (resolvedSource === StorageUISource.IMPORT_DISK) {
-      return this.persistentVolumeClaimWrapper && this.persistentVolumeClaimWrapper.getName();
+  getAccessModes = (): AccessMode[] =>
+    this.volumeTypeOperation(
+      (persistentVolumeClaimWrapper) => persistentVolumeClaimWrapper.getAccessModesEnum(),
+      (dataVolumeWrapper) => dataVolumeWrapper.getAccessModesEnum(),
+    );
+
+  getVolumeMode = (): VolumeMode =>
+    this.volumeTypeOperation(
+      (persistentVolumeClaimWrapper) => persistentVolumeClaimWrapper.getVolumeModeEnum(),
+      (dataVolumeWrapper) => dataVolumeWrapper.getVolumeModeEnum(),
+    );
+
+  getPVCNameBySource = (source?: StorageUISource) => {
+    if (source === StorageUISource.IMPORT_DISK) {
+      return this.persistentVolumeClaimWrapper?.getName();
     }
-    if (resolvedSource === StorageUISource.ATTACH_DISK) {
-      return this.volumeWrapper && this.volumeWrapper.getPersistentVolumeClaimName();
+    if (source === StorageUISource.ATTACH_DISK) {
+      return this.volumeWrapper?.getPersistentVolumeClaimName();
     }
-    if (resolvedSource === StorageUISource.ATTACH_CLONED_DISK) {
-      return this.dataVolumeWrapper && this.dataVolumeWrapper.getPesistentVolumeClaimName();
+    if (source === StorageUISource.ATTACH_CLONED_DISK) {
+      return this.dataVolumeWrapper?.getPesistentVolumeClaimName();
     }
 
     return null;
@@ -136,19 +171,19 @@ export class CombinedDisk {
   getContent = () => {
     switch (this.source) {
       case StorageUISource.CONTAINER: {
-        return this.volumeWrapper.getContainerImage();
+        return this.volumeWrapper?.getContainerImage();
       }
       case StorageUISource.URL: {
         return this.dataVolumeWrapper.getURL();
       }
       case StorageUISource.IMPORT_DISK: {
-        return this.getPVCName(this.source);
+        return this.getPVCNameBySource(this.source);
       }
       case StorageUISource.ATTACH_DISK: {
-        return this.getPVCName(this.source);
+        return this.getPVCNameBySource(this.source);
       }
       case StorageUISource.ATTACH_CLONED_DISK: {
-        return this.getPVCName(this.source);
+        return this.getPVCNameBySource(this.source);
       }
       default:
         return null;
@@ -156,7 +191,7 @@ export class CombinedDisk {
   };
 
   getCDROMSourceValue = () =>
-    isWinToolsImage(this.volumeWrapper.getContainerImage())
+    isWinToolsImage(this.volumeWrapper?.getContainerImage())
       ? 'Windows Tools'
       : this.getSourceValue();
 
@@ -166,6 +201,8 @@ export class CombinedDisk {
       this.getReadableSize(),
       this.getDiskInterface(),
       this.getStorageClassName(),
+      this.getVolumeMode(),
+      (this.getAccessModes() || []).length > 0 ? this.getAccessModes().join(', ') : null,
     ]).join(' - ');
   };
 
@@ -175,17 +212,17 @@ export class CombinedDisk {
     ) => any,
     onDataVolumeWrapper: (dataVolumeWrapper: DataVolumeWrapper) => any,
   ) => {
-    const volumeType = this.volumeWrapper.getType();
+    const volumeType = this.volumeWrapper?.getType();
     if (volumeType === VolumeType.PERSISTENT_VOLUME_CLAIM) {
       if (this.persistentVolumeClaimWrapper) {
-        return onPersistentVolumeClaimWrapper(this.persistentVolumeClaimWrapper);
+        return onPersistentVolumeClaimWrapper(this.persistentVolumeClaimWrapper) || null;
       }
       if (this.pvcsLoading) {
         return undefined;
       }
     } else if (volumeType === VolumeType.DATA_VOLUME) {
       if (this.dataVolumeWrapper) {
-        return onDataVolumeWrapper(this.dataVolumeWrapper);
+        return onDataVolumeWrapper(this.dataVolumeWrapper) || null;
       }
       if (this.dataVolumesLoading) {
         return undefined;
@@ -200,6 +237,8 @@ export class CombinedDiskFactory {
 
   private readonly volumes: V1Volume[];
 
+  private readonly dataVolumeTemplates: V1alpha1DataVolume[];
+
   private readonly dataVolumes: V1alpha1DataVolume[];
 
   private readonly pvcs: K8sResourceKind[];
@@ -218,10 +257,8 @@ export class CombinedDiskFactory {
     return new CombinedDiskFactory({
       disks: vmiLikeWrapper?.getDisks() || [],
       volumes: vmiLikeWrapper?.getVolumes() || [],
-      dataVolumes: [
-        ...getLoadedData(datavolumes, []),
-        ...getDataVolumeTemplates(asVM(vmLikeEntity)),
-      ],
+      dataVolumeTemplates: getDataVolumeTemplates(asVM(vmLikeEntity)),
+      dataVolumes: getLoadedData(datavolumes, []),
       pvcs: getLoadedData(pvcs),
       dataVolumesLoading: !isLoaded(datavolumes),
       pvcsLoading: !isLoaded(pvcs),
@@ -233,6 +270,7 @@ export class CombinedDiskFactory {
     disks,
     volumes,
     dataVolumes,
+    dataVolumeTemplates,
     dataVolumesLoading,
     pvcs,
     pvcsLoading,
@@ -240,6 +278,7 @@ export class CombinedDiskFactory {
   }: {
     disks: V1Disk[];
     volumes: V1Volume[];
+    dataVolumeTemplates?: V1alpha1DataVolume[];
     dataVolumes?: V1alpha1DataVolume[];
     dataVolumesLoading?: boolean;
     pvcs?: K8sResourceKind[];
@@ -248,6 +287,7 @@ export class CombinedDiskFactory {
   }) {
     this.disks = disks;
     this.volumes = volumes;
+    this.dataVolumeTemplates = dataVolumeTemplates;
     this.dataVolumes =
       dataVolumes &&
       dataVolumes.filter((dataVolume) => {
@@ -266,27 +306,52 @@ export class CombinedDiskFactory {
 
   getCombinedDisks = (): CombinedDisk[] => {
     const volumeLookup = createBasicLookup(this.volumes, getSimpleName);
+    const datavolumeTemplateLookup = createBasicLookup(this.dataVolumeTemplates, getName);
     const datavolumeLookup = createBasicLookup(this.dataVolumes, getName);
     const pvcLookup = createBasicLookup(this.pvcs, getName);
 
     return this.disks.map((disk) => {
-      const diskWrapper = DiskWrapper.initialize(disk);
+      const diskWrapper = new DiskWrapper(disk);
       const volume = volumeLookup[diskWrapper.getName()];
-      const volumeWrapper = VolumeWrapper.initialize(volume);
-      const dataVolume =
-        volumeWrapper.getType() === VolumeType.DATA_VOLUME
-          ? datavolumeLookup[volumeWrapper.getDataVolumeName()]
-          : undefined;
-      const pvc =
-        volumeWrapper.getType() === VolumeType.PERSISTENT_VOLUME_CLAIM
-          ? pvcLookup[volumeWrapper.getPersistentVolumeClaimName()]
-          : undefined;
+      const volumeWrapper = new VolumeWrapper(volume);
+      let dataVolumeName: string;
+      let dataVolume;
+      let dataVolumeTemplate;
+      let pvc;
+
+      switch (volumeWrapper.getType()) {
+        case VolumeType.DATA_VOLUME:
+          dataVolumeName = volumeWrapper.getDataVolumeName();
+          dataVolumeTemplate = datavolumeTemplateLookup[dataVolumeName];
+          dataVolume = datavolumeLookup[dataVolumeName];
+          if (!dataVolume) {
+            dataVolume = dataVolumeTemplate;
+          }
+
+          if (dataVolume && this.pvcs) {
+            pvc = this.pvcs.find((p) =>
+              getOwnerReferences(p).some((ownerReference) =>
+                compareOwnerReference(ownerReference, {
+                  name: dataVolumeName,
+                  kind: DataVolumeModel.kind,
+                  apiVersion: apiVersionForModel(DataVolumeModel),
+                } as any),
+              ),
+            );
+          }
+          break;
+        case VolumeType.PERSISTENT_VOLUME_CLAIM:
+          pvc = pvcLookup[volumeWrapper.getPersistentVolumeClaimName()];
+          break;
+        default:
+          break;
+      }
 
       return new CombinedDisk({
         diskWrapper,
         volumeWrapper,
-        dataVolumeWrapper: dataVolume && DataVolumeWrapper.initialize(dataVolume),
-        persistentVolumeClaimWrapper: pvc && PersistentVolumeClaimWrapper.initialize(pvc),
+        dataVolumeWrapper: dataVolume && new DataVolumeWrapper(dataVolume),
+        persistentVolumeClaimWrapper: pvc && new PersistentVolumeClaimWrapper(pvc),
         dataVolumesLoading: this.dataVolumesLoading,
         pvcsLoading: this.pvcsLoading,
       });
@@ -297,5 +362,9 @@ export class CombinedDiskFactory {
     new Set(this.disks.map(getSimpleName).filter((n) => n && n !== excludeName));
 
   getUsedDataVolumeNames = (excludeName: string): Set<string> =>
-    new Set(this.dataVolumes.map((dv) => getName(dv)).filter((n) => n && n !== excludeName));
+    new Set(
+      [...this.dataVolumeTemplates, ...this.dataVolumes]
+        .map((dv) => getName(dv))
+        .filter((n) => n && n !== excludeName),
+    );
 }
