@@ -1,8 +1,10 @@
 import * as React from 'react';
 import * as _ from 'lodash';
+import * as virtualMachineIcon from './images/virtual-machine.svg';
 import {
   Plugin,
   ResourceNSNavItem,
+  OverviewCRD,
   ResourceListPage,
   ResourceDetailsPage,
   ModelFeatureFlag,
@@ -17,9 +19,10 @@ import {
   DashboardsOverviewResourceActivity,
 } from '@console/plugin-sdk';
 import { DashboardsStorageCapacityDropdownItem } from '@console/ceph-storage-plugin';
-import { FLAGS } from '@console/shared/src/constants';
 import { TemplateModel, PodModel } from '@console/internal/models';
 import { getName } from '@console/shared/src/selectors/common';
+import { AddAction } from '@console/dev-console/src/extensions/add-actions';
+import { FirehoseResource } from '@console/internal/components/utils';
 import * as models from './models';
 import { VMTemplateYAMLTemplates, VirtualMachineYAMLTemplates } from './models/templates';
 import { getKubevirtHealthState } from './components/dashboards-page/overview-dashboard/health';
@@ -28,11 +31,14 @@ import {
   VMOffGroupIcon,
 } from './components/dashboards-page/overview-dashboard/inventory';
 import kubevirtReducer from './redux';
+import { accessReviewImportVM } from './utils/accessReview-v2v';
+import { diskImportKindMapping } from './components/dashboards-page/overview-dashboard/utils';
 
 import './style.scss';
 
 type ConsumedExtensions =
   | ResourceNSNavItem
+  | OverviewCRD
   | ResourceListPage
   | ResourceDetailsPage
   | ModelFeatureFlag
@@ -45,10 +51,59 @@ type ConsumedExtensions =
   | DashboardsStorageCapacityDropdownItem
   | ReduxReducer
   | ProjectDashboardInventoryItem
-  | DashboardsOverviewResourceActivity;
+  | DashboardsOverviewResourceActivity
+  | AddAction;
 
 export const FLAG_KUBEVIRT = 'KUBEVIRT';
 
+const virtualMachineConfigurations = (namespace: string): FirehoseResource[] => {
+  const virtualMachineResource = [
+    {
+      isList: true,
+      kind: models.VirtualMachineModel.kind,
+      namespace,
+      prop: 'virtualmachines',
+      optional: true,
+    },
+    {
+      isList: true,
+      kind: models.VirtualMachineInstanceModel.kind,
+      namespace,
+      prop: 'virtualmachineinstances',
+      optional: true,
+    },
+    {
+      isList: true,
+      kind: TemplateModel.kind,
+      prop: 'virtualmachinetemplates',
+      selector: {
+        matchLabels: { 'template.kubevirt.io/type': 'base' },
+      },
+      optional: true,
+    },
+    {
+      isList: true,
+      kind: models.VirtualMachineInstanceMigrationModel.kind,
+      namespace,
+      prop: 'migrations',
+      optional: true,
+    },
+    {
+      isList: true,
+      optional: true,
+      kind: models.DataVolumeModel.kind,
+      prop: 'dataVolumes',
+    },
+    {
+      isList: true,
+      optional: true,
+      kind: models.VirtualMachineImportModel.kind,
+      prop: 'vmImports',
+    },
+  ];
+  return virtualMachineResource;
+};
+
 const plugin: Plugin<ConsumedExtensions> = [
   {
     type: 'ModelDefinition',
@@ -63,13 +118,21 @@ const plugin: Plugin<ConsumedExtensions> = [
       flag: FLAG_KUBEVIRT,
     },
   },
+  {
+    type: 'Overview/CRD',
+    properties: {
+      resources: virtualMachineConfigurations,
+      required: FLAG_KUBEVIRT,
+      utils: () => null,
+    },
+  },
   {
     type: 'NavItem/ResourceNS',
     properties: {
       section: 'Workloads',
       componentProps: {
-        name: 'Virtual Machines',
-        resource: models.VirtualMachineModel.plural,
+        name: 'Virtualization',
+        resource: 'virtualization',
       },
       mergeBefore: 'Deployments',
     },
@@ -77,33 +140,6 @@ const plugin: Plugin<ConsumedExtensions> = [
       required: [FLAG_KUBEVIRT],
     },
   },
-  {
-    // NOTE(yaacov): vmtemplates is a template resource with a selector.
-    // 'NavItem/ResourceNS' is used, and not 'NavItem/Href', because it injects
-    // the namespace needed to get the correct link to a resource ( template with selector ) in our case.
-    type: 'NavItem/ResourceNS',
-    properties: {
-      section: 'Workloads',
-      componentProps: {
-        name: 'Virtual Machine Templates',
-        resource: 'vmtemplates',
-      },
-      mergeBefore: 'Deployments',
-    },
-    flags: {
-      required: [FLAG_KUBEVIRT, FLAGS.OPENSHIFT],
-    },
-  },
-  {
-    type: 'Page/Resource/List',
-    properties: {
-      model: models.VirtualMachineModel,
-      loader: () =>
-        import('./components/vms/vm' /* webpackChunkName: "kubevirt" */).then(
-          (m) => m.VirtualMachinesPage,
-        ),
-    },
-  },
   {
     type: 'YAMLTemplate',
     properties: {
@@ -123,7 +159,7 @@ const plugin: Plugin<ConsumedExtensions> = [
     type: 'Page/Route',
     properties: {
       exact: true,
-      path: ['/k8s/ns/:ns/virtualmachines/~new'],
+      path: ['/k8s/ns/:ns/virtualization/~new'],
       loader: () =>
         import('./components/vms/vm-create-yaml' /* webpackChunkName: "kubevirt" */).then(
           (m) => m.VMCreateYAML,
@@ -135,7 +171,7 @@ const plugin: Plugin<ConsumedExtensions> = [
     type: 'Page/Route',
     properties: {
       exact: true,
-      path: ['/k8s/ns/:ns/virtualmachines/~new-wizard'],
+      path: ['/k8s/ns/:ns/virtualization/~new-wizard'],
       loader: () =>
         import(
           './components/create-vm-wizard' /* webpackChunkName: "kubevirt-create-vm-wizard" */
@@ -166,12 +202,11 @@ const plugin: Plugin<ConsumedExtensions> = [
   {
     type: 'Page/Route',
     properties: {
-      exact: true,
-      path: ['/k8s/ns/:ns/vmtemplates/~new'],
+      path: ['/k8s/ns/:ns/virtualization', '/k8s/all-namespaces/virtualization'],
       loader: () =>
-        import(
-          './components/vm-templates/vm-template-create-yaml' /* webpackChunkName: "kubevirt" */
-        ).then((m) => m.CreateVMTemplateYAML),
+        import('./components/vms/virtualization' /* webpackChunkName: "kubevirt" */).then(
+          (m) => m.VirtualizationPage,
+        ),
       required: FLAG_KUBEVIRT,
     },
   },
@@ -179,11 +214,23 @@ const plugin: Plugin<ConsumedExtensions> = [
     type: 'Page/Route',
     properties: {
       exact: true,
-      path: ['/k8s/ns/:ns/vmtemplates/~new-wizard'],
+      path: ['/k8s/ns/:ns/virtualmachines', '/k8s/all-namespaces/virtualmachines'],
       loader: () =>
-        import(
-          './components/create-vm-wizard' /* webpackChunkName: "kubevirt-create-vm-wizard" */
-        ).then((m) => m.CreateVMWizardPage),
+        import('./components/vms/virtualization' /* webpackChunkName: "kubevirt" */).then(
+          (m) => m.RedirectToVirtualizationPage,
+        ),
+      required: FLAG_KUBEVIRT,
+    },
+  },
+  {
+    type: 'Page/Route',
+    properties: {
+      exact: true,
+      path: ['/k8s/ns/:ns/vmtemplates', '/k8s/all-namespaces/vmtemplates'],
+      loader: () =>
+        import('./components/vms/virtualization' /* webpackChunkName: "kubevirt" */).then(
+          (m) => m.RedirectToVirtualizationTemplatePage,
+        ),
       required: FLAG_KUBEVIRT,
     },
   },
@@ -216,33 +263,44 @@ const plugin: Plugin<ConsumedExtensions> = [
       title: 'Virtualization',
       url: `apis/subresources.${models.VirtualMachineModel.apiGroup}/${models.VirtualMachineModel.apiVersion}/healthz`,
       healthHandler: getKubevirtHealthState,
-      required: FLAG_KUBEVIRT,
+    },
+    flags: {
+      required: [FLAG_KUBEVIRT],
     },
   },
   {
     type: 'Dashboards/Overview/Inventory/Item',
     properties: {
-      additionalResources: [
-        {
+      additionalResources: {
+        vmis: {
           isList: true,
           kind: models.VirtualMachineInstanceModel.kind,
-          prop: 'vmis',
         },
-        {
+        pods: {
           isList: true,
           kind: PodModel.kind,
-          prop: 'pods',
         },
-        {
+        migrations: {
           isList: true,
           kind: models.VirtualMachineInstanceMigrationModel.kind,
-          prop: 'migrations',
         },
-      ],
+        dataVolumes: {
+          kind: models.DataVolumeModel.kind,
+          isList: true,
+          optional: true,
+        },
+        vmImports: {
+          isList: true,
+          kind: models.VirtualMachineImportModel.kind,
+          optional: true,
+        },
+      },
       model: models.VirtualMachineModel,
       mapper: getVMStatusGroups,
       useAbbr: true,
-      required: FLAG_KUBEVIRT,
+    },
+    flags: {
+      required: [FLAG_KUBEVIRT],
     },
   },
   {
@@ -250,7 +308,9 @@ const plugin: Plugin<ConsumedExtensions> = [
     properties: {
       id: 'vm-off',
       icon: <VMOffGroupIcon />,
-      required: FLAG_KUBEVIRT,
+    },
+    flags: {
+      required: [FLAG_KUBEVIRT],
     },
   },
   {
@@ -291,11 +351,25 @@ const plugin: Plugin<ConsumedExtensions> = [
           kind: models.VirtualMachineInstanceMigrationModel.kind,
           prop: 'migrations',
         },
+        {
+          isList: true,
+          optional: true,
+          kind: models.DataVolumeModel.kind,
+          prop: 'dataVolumes',
+        },
+        {
+          isList: true,
+          optional: true,
+          kind: models.VirtualMachineImportModel.kind,
+          prop: 'vmImports',
+        },
       ],
       model: models.VirtualMachineModel,
       mapper: getVMStatusGroups,
       useAbbr: true,
-      required: FLAG_KUBEVIRT,
+    },
+    flags: {
+      required: [FLAG_KUBEVIRT],
     },
   },
   {
@@ -308,13 +382,15 @@ const plugin: Plugin<ConsumedExtensions> = [
       },
       isActivity: (resource) =>
         resource?.status?.phase === 'ImportInProgress' &&
-        !!resource?.metadata?.ownerReferences?.[0],
+        Object.keys(diskImportKindMapping).includes(resource?.metadata?.ownerReferences?.[0]?.kind),
       getTimestamp: (resource) => new Date(resource.metadata.creationTimestamp),
       loader: () =>
         import(
           './components/dashboards-page/overview-dashboard/activity' /* webpackChunkName: "kubevirt-activity" */
         ).then((m) => m.DiskImportActivity),
-      required: FLAG_KUBEVIRT,
+    },
+    flags: {
+      required: [FLAG_KUBEVIRT],
     },
   },
   {
@@ -331,7 +407,23 @@ const plugin: Plugin<ConsumedExtensions> = [
         import(
           './components/dashboards-page/overview-dashboard/activity' /* webpackChunkName: "kubevirt-activity" */
         ).then((m) => m.V2VImportActivity),
-      required: FLAG_KUBEVIRT,
+    },
+    flags: {
+      required: [FLAG_KUBEVIRT],
+    },
+  },
+  {
+    type: 'AddAction',
+    flags: {
+      required: [FLAG_KUBEVIRT],
+    },
+    properties: {
+      id: 'import-via-v2v',
+      url: '/k8s/ns/:namespace/virtualization/~new-wizard?mode=import',
+      label: 'Import Virtual Machine',
+      description: 'Import a virtual machine from external hypervisor',
+      icon: virtualMachineIcon,
+      accessReview: accessReviewImportVM,
     },
   },
 ];
