@@ -1,6 +1,9 @@
 import * as _ from 'lodash';
 import { List } from 'immutable';
 
+// ATTENTION: please do not add any new imports here
+//   - it can easily cause cyclic dependencies
+
 export const concatImmutableLists = (...args): List<any> =>
   args.filter((list) => list).reduce((acc, nextArray) => acc.concat(nextArray), List());
 
@@ -21,6 +24,9 @@ export const iFirehoseResultToJS = (immutableValue, isList = true) => {
 export const immutableListToShallowJS = <A = any>(list, defaultValue: A[] = []): A[] =>
   list ? list.toArray().map((p) => p.toJSON()) : defaultValue;
 
+export const immutableListToJS = <A = any>(list, defaultValue: A[] = []): A[] =>
+  list ? list.toArray().map((p) => p.toJS()) : defaultValue;
+
 export const hasTruthyValue = (obj) => !!(obj && !!obj.find((value) => value));
 
 export const iGet = (obj, key: string, defaultValue = undefined) =>
