@@ -7,6 +7,7 @@ export const BY_EGRESS = 'Egress';
 export const PROJECTS = 'Projects';
 export const BUCKET_CLASS = 'Bucket Class';
 export const OCS_NS = 'openshift-storage';
+export const NB_PROVISIONER = 'noobaa.io/obc';
 
 export const CHART_LABELS = {
   [BY_LOGICAL_USAGE]: 'Logical used capacity per account',
@@ -21,6 +22,7 @@ export enum BC_PROVIDERS {
   PVC = 'PVC',
   GCP = 'Google cloud storage',
   AZURE = 'Azure Blob',
+  IBM = 'IBM COS',
 }
 
 export const PROVIDERS_NOOBAA_MAP = {
@@ -29,6 +31,7 @@ export const PROVIDERS_NOOBAA_MAP = {
   [BC_PROVIDERS.AZURE]: 'azureBlob',
   [BC_PROVIDERS.GCP]: 'googleCloudStorage',
   [BC_PROVIDERS.PVC]: 'pvPool',
+  [BC_PROVIDERS.IBM]: 'ibmCos',
 };
 
 export const BUCKET_LABEL_NOOBAA_MAP = {
@@ -36,6 +39,7 @@ export const BUCKET_LABEL_NOOBAA_MAP = {
   [BC_PROVIDERS.S3]: 'targetBucket',
   [BC_PROVIDERS.AZURE]: 'targetBlobContainer',
   [BC_PROVIDERS.GCP]: 'targetBucket',
+  [BC_PROVIDERS.IBM]: 'targetBucket',
 };
 
 export const NOOBAA_TYPE_MAP = {
@@ -44,6 +48,7 @@ export const NOOBAA_TYPE_MAP = {
   [BC_PROVIDERS.AZURE]: 'azure-blob',
   [BC_PROVIDERS.GCP]: 'google-cloud-storage',
   [BC_PROVIDERS.PVC]: 'pv-pool',
+  [BC_PROVIDERS.IBM]: 'ibm-cos',
 };
 
 export const AWS_REGIONS = [
