@@ -12,9 +12,10 @@ import * as crudView from '@console/internal-integration-tests/views/crud.view';
 import * as catalogView from '@console/internal-integration-tests/views/catalog.view';
 import * as catalogPageView from '@console/internal-integration-tests/views/catalog-page.view';
 import * as sidenavView from '@console/internal-integration-tests/views/sidenav.view';
-import * as yamlView from '@console/internal-integration-tests/views/yaml.view';
 import * as operatorView from '../views/operator.view';
 import * as operatorHubView from '../views/operator-hub.view';
+import { click } from '@console/shared/src/test-utils/utils';
+import { NAME_FIELD_ID, formFieldIsPresent } from '../views/descriptors.view';
 
 describe('Interacting with an `AllNamespaces` install mode Operator (Jaeger)', () => {
   const jaegerResources = new Set([
@@ -27,6 +28,7 @@ describe('Interacting with an `AllNamespaces` install mode Operator (Jaeger)', (
   ]);
   const jaegerOperatorName = 'jaeger-operator';
   const jaegerName = 'my-jaeger';
+  const customProviderUID = 'providerType-console-e-2-e-operators';
 
   const catalogNamespace = _.get(browser.params, 'globalCatalogNamespace', 'openshift-marketplace');
   const jaegerTileID = `jaeger-console-e2e-${catalogNamespace}`;
@@ -90,7 +92,7 @@ describe('Interacting with an `AllNamespaces` install mode Operator (Jaeger)', (
   it('displays subscription creation form for selected Operator', async () => {
     await catalogView.categoryTabsPresent();
     await catalogView.categoryTabs.get(0).click();
-    await catalogPageView.clickFilterCheckbox('providerType-custom');
+    await catalogPageView.clickFilterCheckbox(customProviderUID);
     await catalogPageView.catalogTileByID(jaegerTileID).click();
     await browser.wait(until.visibilityOf(operatorHubView.operatorModal));
     await operatorHubView.operatorModalInstallBtn.click();
@@ -123,7 +125,7 @@ describe('Interacting with an `AllNamespaces` install mode Operator (Jaeger)', (
     await operatorHubView.viewInstalledOperator();
     await crudView.isLoaded();
 
-    await browser.wait(until.visibilityOf(operatorView.rowForOperator('Jaeger Tracing')), 30000);
+    await browser.wait(until.visibilityOf(operatorView.rowForOperator('Jaeger Tracing')), 60000);
   });
 
   it('creates Operator `Deployment`', async () => {
@@ -160,16 +162,15 @@ describe('Interacting with an `AllNamespaces` install mode Operator (Jaeger)', (
     );
   });
 
-  it('displays YAML editor for creating a new `Jaeger` instance', async () => {
+  it('displays form editor for creating a new `Jaeger` instance', async () => {
     await browser.wait(until.visibilityOf(element(by.buttonText('Create Jaeger'))));
     await retry(() => element(by.buttonText('Create Jaeger')).click());
-    await yamlView.isLoaded();
-
+    await formFieldIsPresent(NAME_FIELD_ID);
     expect($('.co-create-operand__header').getText()).toContain('Create Jaeger');
   });
 
   it('displays new `Jaeger` that was created from YAML editor', async () => {
-    await $('#save-changes').click();
+    await $('button[type="submit"]').click();
     await crudView.isLoaded();
     await browser.wait(until.visibilityOf(operatorView.operandLink(jaegerName)));
 
@@ -202,6 +203,7 @@ describe('Interacting with an `AllNamespaces` install mode Operator (Jaeger)', (
     await crudView.isLoaded();
 
     await crudView.rowFiltersPresent();
+    await click(crudView.rowFiltersButton);
     jaegerResources.forEach((kind) => {
       expect(crudView.rowFilterFor(kind).isDisplayed()).toBe(true);
     });
@@ -210,7 +212,7 @@ describe('Interacting with an `AllNamespaces` install mode Operator (Jaeger)', (
   it('displays button to uninstall the Operator', async () => {
     await browser.get(`${appHost}/operatorhub/ns/${testName}`);
     await crudView.isLoaded();
-    await catalogPageView.clickFilterCheckbox('providerType-custom');
+    await catalogPageView.clickFilterCheckbox(customProviderUID);
     await catalogPageView.clickFilterCheckbox('installState-installed');
     await catalogPageView.catalogTileByID(jaegerTileID).click();
     await operatorHubView.operatorModalIsLoaded();
