@@ -31,8 +31,8 @@ import {
   TableRow,
   TableData,
   TableProps,
-  TableRowProps,
   MultiListPage,
+  RowFunction,
 } from '@console/internal/components/factory';
 import { ConfigMapModel } from '@console/internal/models';
 import { PopoverStatus } from '@console/shared';
@@ -314,7 +314,7 @@ const getOperatorCount = (
     },
   } as any).length; // Type inferred to prevent Lodash TypeScript error.
 
-const CatalogSourceTableRow: React.FC<CatalogSourceTableRowProps> = ({
+const CatalogSourceTableRow: RowFunction<CatalogSourceTableRowObj> = ({
   obj: {
     availability = '-',
     disabled = false,
@@ -472,6 +472,7 @@ export const CatalogSourceListPage: React.FC<CatalogSourceListPageProps> = (prop
     flatten={(data) => flatten({ operatorHub: props.obj, ...data })}
     ListComponent={CatalogSourceList}
     textFilter="catalog-source-name"
+    hideLabelFilter
     resources={[
       {
         isList: true,
@@ -500,11 +501,6 @@ type CatalogSourceTableRowObj = {
   source?: CatalogSourceKind;
 };
 
-type CatalogSourceTableRowProps = {
-  obj: CatalogSourceTableRowObj;
-  key: string;
-} & TableRowProps;
-
 type DefaultSourceKebabProps = {
   kind: K8sKind;
   operatorHub: OperatorHubKind;
