@@ -3,11 +3,18 @@ import { Link, match as RouterMatch } from 'react-router-dom';
 import * as _ from 'lodash';
 import { connect } from 'react-redux';
 import * as classNames from 'classnames';
-import { sortable } from '@patternfly/react-table';
+import { sortable, wrappable } from '@patternfly/react-table';
 import { Helmet } from 'react-helmet';
 import { AddCircleOIcon } from '@patternfly/react-icons';
-import { Alert, Card, CardBody, CardFooter, CardHeader } from '@patternfly/react-core';
-import * as UIActions from '@console/internal/actions/ui';
+import {
+  Alert,
+  Button,
+  Card,
+  CardBody,
+  CardFooter,
+  CardHeader,
+  Popover,
+} from '@patternfly/react-core';
 import { ALL_NAMESPACES_KEY, Status, WarningStatus, getNamespace, getUID } from '@console/shared';
 import {
   DetailsPage,
@@ -15,6 +22,7 @@ import {
   TableRow,
   TableData,
   MultiListPage,
+  RowFunctionArgs,
 } from '@console/internal/components/factory';
 import { withFallback } from '@console/shared/src/components/error/error-boundary';
 import {
@@ -33,7 +41,6 @@ import {
   Kebab,
   MsgBox,
   navFactory,
-  PageHeading,
   ResourceKebab,
   ResourceLink,
   Timestamp,
@@ -52,6 +59,7 @@ import {
   KebabAction,
 } from '@console/internal/components/utils';
 import { useAccessReview } from '@console/internal/components/utils/rbac';
+import { RootState } from '@console/internal/redux';
 import {
   ClusterServiceVersionModel,
   SubscriptionModel,
@@ -78,52 +86,84 @@ import { operatorGroupFor, operatorNamespaceFor } from './operator-group';
 import { SubscriptionDetails, catalogSourceForSubscription } from './subscription';
 import { ClusterServiceVersionLogo, referenceForProvidedAPI, providedAPIsFor } from './index';
 
+const clusterServiceVersionStateToProps = (state: RootState): ClusterServiceVersionStateProps => {
+  return {
+    activeNamespace: state.UI.get('activeNamespace'),
+  };
+};
+
 const isSubscription = (obj) => referenceFor(obj) === referenceForModel(SubscriptionModel);
 const isCSV = (obj) => referenceFor(obj) === referenceForModel(ClusterServiceVersionModel);
 const isPackageServer = (obj) =>
   obj.metadata.name === 'packageserver' &&
   obj.metadata.namespace === 'openshift-operator-lifecycle-manager';
 
-const tableColumnClasses = [
-  '',
-  '',
-  classNames('pf-m-hidden', 'pf-m-visible-on-sm'),
-  classNames('pf-m-hidden', 'pf-m-visible-on-lg'),
-  classNames('pf-m-hidden', 'pf-m-visible-on-xl'),
-  Kebab.columnClass,
-];
+const nameColumnClass = '';
+const namespaceColumnClass = '';
+const managedNamespacesColumnClass = classNames('pf-m-hidden', 'pf-m-visible-on-sm');
+const statusColumnClass = classNames('pf-m-hidden', 'pf-m-visible-on-lg');
+const lastUpdatedColumnClass = classNames('pf-m-hidden', 'pf-m-visible-on-2xl');
+const providedAPIsColumnClass = classNames('pf-m-hidden', 'pf-m-visible-on-xl');
 
-export const ClusterServiceVersionTableHeader = () => {
-  return [
-    {
-      title: 'Name',
-      sortField: 'metadata.name',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[0] },
-    },
-    {
-      title: 'Namespace',
-      props: { className: tableColumnClasses[1] },
-    },
-    {
-      title: 'Status',
-      props: { className: tableColumnClasses[2] },
-    },
-    {
-      title: 'Deployment',
-      props: { className: tableColumnClasses[3] },
-    },
-    {
-      title: 'Provided APIs',
-      props: { className: tableColumnClasses[4] },
-    },
-    {
-      title: '',
-      props: { className: tableColumnClasses[5] },
-    },
-  ];
+const nameHeader: Header = {
+  title: 'Name',
+  sortField: 'metadata.name',
+  transforms: [sortable],
+  props: { className: nameColumnClass },
 };
 
+const namespaceHeader: Header = {
+  title: 'Namespace',
+  sortFunc: 'getOperatorNamespace',
+  transforms: [sortable],
+  props: { className: namespaceColumnClass },
+};
+
+const managedNamespacesHeader: Header = {
+  title: 'Managed Namespaces',
+  sortFunc: 'formatTargetNamespaces',
+  transforms: [sortable, wrappable],
+  props: { className: managedNamespacesColumnClass },
+};
+
+const statusHeader: Header = {
+  title: 'Status',
+  props: { className: statusColumnClass },
+};
+
+const lastUpdatedHeader: Header = {
+  title: 'Last Updated',
+  props: { className: lastUpdatedColumnClass },
+};
+
+const providedAPIsHeader: Header = {
+  title: 'Provided APIs',
+  props: { className: providedAPIsColumnClass },
+};
+
+const kebabHeader: Header = {
+  title: '',
+  props: { className: Kebab.columnClass },
+};
+
+export const AllProjectsTableHeader = (): Header[] => [
+  nameHeader,
+  namespaceHeader,
+  managedNamespacesHeader,
+  statusHeader,
+  lastUpdatedHeader,
+  providedAPIsHeader,
+  kebabHeader,
+];
+export const SingleProjectTableHeader = (): Header[] => [
+  nameHeader,
+  managedNamespacesHeader,
+  statusHeader,
+  lastUpdatedHeader,
+  providedAPIsHeader,
+  kebabHeader,
+];
+
 const editSubscription = (sub: SubscriptionKind): KebabOption =>
   !_.isNil(sub)
     ? {
@@ -136,7 +176,7 @@ const editSubscription = (sub: SubscriptionKind): KebabOption =>
       }
     : null;
 
-const uninstall = (sub: SubscriptionKind, displayName?: string): KebabOption =>
+const uninstall = (sub: SubscriptionKind, csv?: ClusterServiceVersionKind): KebabOption =>
   !_.isNil(sub)
     ? {
         label: 'Uninstall Operator',
@@ -146,7 +186,7 @@ const uninstall = (sub: SubscriptionKind, displayName?: string): KebabOption =>
             k8sGet,
             k8sPatch,
             subscription: sub,
-            displayName,
+            csv,
           }),
         accessReview: {
           group: SubscriptionModel.apiGroup,
@@ -164,10 +204,7 @@ const menuActionsForCSV = (
 ): KebabAction[] => {
   return _.isEmpty(subscription)
     ? [Kebab.factory.Delete]
-    : [
-        () => editSubscription(subscription),
-        () => uninstall(subscription, _.get(csv, 'spec.displayName')),
-      ];
+    : [() => editSubscription(subscription), () => uninstall(subscription, csv)];
 };
 
 const ClusterServiceVersionStatus: React.FC<ClusterServiceVersionStatusProps> = ({
@@ -205,101 +242,140 @@ const ClusterServiceVersionStatus: React.FC<ClusterServiceVersionStatusProps> =
   ) : null;
 };
 
-export const ClusterServiceVersionTableRow = withFallback<ClusterServiceVersionTableRowProps>(
-  ({ obj, key, subscription, catalogSourceMissing, index, style }) => {
-    const { displayName, provider, version } = _.get(obj, 'spec');
-    const [icon] = _.get(obj, 'spec.icon', []);
-    const deploymentName = _.get(obj, 'spec.install.spec.deployments[0].name');
-    const namespace = getNamespace(obj);
-    const route = resourceObjPath(obj, referenceFor(obj));
-    const uid = getUID(obj);
-    const internalObjects = getInternalObjects(obj);
-    return (
-      <TableRow id={uid} trKey={key} index={index} style={style}>
-        {/* Name */}
-        <TableData className={tableColumnClasses[0]}>
-          <Link
-            to={route}
-            className="co-clusterserviceversion-link"
-            data-test-operator-row={displayName}
-          >
-            <ClusterServiceVersionLogo
-              icon={icon}
-              displayName={displayName}
-              version={version}
-              provider={provider}
-            />
-          </Link>
-        </TableData>
+const ManagedNamespaces: React.FC<ManagedNamespacesProps> = ({ obj }) => {
+  const { 'olm.targetNamespaces': olmTargetNamespaces = '' } = obj.metadata?.annotations || {};
+  const managedNamespaces = olmTargetNamespaces?.split(',') || [];
 
-        {/* Namespace */}
-        <TableData className={tableColumnClasses[1]}>
-          <ResourceLink kind="Namespace" title={namespace} name={namespace} />
-        </TableData>
+  if (managedNamespaces.length === 1 && managedNamespaces[0] === '') {
+    return <>All Namespaces</>;
+  }
 
-        {/* Status */}
-        <TableData className={tableColumnClasses[2]}>
-          <div className="co-clusterserviceversion-row__status">
-            <ClusterServiceVersionStatus
-              catalogSourceMissing={catalogSourceMissing}
-              obj={obj}
-              subscription={subscription}
-            />
-          </div>
-        </TableData>
-
-        {/* Deployment */}
-        <TableData className={tableColumnClasses[3]}>
-          <ResourceLink
-            kind="Deployment"
-            name={deploymentName}
-            namespace={operatorNamespaceFor(obj)}
-            title={deploymentName}
-          />
-        </TableData>
-
-        {/* Provided APIs */}
-        <TableData className={tableColumnClasses[4]}>
-          {_.take(
-            providedAPIsFor(obj).filter((desc) => !isInternalObject(internalObjects, desc.name)),
-            4,
-          ).map((desc) => (
-            <div key={referenceForProvidedAPI(desc)}>
-              <Link to={`${route}/${referenceForProvidedAPI(desc)}`} title={desc.name}>
-                {desc.displayName || desc.kind}
-              </Link>
-            </div>
+  switch (managedNamespaces.length) {
+    case 0:
+      return <span className="text-muted">All Namespaces</span>;
+    case 1:
+      return (
+        <ResourceLink kind="Namespace" title={managedNamespaces[0]} name={managedNamespaces[0]} />
+      );
+    default:
+      return (
+        <Popover
+          headerContent="Managed Namespaces"
+          bodyContent={managedNamespaces.map((namespace) => (
+            <ResourceLink kind="Namespace" title={namespace} name={namespace} />
           ))}
-          {providedAPIsFor(obj).filter((desc) => !isInternalObject(internalObjects, desc.name))
-            .length > 4 && (
-            <Link to={route} title={`View ${providedAPIsFor(obj).length - 4} more...`}>
-              {`View ${providedAPIsFor(obj).length - 4} more...`}
-            </Link>
-          )}
-        </TableData>
+        >
+          <Button variant="link" isInline>
+            {managedNamespaces.length} Namespaces
+          </Button>
+        </Popover>
+      );
+  }
+};
 
-        {/* Kabob */}
-        <TableData className={tableColumnClasses[5]}>
-          <ResourceKebab
-            resource={obj}
-            kind={referenceFor(obj)}
-            actions={menuActionsForCSV(obj, subscription)}
+export const NamespacedClusterServiceVersionTableRow = withFallback<
+  ClusterServiceVersionTableRowProps
+>(({ activeNamespace, obj, rowKey, subscription, catalogSourceMissing, index, style }) => {
+  const { displayName, provider, version } = _.get(obj, 'spec');
+  const { 'olm.operatorNamespace': olmOperatorNamespace = '' } = obj.metadata?.annotations || {};
+  const [icon] = _.get(obj, 'spec.icon', []);
+  const route = resourceObjPath(obj, referenceFor(obj));
+  const uid = getUID(obj);
+  const internalObjects = getInternalObjects(obj);
+  const providedAPIs = providedAPIsFor(obj).filter(
+    (desc) => !isInternalObject(internalObjects, desc.name),
+  );
+
+  return (
+    <TableRow id={uid} trKey={rowKey} index={index} style={style}>
+      {/* Name */}
+      <TableData className={nameColumnClass}>
+        <Link
+          to={route}
+          className="co-clusterserviceversion-link"
+          data-test-operator-row={displayName}
+        >
+          <ClusterServiceVersionLogo
+            icon={icon}
+            displayName={displayName}
+            version={version}
+            provider={provider}
           />
+        </Link>
+      </TableData>
+
+      {/* Operator Namespace */}
+      {activeNamespace === ALL_NAMESPACES_KEY ? (
+        <TableData className={namespaceColumnClass}>
+          <ResourceLink kind="Namespace" title={olmOperatorNamespace} name={olmOperatorNamespace} />
         </TableData>
-      </TableRow>
-    );
-  },
+      ) : null}
+
+      {/* Managed Namespaces */}
+      <TableData className={managedNamespacesColumnClass}>
+        <ManagedNamespaces obj={obj} />
+      </TableData>
+
+      {/* Status */}
+      <TableData className={statusColumnClass}>
+        <div className="co-clusterserviceversion-row__status">
+          <ClusterServiceVersionStatus
+            catalogSourceMissing={catalogSourceMissing}
+            obj={obj}
+            subscription={subscription}
+          />
+        </div>
+      </TableData>
+
+      {/* Last Updated */}
+      <TableData className={lastUpdatedColumnClass}>
+        {obj.status == null ? '-' : <Timestamp timestamp={obj.status.lastUpdateTime} />}
+      </TableData>
+
+      {/* Provided APIs */}
+      <TableData className={providedAPIsColumnClass}>
+        {!_.isEmpty(providedAPIs)
+          ? _.take(providedAPIs, 4).map((desc) => (
+              <div key={referenceForProvidedAPI(desc)}>
+                <Link to={`${route}/${referenceForProvidedAPI(desc)}`} title={desc.name}>
+                  {desc.displayName || desc.kind}
+                </Link>
+              </div>
+            ))
+          : '-'}
+        {providedAPIs.length > 4 && (
+          <Link to={route} title={`View ${providedAPIsFor(obj).length - 4} more...`}>
+            {`View ${providedAPIsFor(obj).length - 4} more...`}
+          </Link>
+        )}
+      </TableData>
+
+      {/* Kebab */}
+      <TableData className={Kebab.columnClass}>
+        <ResourceKebab
+          resource={obj}
+          kind={referenceFor(obj)}
+          actions={menuActionsForCSV(obj, subscription)}
+        />
+      </TableData>
+    </TableRow>
+  );
+});
+
+export const ClusterServiceVersionTableRow = connect(clusterServiceVersionStateToProps)(
+  NamespacedClusterServiceVersionTableRow,
 );
 
-const SubscriptionTableRow: React.FC<SubscriptionTableRowProps> = ({
+const NamespacedSubscriptionTableRow: React.FC<SubscriptionTableRowProps> = ({
+  activeNamespace,
   catalogSourceMissing,
-  key,
+  rowKey,
   obj,
   index,
   style,
 }) => {
   const csvName = _.get(obj, 'spec.name');
-  const menuActions = [Kebab.factory.Edit, () => uninstall(obj, obj.spec.displayName)];
+  const menuActions = [Kebab.factory.Edit, () => uninstall(obj)];
   const namespace = getNamespace(obj);
   const route = resourceObjPath(obj, referenceForModel(SubscriptionModel));
   const subscriptionState = _.get(obj, 'status.state', 'Unknown');
@@ -321,9 +397,9 @@ const SubscriptionTableRow: React.FC<SubscriptionTableRowProps> = ({
   };
 
   return (
-    <TableRow id={uid} trKey={key} index={index} style={style}>
+    <TableRow id={uid} trKey={rowKey} index={index} style={style}>
       {/* Name */}
-      <TableData className={tableColumnClasses[0]}>
+      <TableData className={nameColumnClass}>
         <Link to={route}>
           <ClusterServiceVersionLogo
             icon={null}
@@ -334,35 +410,46 @@ const SubscriptionTableRow: React.FC<SubscriptionTableRowProps> = ({
         </Link>
       </TableData>
 
-      {/* Namespace */}
-      <TableData className={tableColumnClasses[1]}>
-        <ResourceLink kind="Namespace" title={namespace} name={namespace} />
+      {/* Operator Namespace */}
+      {activeNamespace === ALL_NAMESPACES_KEY ? (
+        <TableData className={namespaceColumnClass}>
+          <ResourceLink kind="Namespace" title={namespace} name={namespace} />
+        </TableData>
+      ) : null}
+
+      {/* Managed Namespaces */}
+      <TableData className={managedNamespacesColumnClass}>
+        <span className="text-muted">None</span>
       </TableData>
 
       {/* Status */}
-      <TableData className={tableColumnClasses[3]}>{getStatus()}</TableData>
+      <TableData className={statusColumnClass}>{getStatus()}</TableData>
 
-      {/* Deployment */}
-      <TableData className={tableColumnClasses[2]}>
-        <span className="text-muted">None</span>
+      {/* Last Updated */}
+      <TableData className={lastUpdatedColumnClass}>
+        {obj.status == null ? '-' : <Timestamp timestamp={obj.status.lastUpdated} />}
       </TableData>
 
       {/* Provided APIs */}
-      <TableData className={tableColumnClasses[4]}>
+      <TableData className={providedAPIsColumnClass}>
         <span className="text-muted">None</span>
       </TableData>
 
-      {/* Kabob */}
-      <TableData className={tableColumnClasses[5]}>
+      {/* Kebab */}
+      <TableData className={Kebab.columnClass}>
         <ResourceKebab resource={obj} kind={referenceFor(obj)} actions={menuActions} />
       </TableData>
     </TableRow>
   );
 };
 
+export const SubscriptionTableRow = connect(clusterServiceVersionStateToProps)(
+  NamespacedSubscriptionTableRow,
+);
+
 const InstalledOperatorTableRow: React.FC<InstalledOperatorTableRowProps> = ({
-  catalogSources = [],
   obj,
+  catalogSources = [],
   subscriptions = [],
   ...rest
 }) => {
@@ -394,21 +481,24 @@ const InstalledOperatorTableRow: React.FC<InstalledOperatorTableRowProps> = ({
 
 const NoOperatorsMatchFilterMsg = () => <MsgBox title="No Operators Found" />;
 
-export const ClusterServiceVersionList: React.SFC<ClusterServiceVersionListProps> = ({
+export const NamespacedClusterServiceVersionList: React.SFC<ClusterServiceVersionListProps> = ({
+  activeNamespace,
   subscriptions,
   catalogSources,
+  data,
   ...rest
 }) => {
-  const ns = UIActions.getActiveNamespace();
   const noDataDetail = (
     <>
       <div>
         No Operators are available
-        {ns !== ALL_NAMESPACES_KEY && (
+        {activeNamespace !== ALL_NAMESPACES_KEY && (
           <>
             {' '}
             for project{' '}
-            <span className="co-clusterserviceversion-empty__state__namespace">{ns}</span>
+            <span className="co-clusterserviceversion-empty__state__namespace">
+              {activeNamespace}
+            </span>
           </>
         )}
         .
@@ -420,14 +510,61 @@ export const ClusterServiceVersionList: React.SFC<ClusterServiceVersionListProps
   );
   const NoDataEmptyMsg = () => <MsgBox title="No Operators Found" detail={noDataDetail} />;
 
-  return (
+  const isCopiedCSV = (source, kind) => {
+    return (
+      referenceForModel(ClusterServiceVersionModel) === kind && source.status?.reason === 'Copied'
+    );
+  };
+
+  const removeCopiedCSVs = (operators: (ClusterServiceVersionKind | SubscriptionKind)[]) => {
+    return operators.filter((source) => {
+      const kind = referenceFor(source);
+      if (isSubscription(kind)) {
+        return true;
+      }
+      return !isCopiedCSV(source, kind);
+    });
+  };
+
+  const formatTargetNamespaces = (obj: ClusterServiceVersionKind | SubscriptionKind): string => {
+    if (obj.kind === 'Subscription') {
+      return 'None';
+    }
+
+    const namespaces = obj.metadata.annotations?.['olm.targetNamespaces']?.split(',') || [];
+
+    if (namespaces.length === 1 && namespaces[0] === '') {
+      return 'All Namespaces';
+    }
+
+    switch (namespaces.length) {
+      case 0:
+        return 'All Namespaces';
+      case 1:
+        return namespaces[0];
+      default:
+        return `${namespaces.length} Namespaces`;
+    }
+  };
+  const getOperatorNamespace = (
+    obj: ClusterServiceVersionKind | SubscriptionKind,
+  ): string | null => {
+    const olmOperatorNamespace = obj.metadata?.annotations?.['olm.operatorNamespace'];
+    return olmOperatorNamespace ?? getNamespace(obj);
+  };
+
+  return activeNamespace === ALL_NAMESPACES_KEY ? (
     <Table
+      data={removeCopiedCSVs(data) as any[]}
       {...rest}
       aria-label="Installed Operators"
-      Header={ClusterServiceVersionTableHeader}
-      Row={(rowProps) => (
+      Header={AllProjectsTableHeader}
+      Row={(rowArgs: RowFunctionArgs<ClusterServiceVersionKind | SubscriptionKind>) => (
         <InstalledOperatorTableRow
-          {...rowProps}
+          obj={rowArgs.obj}
+          index={rowArgs.index}
+          rowKey={rowArgs.key}
+          style={rowArgs.style}
           catalogSources={catalogSources.data}
           subscriptions={subscriptions.data}
         />
@@ -435,10 +572,42 @@ export const ClusterServiceVersionList: React.SFC<ClusterServiceVersionListProps
       EmptyMsg={NoOperatorsMatchFilterMsg}
       NoDataEmptyMsg={NoDataEmptyMsg}
       virtualize
+      customSorts={{
+        formatTargetNamespaces,
+        getOperatorNamespace,
+      }}
+    />
+  ) : (
+    <Table
+      data={data}
+      {...rest}
+      aria-label="Installed Operators"
+      Header={SingleProjectTableHeader}
+      Row={(rowArgs: RowFunctionArgs<ClusterServiceVersionKind | SubscriptionKind>) => (
+        <InstalledOperatorTableRow
+          obj={rowArgs.obj}
+          index={rowArgs.index}
+          rowKey={rowArgs.key}
+          style={rowArgs.style}
+          catalogSources={catalogSources.data}
+          subscriptions={subscriptions.data}
+        />
+      )}
+      EmptyMsg={NoOperatorsMatchFilterMsg}
+      NoDataEmptyMsg={NoDataEmptyMsg}
+      virtualize
+      customSorts={{
+        formatTargetNamespaces,
+        getOperatorNamespace,
+      }}
     />
   );
 };
 
+export const ClusterServiceVersionList = connect(clusterServiceVersionStateToProps)(
+  NamespacedClusterServiceVersionList,
+);
+
 export const ClusterServiceVersionsPage: React.FC<ClusterServiceVersionsPageProps> = (props) => {
   const title = 'Installed Operators';
   const helpText = (
@@ -480,7 +649,6 @@ export const ClusterServiceVersionsPage: React.FC<ClusterServiceVersionsPageProp
       <Helmet>
         <title>{title}</title>
       </Helmet>
-      <PageHeading title={title} />
       <MultiListPage
         {...props}
         resources={[
@@ -500,11 +668,11 @@ export const ClusterServiceVersionsPage: React.FC<ClusterServiceVersionsPageProp
             optional: true,
           },
         ]}
+        title={title}
         flatten={flatten}
         namespace={props.namespace}
         ListComponent={ClusterServiceVersionList}
         helpText={helpText}
-        showTitle={false}
       />
     </>
   );
@@ -574,26 +742,20 @@ const crdCardRowStateToProps = ({ k8s }, { crdDescs }) => {
 
 export const CRDCardRow = connect(crdCardRowStateToProps)((props: CRDCardRowProps) => {
   const internalObjects = getInternalObjects(props.csv);
+  const crds = props.crdDescs?.filter(({ name }) => !isInternalObject(internalObjects, name));
   return (
     <div className="co-crd-card-row">
-      {_.isEmpty(props.crdDescs) ? (
+      {_.isEmpty(crds) ? (
         <span className="text-muted">No Kubernetes APIs are being provided by this Operator.</span>
       ) : (
-        props.crdDescs.reduce(
-          (acc, desc) =>
-            !isInternalObject(internalObjects, desc.name)
-              ? [
-                  ...acc,
-                  <CRDCard
-                    key={referenceForProvidedAPI(desc)}
-                    crd={desc}
-                    csv={props.csv}
-                    canCreate={props.createable.includes(referenceForProvidedAPI(desc))}
-                  />,
-                ]
-              : acc,
-          [],
-        )
+        crds.map((crd) => (
+          <CRDCard
+            key={referenceForProvidedAPI(crd)}
+            crd={crd}
+            csv={props.csv}
+            canCreate={props.createable.includes(referenceForProvidedAPI(crd))}
+          />
+        ))
       )}
     </div>
   );
@@ -603,8 +765,10 @@ export const ClusterServiceVersionDetails: React.SFC<ClusterServiceVersionDetail
   props,
 ) => {
   const { spec, metadata, status } = props.obj;
-  const { 'marketplace.openshift.io/support-workflow': marketplaceSupportWorkflow } =
-    metadata.annotations || {};
+  const {
+    'marketplace.openshift.io/support-workflow': marketplaceSupportWorkflow,
+    'olm.targetNamespaces': olmTargetNamespaces = '',
+  } = metadata.annotations || {};
 
   return (
     <>
@@ -687,7 +851,30 @@ export const ClusterServiceVersionDetails: React.SFC<ClusterServiceVersionDetail
         <div className="co-m-pane__body-group">
           <div className="row">
             <div className="col-sm-6">
-              <ResourceSummary resource={props.obj} />
+              <ResourceSummary resource={props.obj}>
+                <dt>
+                  <Popover
+                    headerContent={<div>Managed Namespaces</div>}
+                    bodyContent={<div>Operands in this Namespace are managed by the Operator.</div>}
+                    maxWidth="30rem"
+                  >
+                    <Button variant="plain" className="co-m-pane__details-popover-button">
+                      Managed Namespaces
+                    </Button>
+                  </Popover>
+                </dt>
+                <dd>
+                  {olmTargetNamespaces === '' ? (
+                    'All Namespaces'
+                  ) : (
+                    <ResourceLink
+                      kind="Namespace"
+                      name={props.obj.metadata.namespace}
+                      title={props.obj.metadata.uid}
+                    />
+                  )}
+                </dd>
+              </ResourceSummary>
             </div>
             <div className="col-sm-6">
               <dt>Status</dt>
@@ -790,7 +977,9 @@ export const ClusterServiceVersionsDetailsPage: React.FC<ClusterServiceVersionsD
                 ...acc,
                 {
                   href: referenceForProvidedAPI(desc),
-                  name: desc.displayName || desc.kind,
+                  name: ['Details', 'YAML', 'Subscription', 'Events'].includes(desc.displayName)
+                    ? `${desc.displayName} Operand`
+                    : desc.displayName,
                   component: React.memo(
                     () => (
                       <ProvidedAPIPage
@@ -819,7 +1008,7 @@ export const ClusterServiceVersionsDetailsPage: React.FC<ClusterServiceVersionsD
     return [
       ...(_.isEmpty(subscription)
         ? [Kebab.factory.Delete(model, obj)]
-        : [editSubscription(subscription), uninstall(subscription)]),
+        : [editSubscription(subscription), uninstall(subscription, obj)]),
     ];
   };
 
@@ -894,6 +1083,7 @@ export type ClusterServiceVersionListProps = {
   data: ClusterServiceVersionKind[];
   subscriptions: FirehoseResult<SubscriptionKind[]>;
   catalogSources: FirehoseResult<CatalogSourceKind[]>;
+  activeNamespace?: string;
 };
 
 export type CRDCardProps = {
@@ -921,29 +1111,35 @@ export type ClusterServiceVersionDetailsProps = {
 };
 
 type InstalledOperatorTableRowProps = {
-  catalogSources: CatalogSourceKind[];
-  index: number;
-  key?: string;
   obj: ClusterServiceVersionKind | SubscriptionKind;
+  index: number;
+  rowKey: string;
   style: object;
+  catalogSources: CatalogSourceKind[];
   subscriptions: SubscriptionKind[];
 };
 
 export type ClusterServiceVersionTableRowProps = {
-  catalogSourceMissing: boolean;
-  index: number;
-  key?: string;
   obj: ClusterServiceVersionKind;
+  index: number;
+  rowKey: string;
   style: object;
+  catalogSourceMissing: boolean;
   subscription: SubscriptionKind;
+  activeNamespace?: string;
 };
 
 type SubscriptionTableRowProps = {
-  catalogSourceMissing: boolean;
-  index: number;
-  key?: string;
   obj: SubscriptionKind;
+  index: number;
+  rowKey: string;
   style: object;
+  catalogSourceMissing: boolean;
+  activeNamespace?: string;
+};
+
+type ManagedNamespacesProps = {
+  obj: ClusterServiceVersionKind;
 };
 
 export type CSVSubscriptionProps = {
@@ -954,11 +1150,25 @@ export type CSVSubscriptionProps = {
   subscriptions: SubscriptionKind[];
 };
 
+type ClusterServiceVersionStateProps = {
+  activeNamespace?: string;
+};
+
+type Header = {
+  title: string;
+  sortField?: string;
+  sortFunc?: string;
+  transforms?: any;
+  props: { className: string };
+};
+
 // TODO(alecmerdler): Find Webpack loader/plugin to add `displayName` to React components automagically
 ClusterServiceVersionList.displayName = 'ClusterServiceVersionList';
+NamespacedClusterServiceVersionList.displayName = 'ClusterServiceVersionList';
 ClusterServiceVersionsPage.displayName = 'ClusterServiceVersionsPage';
 ClusterServiceVersionTableRow.displayName = 'ClusterServiceVersionTableRow';
-ClusterServiceVersionTableHeader.displayName = 'ClusterServiceVersionTableHeader';
+SingleProjectTableHeader.displayName = 'SingleProjectClusterServiceVersionTableHeader';
+AllProjectsTableHeader.displayName = 'AllProjectsClusterServiceVersionTableHeader';
 CRDCard.displayName = 'CRDCard';
 ClusterServiceVersionsDetailsPage.displayName = 'ClusterServiceVersionsDetailsPage';
 ClusterServiceVersionDetails.displayName = 'ClusterServiceVersionDetails';
