@@ -1,16 +1,15 @@
 import * as React from 'react';
 import * as _ from 'lodash';
-import { Link } from 'react-router-dom';
 import {
-  K8sResourceKind,
   GroupVersionKind,
   referenceForGroupVersionKind,
   resourceURL,
   referenceFor,
   referenceForModel,
+  K8sKind,
+  K8sResourceKind,
 } from '@console/internal/module/k8s';
-import { ResourceIcon } from '@console/internal/components/utils/resource-icon';
-import { PackageManifestModel, ClusterServiceVersionModel } from '../models';
+import { PackageManifestModel } from '../models';
 import {
   ClusterServiceVersionKind,
   CRDDescription,
@@ -18,14 +17,13 @@ import {
   PackageManifestKind,
   StepResource,
   ClusterServiceVersionIcon,
+  ProvidedAPI,
 } from '../types';
 import * as operatorLogo from '../operator.svg';
 
 export const visibilityLabel = 'olm-visibility';
 
-type ProvidedAPIsFor = (
-  csv: ClusterServiceVersionKind,
-) => (CRDDescription | APIServiceDefinition)[];
+type ProvidedAPIsFor = (csv: ClusterServiceVersionKind) => ProvidedAPI[];
 export const providedAPIsFor: ProvidedAPIsFor = (csv) =>
   _.get(csv, 'spec.customresourcedefinitions.owned', []).concat(
     _.get(csv, 'spec.apiservicedefinitions.owned', []),
@@ -58,19 +56,25 @@ export const providedAPIsForChannel = (pkg: PackageManifestKind) => (channel: st
     ]),
   );
 
-export const iconFor = (pkg: PackageManifestKind) =>
-  resourceURL(PackageManifestModel, {
-    ns: _.get(pkg.status, 'catalogSourceNamespace'),
+export const iconFor = (pkg: PackageManifestKind) => {
+  const defaultChannel = pkg?.status?.defaultChannel
+    ? pkg.status.channels?.find((ch) => ch.name === pkg.status.defaultChannel)
+    : pkg?.status?.channels?.[0];
+  if (!defaultChannel) {
+    return null;
+  }
+
+  return resourceURL(PackageManifestModel, {
+    ns: pkg?.status?.catalogSourceNamespace,
     name: pkg.metadata.name,
     path: 'icon',
     queryParams: {
-      resourceVersion: [
-        pkg.metadata.name,
-        _.get(pkg.status, 'channels[0].name'),
-        _.get(pkg.status, 'channels[0].currentCSV'),
-      ].join('.'),
+      resourceVersion: [pkg.metadata.name, defaultChannel.name, defaultChannel.currentCSV].join(
+        '.',
+      ),
     },
   });
+};
 
 export const ClusterServiceVersionLogo: React.SFC<ClusterServiceVersionLogoProps> = (props) => {
   const { icon, displayName, provider, version } = props;
@@ -86,7 +90,7 @@ export const ClusterServiceVersionLogo: React.SFC<ClusterServiceVersionLogoProps
         <img
           className="co-catalog-item-icon__img co-catalog-item-icon__img--large"
           src={imgSrc}
-          alt={displayName}
+          alt=""
         />
       </div>
       <div className="co-clusterserviceversion-logo__name">
@@ -102,31 +106,35 @@ export const ClusterServiceVersionLogo: React.SFC<ClusterServiceVersionLogoProps
   );
 };
 
-export const OperandLink: React.SFC<OperandLinkProps> = (props) => {
-  const { namespace, name } = props.obj.metadata;
-  const csvName = () =>
-    window.location.pathname
-      .split('/')
-      .find(
-        (part, i, allParts) =>
-          allParts[i - 1] === referenceForModel(ClusterServiceVersionModel) ||
-          allParts[i - 1] === ClusterServiceVersionModel.plural,
-      );
-
-  const reference = referenceFor(props.obj);
-  const to = namespace
-    ? `/k8s/ns/${namespace}/${ClusterServiceVersionModel.plural}/${csvName()}/${reference}/${name}`
-    : `/k8s/cluster/${reference}/${name}`;
-  return (
-    <span className="co-resource-item">
-      <ResourceIcon kind={referenceFor(props.obj)} />
-      <Link to={to} className="co-resource-item__resource-name" data-test-operand-link={name}>
-        {name}
-      </Link>
-    </span>
+export const providedAPIForModel = (csv: ClusterServiceVersionKind, model: K8sKind): ProvidedAPI =>
+  _.find<ProvidedAPI>(
+    providedAPIsFor(csv),
+    (crd) => referenceForProvidedAPI(crd) === referenceForModel(model),
   );
+
+export const parseALMExamples = (csv: ClusterServiceVersionKind) => {
+  try {
+    return JSON.parse(csv?.metadata?.annotations?.['alm-examples'] ?? '[]');
+  } catch (e) {
+    // eslint-disable-next-line no-console
+    console.warn('Unable to parse ALM expamples\n', e);
+    return [];
+  }
 };
 
+export const exampleForModel = (csv: ClusterServiceVersionKind, model: K8sKind) =>
+  _.defaultsDeep(
+    {},
+    {
+      kind: model.kind,
+      apiVersion: `${model.apiGroup}/${model.apiVersion}`,
+    },
+    _.find(
+      parseALMExamples(csv),
+      (s: K8sResourceKind) => referenceFor(s) === referenceForModel(model),
+    ),
+  );
+
 export type ClusterServiceVersionLogoProps = {
   displayName: string;
   icon: ClusterServiceVersionIcon | string;
@@ -134,9 +142,4 @@ export type ClusterServiceVersionLogoProps = {
   version?: string;
 };
 
-export type OperandLinkProps = {
-  obj: K8sResourceKind;
-};
-
-OperandLink.displayName = 'OperandLink';
 ClusterServiceVersionLogo.displayName = 'ClusterServiceVersionLogo';
