@@ -14,7 +14,7 @@ import {
 import { K8sKind, K8sResourceKind } from '@console/internal/module/k8s';
 import { getActiveNamespace } from '@console/internal/actions/ui';
 import { YellowExclamationTriangleIcon } from '@console/shared';
-import { SubscriptionKind } from '../../types';
+import { ClusterServiceVersionKind, SubscriptionKind } from '../../types';
 import { ClusterServiceVersionModel, SubscriptionModel } from '../../models';
 
 export const UninstallOperatorModal = withHandlePromise((props: UninstallOperatorModalProps) => {
@@ -58,7 +58,7 @@ export const UninstallOperatorModal = withHandlePromise((props: UninstallOperato
       .catch(_.noop);
   };
 
-  const name = props.displayName || props.subscription.spec.name;
+  const name = _.get(props.csv, 'spec.displayName') || props.subscription.spec.name;
   const context =
     props.subscription.metadata.namespace === 'openshift-operators' ? (
       <strong>all namespaces</strong>
@@ -67,14 +67,25 @@ export const UninstallOperatorModal = withHandlePromise((props: UninstallOperato
         namespace <strong>{props.subscription.metadata.namespace}</strong>
       </>
     );
+  const uninstallMessage =
+    props.csv?.metadata?.annotations['operator.openshift.io/uninstall-message'];
+
   return (
     <form onSubmit={submit} name="form" className="modal-content co-catalog-install-modal">
       <ModalTitle className="modal-header">
         <YellowExclamationTriangleIcon className="co-icon-space-r" /> Uninstall Operator?
       </ModalTitle>
       <ModalBody>
-        This will remove operator <strong>{name}</strong> from {context}. Your application will keep
-        running, but it will no longer receive updates or configuration changes.
+        This will remove operator <strong>{name}</strong> from {context}. Removing the operator will
+        not remove any of its custom resource definitions or managed resources. If your operator has
+        deployed applications on the cluster or configured off-cluster resources, these will
+        continue to run and need to be cleaned up manually.
+        {uninstallMessage && (
+          <>
+            <h2>Message from operator developer</h2>
+            <p>{uninstallMessage}</p>
+          </>
+        )}
       </ModalBody>
       <ModalSubmitFooter
         inProgress={props.inProgress}
@@ -103,7 +114,7 @@ export type UninstallOperatorModalProps = {
     data: { op: string; path: string; value: any }[],
   ) => Promise<any>;
   subscription: SubscriptionKind;
-  displayName?: string;
+  csv?: ClusterServiceVersionKind;
 };
 
 UninstallOperatorModal.displayName = 'UninstallOperatorModal';
