@@ -24,7 +24,13 @@ import * as operatorLogo from '@console/internal/imgs/operator.svg';
 import { SubscriptionModel } from '../../models';
 import { OperatorHubItemDetails } from './operator-hub-item-details';
 import { communityOperatorWarningModal } from './operator-hub-community-provider-modal';
-import { OperatorHubItem, InstalledState, ProviderType, CapabilityLevel } from './index';
+import {
+  OperatorHubItem,
+  InstalledState,
+  ProviderType,
+  CapabilityLevel,
+  InfraFeatures,
+} from './index';
 
 const osBaseLabel = 'operatorframework.io/os.';
 const targetGOOSLabel = window.SERVER_FLAGS.GOOS ? `${osBaseLabel}${window.SERVER_FLAGS.GOOS}` : '';
@@ -83,17 +89,23 @@ const badge = (text: string) => (
 /**
  * Filter property white list
  */
-const operatorHubFilterGroups = ['providerType', 'provider', 'installState', 'capabilityLevel'];
+const operatorHubFilterGroups = [
+  'providerType',
+  'provider',
+  'installState',
+  'capabilityLevel',
+  'infraFeatures',
+];
 
 const operatorHubFilterMap = {
   providerType: 'Provider Type',
   provider: 'Provider',
   installState: 'Install State',
   capabilityLevel: 'Capability Level',
+  infraFeatures: 'Infrastructure Features',
 };
 
 const COMMUNITY_PROVIDER_TYPE = 'Community';
-const CUSTOM_PROVIDER_TYPE = 'Custom';
 const MARKETPLACE_PROVIDER_TYPE = 'Marketplace';
 
 const ignoredProviderTails = [', Inc.', ', Inc', ' Inc.', ' Inc', ', LLC', ' LLC'];
@@ -157,10 +169,8 @@ const providerTypeSort = (provider) => {
       return 2;
     case ProviderType.Marketplace:
       return 3;
-    case ProviderType.Custom:
-      return 4;
     default:
-      return 5;
+      return 4;
   }
 };
 
@@ -190,6 +200,19 @@ const capabilityLevelSort = (provider) => {
   }
 };
 
+const infraFeaturesSort = (infrastructure) => {
+  switch (infrastructure.value) {
+    case InfraFeatures.Disconnected:
+      return 0;
+    case InfraFeatures.Proxy:
+      return 1;
+    case InfraFeatures.FipsMode:
+      return 2;
+    default:
+      return 3;
+  }
+};
+
 const sortFilterValues = (values, field) => {
   let sorter: any = ['value'];
 
@@ -198,7 +221,7 @@ const sortFilterValues = (values, field) => {
   }
 
   if (field === 'providerType') {
-    sorter = providerTypeSort;
+    return _.sortBy(values, [providerTypeSort, 'value']);
   }
 
   if (field === 'installState') {
@@ -209,6 +232,10 @@ const sortFilterValues = (values, field) => {
     sorter = capabilityLevelSort;
   }
 
+  if (field === 'infraFeatures') {
+    sorter = infraFeaturesSort;
+  }
+
   return _.sortBy(values, sorter);
 };
 
@@ -238,7 +265,7 @@ const determineAvailableFilters = (initialFilters, items, filterGroups) => {
         value = getProviderValue(value);
         synonyms = _.map(ignoredProviderTails, (tail) => `${value}${tail}`);
       }
-      if (value !== undefined) {
+      if (value !== undefined && !Array.isArray(value)) {
         if (!_.some(values, { value })) {
           values.push({
             label: value,
@@ -248,6 +275,19 @@ const determineAvailableFilters = (initialFilters, items, filterGroups) => {
           });
         }
       }
+
+      if (Array.isArray(value)) {
+        _.each(value, (v) => {
+          if (!_.some(values, { v })) {
+            values.push({
+              label: v,
+              synonyms,
+              value: v,
+              active: false,
+            });
+          }
+        });
+      }
     });
 
     _.forEach(sortFilterValues(values, field), (nextValue: any) =>
@@ -340,11 +380,7 @@ export const OperatorHubTileView: React.FC<OperatorHubTileViewProps> = (props) =
 
     const { uid, name, imgUrl, provider, description, installed } = item;
     const vendor = provider ? `provided by ${provider}` : null;
-    const badges = [
-      COMMUNITY_PROVIDER_TYPE,
-      CUSTOM_PROVIDER_TYPE,
-      MARKETPLACE_PROVIDER_TYPE,
-    ].includes(item.providerType)
+    const badges = [COMMUNITY_PROVIDER_TYPE, MARKETPLACE_PROVIDER_TYPE].includes(item.providerType)
       ? [badge(item.providerType)]
       : [];
     const icon = (
@@ -367,7 +403,6 @@ export const OperatorHubTileView: React.FC<OperatorHubTileViewProps> = (props) =
         vendor={vendor}
         description={description}
         onClick={() => openOverlay(item)}
-        maxDescriptionLength={-1}
         footer={
           installed ? (
             <span>
@@ -422,6 +457,7 @@ export const OperatorHubTileView: React.FC<OperatorHubTileViewProps> = (props) =
       {detailsItem && (
         <Modal
           className="co-catalog-page__overlay co-catalog-page__overlay--right"
+          data-test-id="operator-modal-box"
           header={
             <>
               <CatalogItemHeader
@@ -429,6 +465,7 @@ export const OperatorHubTileView: React.FC<OperatorHubTileViewProps> = (props) =
                 iconImg={detailsItem.imgUrl}
                 title={detailsItem.name}
                 vendor={`${detailsItem.version} provided by ${detailsItem.provider}`}
+                data-test-id="operator-modal-header"
               />
               <div className="co-catalog-page__overlay-actions">
                 {detailsItem.marketplaceRemoteWorkflow && (
@@ -453,6 +490,7 @@ export const OperatorHubTileView: React.FC<OperatorHubTileViewProps> = (props) =
                       { 'pf-m-primary': !detailsItem.marketplaceRemoteWorkflow },
                       'co-catalog-page__overlay-action',
                     )}
+                    data-test-id="operator-install-btn"
                     to={createLink}
                   >
                     Install
@@ -460,6 +498,7 @@ export const OperatorHubTileView: React.FC<OperatorHubTileViewProps> = (props) =
                 ) : (
                   <Button
                     className="co-catalog-page__overlay-action"
+                    data-test-id="operator-uninstall-btn"
                     isDisabled={!detailsItem.installed}
                     onClick={() => history.push(uninstallLink())}
                     variant="secondary"
