@@ -53,6 +53,7 @@ import {
 } from '../index';
 import { installedFor, supports, providedAPIsFor, isGlobal } from '../operator-group';
 import { CRDCard } from '../clusterserviceversion';
+import { getInternalObjects, isInternalObject } from '../../utils';
 
 export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> = (props) => {
   const [targetNamespace, setTargetNamespace] = React.useState(null);
@@ -94,6 +95,7 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
     currentCSVDesc.annotations?.['operatorframework.io/suggested-namespace'];
   const operatorRequestsMonitoring =
     currentCSVDesc.annotations?.['operatorframework.io/cluster-monitoring'] === 'true';
+  const internalObjects = getInternalObjects(currentCSVDesc, 'annotations');
 
   const globalNS =
     (props.operatorGroup?.data || ([] as OperatorGroupKind[])).find(
@@ -344,8 +346,8 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
         >
           The operator group in the {selectedTargetNamespace} namespace does not support the
           {selectedInstallMode === InstallModeType.InstallModeTypeAllNamespaces
-            ? 'global'
-            : 'single namespace'}
+            ? ' global '
+            : ' single namespace '}
           installation mode.
         </Alert>
       )) ||
@@ -384,17 +386,26 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
   const showMonitoringCheckbox =
     operatorRequestsMonitoring && _.startsWith(selectedTargetNamespace, 'openshift-');
 
-  const createNamespaceDetails = isSuggestedNamespaceSelected && !suggestedNamespaceExists && (
+  const suggestedNamespaceDetails = isSuggestedNamespaceSelected && (
     <>
       <Alert
         isInline
         className="co-alert co-alert--scrollable"
-        variant="info"
-        title="Namespace creation"
+        variant={suggestedNamespaceExists ? 'warning' : 'info'}
+        title={suggestedNamespaceExists ? 'Namespace already exists' : 'Namespace creation'}
       >
-        Namespace <b>{suggestedNamespace}</b> does not exist and will be created.
+        {suggestedNamespaceExists ? (
+          <>
+            Namespace <b>{suggestedNamespace}</b> already exists and will be used. Other users can
+            already have access to this namespace.
+          </>
+        ) : (
+          <>
+            Namespace <b>{suggestedNamespace}</b> does not exist and will be created.
+          </>
+        )}
       </Alert>
-      {showMonitoringCheckbox && (
+      {showMonitoringCheckbox && !suggestedNamespaceExists && (
         <div className="co-form-subsection">
           <Checkbox
             id="enable-monitoring-checkbox"
@@ -451,7 +462,7 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
           }}
         />
       </div>
-      {createNamespaceDetails}
+      {suggestedNamespaceDetails}
     </>
   );
 
@@ -476,7 +487,7 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
         <ResourceIcon kind="Project" />
         <b>{suggestedNamespace}</b>
       </RadioInput>
-      {useSuggestedNSForSingleInstallMode && createNamespaceDetails}
+      {useSuggestedNSForSingleInstallMode && suggestedNamespaceDetails}
       <RadioInput
         onChange={() => {
           setUseSuggestedNSForSingleInstallMode(false);
@@ -496,10 +507,29 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
     </div>
   );
 
+  const providedAPIs = providedAPIsForChannel(props.packageManifest.data[0])(
+    selectedUpdateChannel,
+  ).filter((item) => !isInternalObject(internalObjects, item.name));
+
   return (
     <div className="row">
       <div className="col-xs-6">
         <>
+          <div className="form-group">
+            <Tooltip content="The channel to track and receive the updates from.">
+              <h5 className="co-required">Update Channel</h5>
+            </Tooltip>
+            <RadioGroup
+              currentValue={selectedUpdateChannel}
+              items={channels.map((ch) => ({ value: ch.name, title: ch.name }))}
+              onChange={(e) => {
+                setUpdateChannel(e.currentTarget.value);
+                setInstallMode(null);
+                setTargetNamespace(null);
+                setCannotResolve(false);
+              }}
+            />
+          </div>
           <div className="form-group">
             <h5 className="co-required">Installation Mode</h5>
             <div>
@@ -551,19 +581,6 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
             {selectedInstallMode === InstallModeType.InstallModeTypeOwnNamespace &&
               singleNamespaceInstallMode}
           </div>
-          <div className="form-group">
-            <Tooltip content="The channel to track and receive the updates from.">
-              <h5 className="co-required">Update Channel</h5>
-            </Tooltip>
-            <RadioGroup
-              currentValue={selectedUpdateChannel}
-              items={channels.map((ch) => ({ value: ch.name, title: ch.name }))}
-              onChange={(e) => {
-                setUpdateChannel(e.currentTarget.value);
-                setInstallMode(null);
-              }}
-            />
-          </div>
           <div className="form-group">
             <Tooltip content="The strategy to determine either manual or automatic updates.">
               <h5 className="co-required">Approval Strategy</h5>
@@ -582,7 +599,7 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
         {formError()}
         <ActionGroup className="pf-c-form">
           <Button onClick={() => submit()} isDisabled={formValid()} variant="primary">
-            Subscribe
+            Install
           </Button>
           <Button variant="secondary" onClick={() => history.push('/operatorhub')}>
             Cancel
@@ -597,14 +614,10 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
         />
         <h4>Provided APIs</h4>
         <div className="co-crd-card-row">
-          {_.isEmpty(
-            providedAPIsForChannel(props.packageManifest.data[0])(selectedUpdateChannel),
-          ) ? (
+          {!providedAPIs.length ? (
             <span className="text-muted">No Kubernetes APIs are provided by this Operator.</span>
           ) : (
-            providedAPIsForChannel(props.packageManifest.data[0])(
-              selectedUpdateChannel,
-            ).map((api) => (
+            providedAPIs.map((api) => (
               <CRDCard key={referenceForProvidedAPI(api)} canCreate={false} crd={api} csv={null} />
             ))
           )}
@@ -630,16 +643,16 @@ export const OperatorHubSubscribePage: React.SFC<OperatorHubSubscribePageProps>
   return (
     <>
       <Helmet>
-        <title>OperatorHub Subscription</title>
+        <title>Operator Installation</title>
       </Helmet>
       <div className="co-m-nav-title co-m-nav-title--breadcrumbs">
         <BreadCrumbs
           breadcrumbs={[
             { name: 'OperatorHub', path: `/operatorhub?${search.toString()}` },
-            { name: 'Operator Subscription', path: props.match.url },
+            { name: 'Operator Installation', path: props.match.url },
           ]}
         />
-        <h1 className="co-m-pane__heading">Create Operator Subscription</h1>
+        <h1 className="co-m-pane__heading">Install Operator</h1>
         <p className="co-help-text">
           Install your Operator by subscribing to one of the update channels to keep the Operator up
           to date. The strategy determines either manual or automatic updates.
