@@ -1,7 +1,7 @@
-import { Padding, Translatable } from './types';
+import { Padding, Translatable, IRect } from './types';
 import Point from './Point';
 
-export default class Rect implements Translatable {
+export default class Rect implements Translatable, IRect {
   static readonly EMPTY = new Rect();
 
   width: number = 0;
@@ -22,7 +22,7 @@ export default class Rect implements Translatable {
     return Rect.SINGLETON;
   }
 
-  static fromRect(rect: Rect): Rect {
+  static fromRect(rect: IRect): Rect {
     return new Rect(rect.x, rect.y, rect.width, rect.height);
   }
 
@@ -37,10 +37,6 @@ export default class Rect implements Translatable {
     return this.width <= 0 || this.height <= 0;
   }
 
-  getLocation(): Point {
-    return new Point(this.x, this.y);
-  }
-
   setLocation(x: number, y: number): Rect {
     this.x = x;
     this.y = y;
@@ -104,7 +100,7 @@ export default class Rect implements Translatable {
     return this;
   }
 
-  expand(v: number, h: number): Rect {
+  expand(h: number, v: number): Rect {
     this.y -= v;
     this.height += v * 2;
     this.x -= h;
@@ -122,7 +118,7 @@ export default class Rect implements Translatable {
       } else if (padding.length === 1) {
         this.expand(padding[0], padding[0]);
       } else if (padding.length === 2) {
-        this.expand(padding[0], padding[1]);
+        this.expand(padding[1], padding[0]);
       } else if (padding.length === 3) {
         this.y -= padding[0];
         this.height += padding[0] + padding[2];
@@ -149,7 +145,7 @@ export default class Rect implements Translatable {
     return Rect.fromRect(this);
   }
 
-  equals(r: Rect) {
+  equals(r: IRect) {
     return r.x === this.x && r.y === this.y && r.width === this.width && r.height === this.height;
   }
 }
