@@ -4,7 +4,7 @@ import * as classNames from 'classnames';
 import { sortable } from '@patternfly/react-table';
 import { K8sResourceKind, K8sResourceKindReference, referenceFor } from '../module/k8s';
 import { startBuild } from '../module/k8s/builds';
-import { DetailsPage, ListPage, Table, TableRow, TableData } from './factory';
+import { DetailsPage, ListPage, Table, TableRow, TableData, RowFunction } from './factory';
 import { errorModal } from './modals';
 import {
   BuildHooks,
@@ -19,6 +19,7 @@ import {
   resourceObjPath,
   ResourceSummary,
   SectionHeading,
+  Timestamp,
   WebhookTriggers,
 } from './utils';
 import {
@@ -27,7 +28,6 @@ import {
   BuildStrategyType,
   PipelineBuildStrategyAlert,
 } from './build';
-import { fromNow } from './utils/datetime';
 import { ResourceEventStream } from './events';
 import { BuildConfigModel } from '../models';
 
@@ -146,7 +146,7 @@ const BuildConfigsTableHeader = () => {
 };
 BuildConfigsTableHeader.displayName = 'BuildConfigsTableHeader';
 
-const BuildConfigsTableRow: React.FC<BuildConfigsTableRowProps> = ({ obj, index, key, style }) => {
+const BuildConfigsTableRow: RowFunction<K8sResourceKind> = ({ obj, index, key, style }) => {
   return (
     <TableRow id={obj.metadata.uid} index={index} trKey={key} style={style}>
       <TableData className={tableColumnClasses[0]}>
@@ -164,7 +164,7 @@ const BuildConfigsTableRow: React.FC<BuildConfigsTableRowProps> = ({ obj, index,
         <LabelList kind={BuildConfigsReference} labels={obj.metadata.labels} />
       </TableData>
       <TableData className={tableColumnClasses[3]}>
-        {fromNow(obj.metadata.creationTimestamp)}
+        <Timestamp timestamp={obj.metadata.creationTimestamp} />
       </TableData>
       <TableData className={tableColumnClasses[4]}>
         <ResourceKebab actions={menuActions} kind={BuildConfigsReference} resource={obj} />
@@ -172,13 +172,6 @@ const BuildConfigsTableRow: React.FC<BuildConfigsTableRowProps> = ({ obj, index,
     </TableRow>
   );
 };
-BuildConfigsTableRow.displayName = 'BuildConfigsTableRow';
-type BuildConfigsTableRowProps = {
-  obj: K8sResourceKind;
-  index: number;
-  key?: string;
-  style: object;
-};
 
 const buildStrategy = (buildConfig: K8sResourceKind): BuildStrategyType =>
   buildConfig.spec.strategy.type;
@@ -191,8 +184,8 @@ const allStrategies = [
 ];
 const filters = [
   {
+    filterGroupName: 'Build Strategy',
     type: 'build-strategy',
-    selected: allStrategies,
     reducer: buildStrategy,
     items: _.map(allStrategies, (strategy) => ({
       id: strategy,
