@@ -6,7 +6,7 @@ import { ActionGroup, Button } from '@patternfly/react-core';
 import { SecretModel, ConfigMapModel } from '../../models';
 import { IdentityProvider, k8sCreate, K8sResourceKind, OAuthKind } from '../../module/k8s';
 import { ButtonBar, PromiseComponent, history, AsyncComponent } from '../utils';
-import { addIDP, getOAuthResource, redirectToOAuthPage } from './';
+import { addIDP, getOAuthResource, redirectToOAuthPage, mockNames } from './';
 import { IDPNameInput } from './idp-name-input';
 import { IDPCAFileInput } from './idp-cafile-input';
 
@@ -75,7 +75,12 @@ export class AddBasicAuthPage extends PromiseComponent<{}, AddBasicAuthPageState
     return this.handlePromise(k8sCreate(ConfigMapModel, ca));
   }
 
-  addBasicAuthIDP(oauth: OAuthKind, secretName: string, caName: string): Promise<K8sResourceKind> {
+  addBasicAuthIDP(
+    oauth: OAuthKind,
+    secretName: string,
+    caName: string,
+    dryRun?: boolean,
+  ): Promise<K8sResourceKind> {
     const { name, url } = this.state;
     const idp: IdentityProvider = {
       name,
@@ -101,7 +106,7 @@ export class AddBasicAuthPage extends PromiseComponent<{}, AddBasicAuthPageState
       };
     }
 
-    return this.handlePromise(addIDP(oauth, idp));
+    return this.handlePromise(addIDP(oauth, idp, dryRun));
   }
 
   submit: React.FormEventHandler<HTMLFormElement> = (e) => {
@@ -115,15 +120,23 @@ export class AddBasicAuthPage extends PromiseComponent<{}, AddBasicAuthPageState
     // Clear any previous errors.
     this.setState({ errorMessage: '' });
     this.getOAuthResource().then((oauth: OAuthKind) => {
-      const promises = [this.createTLSSecret(), this.createCAConfigMap()];
+      const mockSecret = this.state.certFileContent ? mockNames.secret : '';
+      const mockCA = this.state.caFileContent ? mockNames.ca : '';
+      this.addBasicAuthIDP(oauth, mockSecret, mockCA, true)
+        .then(() => {
+          const promises = [this.createTLSSecret(), this.createCAConfigMap()];
 
-      Promise.all(promises)
-        .then(([tlsSecret, configMap]) => {
-          const caName = configMap ? configMap.metadata.name : '';
-          const secretName = tlsSecret ? tlsSecret.metadata.name : '';
-          return this.addBasicAuthIDP(oauth, secretName, caName);
+          Promise.all(promises)
+            .then(([tlsSecret, configMap]) => {
+              const caName = configMap ? configMap.metadata.name : '';
+              const secretName = tlsSecret ? tlsSecret.metadata.name : '';
+              return this.addBasicAuthIDP(oauth, secretName, caName);
+            })
+            .then(redirectToOAuthPage);
         })
-        .then(redirectToOAuthPage);
+        .catch((err) => {
+          this.setState({ errorMessage: err });
+        });
     });
   };
 
@@ -168,7 +181,7 @@ export class AddBasicAuthPage extends PromiseComponent<{}, AddBasicAuthPageState
             </label>
             <input
               className="pf-c-form-control"
-              type="text"
+              type="url"
               onChange={this.urlChanged}
               value={url}
               id="url"
@@ -202,7 +215,7 @@ export class AddBasicAuthPage extends PromiseComponent<{}, AddBasicAuthPageState
           </div>
           <ButtonBar errorMessage={this.state.errorMessage} inProgress={this.state.inProgress}>
             <ActionGroup className="pf-c-form">
-              <Button type="submit" variant="primary">
+              <Button type="submit" variant="primary" data-test-id="add-idp">
                 Add
               </Button>
               <Button type="button" variant="secondary" onClick={history.goBack}>
