@@ -2,13 +2,15 @@ import * as React from 'react';
 import * as _ from 'lodash-es';
 
 import { Status, PodRingController } from '@console/shared';
+import PodRingSet from '@console/shared/src/components/pod/PodRingSet';
+import { AddHealthChecks, EditHealthChecks } from '@console/app/src/actions/modify-health-checks';
 import { k8sCreate, K8sKind, K8sResourceKind, K8sResourceKindReference } from '../module/k8s';
 import { errorModal } from './modals';
 import { DeploymentConfigModel } from '../models';
 import { Conditions } from './conditions';
 import { ResourceEventStream } from './events';
 import { VolumesTable } from './volumes-table';
-import { DetailsPage, ListPage, Table } from './factory';
+import { DetailsPage, ListPage, Table, RowFunction } from './factory';
 import {
   AsyncComponent,
   ContainerTable,
@@ -27,7 +29,6 @@ import {
 import { ReplicationControllersPage } from './replication-controller';
 
 import { WorkloadTableRow, WorkloadTableHeader } from './workload-table';
-import PodRingSet from '@console/shared/src/components/pod/PodRingSet';
 
 const DeploymentConfigsReference: K8sResourceKindReference = 'DeploymentConfig';
 
@@ -82,8 +83,10 @@ export const menuActions: KebabAction[] = [
   RolloutAction,
   PauseAction,
   ModifyCount,
+  AddHealthChecks,
   AddStorage,
   ...getExtensionsKebabActionsForKind(DeploymentConfigModel),
+  EditHealthChecks,
   ...common,
 ];
 
@@ -270,30 +273,18 @@ DeploymentConfigsDetailsPage.displayName = 'DeploymentConfigsDetailsPage';
 
 const kind = 'DeploymentConfig';
 
-const DeploymentConfigTableRow: React.FC<DeploymentConfigTableRowProps> = ({
-  obj,
-  index,
-  key,
-  style,
-}) => {
+const DeploymentConfigTableRow: RowFunction<K8sResourceKind> = ({ obj, index, key, style }) => {
   return (
     <WorkloadTableRow
       obj={obj}
       index={index}
-      key={key}
+      rowKey={key}
       style={style}
       menuActions={menuActions}
       kind={kind}
     />
   );
 };
-DeploymentConfigTableRow.displayName = 'DeploymentTableRow';
-type DeploymentConfigTableRowProps = {
-  obj: K8sResourceKind;
-  index: number;
-  key?: string;
-  style: object;
-};
 
 const DeploymentConfigTableHeader = () => {
   return WorkloadTableHeader();
