@@ -2,10 +2,21 @@ import * as _ from 'lodash-es';
 import * as PropTypes from 'prop-types';
 import * as React from 'react';
 import { connect } from 'react-redux';
-import { getNodeRoles, getMachinePhase } from '@console/shared';
+import {
+  getNodeRoles,
+  getMachinePhase,
+  nodeMemory,
+  nodeCPU,
+  nodeFS,
+  nodePods,
+} from '@console/shared';
 import * as UIActions from '../../actions/ui';
+import {
+  alertStateOrder,
+  silenceFiringAlertsOrder,
+  silenceStateOrder,
+} from '../../reducers/monitoring';
 import { ingressValidHosts } from '../ingress';
-import { alertStateOrder, silenceStateOrder } from '../../reducers/monitoring';
 import { convertToBaseValue, EmptyBox, StatusBox, WithScrollContainer } from '../utils';
 import {
   getClusterOperatorStatus,
@@ -13,6 +24,7 @@ import {
   getJobTypeAndCompletions,
   getTemplateInstanceStatus,
   K8sResourceKind,
+  K8sResourceKindReference,
   NodeKind,
   planExternalName,
   PodKind,
@@ -32,6 +44,7 @@ import {
   TableBody,
   TableGridBreakpoint,
   SortByDirection,
+  OnSelect,
 } from '@patternfly/react-table';
 
 import { CellMeasurerCache, CellMeasurer } from 'react-virtualized';
@@ -114,6 +127,7 @@ const sorts = {
   pvStorage: (pv) => _.toInteger(convertToBaseValue(pv?.spec?.capacity?.storage)),
   pvcStorage: (pvc) => _.toInteger(convertToBaseValue(pvc?.status?.capacity?.storage)),
   serviceClassDisplayName,
+  silenceFiringAlertsOrder,
   silenceStateOrder,
   string: (val) => JSON.stringify(val),
   number: (val) => _.toNumber(val),
@@ -124,7 +138,11 @@ const sorts = {
     const roles = getNodeRoles(node);
     return roles.sort().join(', ');
   },
+  nodeMemory: (node: NodeKind): number => nodeMemory(node),
+  nodeCPU: (node: NodeKind): number => nodeCPU(node),
+  nodeFS: (node: NodeKind): number => nodeFS(node),
   machinePhase: (machine: MachineKind): string => getMachinePhase(machine),
+  nodePods: (node: NodeKind): number => nodePods(node),
 };
 
 const stateToProps = (
@@ -135,7 +153,6 @@ const stateToProps = (
     defaultSortField = 'metadata.name',
     defaultSortFunc = undefined,
     defaultSortOrder = SortByDirection.asc,
-    defaultSortAsNumber = false,
     filters = {},
     loaded = false,
     reduxID = null,
@@ -145,7 +162,7 @@ const stateToProps = (
   },
 ) => {
   const allFilters = staticFilters ? Object.assign({}, filters, ...staticFilters) : filters;
-  let newData = getFilteredRows(allFilters, rowFilters, data);
+  const newData = getFilteredRows(allFilters, rowFilters, data);
 
   const listId = reduxIDs ? reduxIDs.join(',') : reduxID;
   // Only default to 'metadata.name' if no `defaultSortFunc`
@@ -154,17 +171,12 @@ const stateToProps = (
     defaultSortFunc ? undefined : defaultSortField,
   );
   const currentSortFunc = UI.getIn(['listSorts', listId, 'func'], defaultSortFunc);
-  const currentSortAsNumber = UI.getIn(['listSorts', listId, 'sortAsNumber'], defaultSortAsNumber);
   const currentSortOrder = UI.getIn(['listSorts', listId, 'orderBy'], defaultSortOrder);
 
   if (loaded) {
     let sortBy: string | Function = 'metadata.name';
     if (currentSortField) {
-      if (currentSortAsNumber) {
-        sortBy = (resource) => sorts.number(_.get(resource, currentSortField, ''));
-      } else {
-        sortBy = (resource) => sorts.string(_.get(resource, currentSortField, ''));
-      }
+      sortBy = (resource) => sorts.string(_.get(resource, currentSortField, ''));
     } else if (currentSortFunc && customSorts[currentSortFunc]) {
       // Sort resources by a function in the 'customSorts' prop
       sortBy = customSorts[currentSortFunc];
@@ -173,12 +185,29 @@ const stateToProps = (
       sortBy = sorts[currentSortFunc];
     }
 
-    // Always set the secondary sort criteria to ascending by name
-    newData = _.orderBy(
-      newData,
-      [sortBy, 'metadata.name'],
-      [currentSortOrder, SortByDirection.asc],
-    );
+    const getSortValue = (resource) => {
+      const val = _.isFunction(sortBy) ? sortBy(resource) : _.get(resource, sortBy as string);
+      return val ?? '';
+    };
+    newData?.sort((a, b) => {
+      const lang = navigator.languages[0] || navigator.language;
+      // Use `localCompare` with `numeric: true` for a natural sort order (e.g., pv-1, pv-9, pv-10)
+      const compareOpts = { numeric: true, ignorePunctuation: true };
+      const aValue = getSortValue(a);
+      const bValue = getSortValue(b);
+      const result: number =
+        Number.isFinite(aValue) && Number.isFinite(bValue)
+          ? aValue - bValue
+          : `${aValue}`.localeCompare(`${bValue}`, lang, compareOpts);
+      if (result !== 0) {
+        return currentSortOrder === SortByDirection.asc ? result : result * -1;
+      }
+
+      // Use name as a secondary sort for a stable sort.
+      const aName = a?.metadata?.name || '';
+      const bName = b?.metadata?.name || '';
+      return aName.localeCompare(bName, lang, compareOpts);
+    });
   }
 
   return {
@@ -278,7 +307,8 @@ const VirtualBody: React.SFC<VirtualBodyProps> = (props) => {
       style,
       customData,
     };
-    const row = (Row as RowFunction)(rowArgs as RowFunctionArgs);
+
+    const row = Row(rowArgs);
 
     // do not render non visible elements (this excludes overscan)
     if (!isVisible) {
@@ -317,20 +347,21 @@ const VirtualBody: React.SFC<VirtualBodyProps> = (props) => {
   );
 };
 
-export type RowFunctionArgs = {
-  obj: object;
+export type RowFunctionArgs<T = any, C = any> = {
+  obj: T;
   index: number;
-  columns: [];
+  columns: any[];
   isScrolling: boolean;
   key: string;
   style: object;
-  customData?: any;
+  customData?: C;
 };
-export type RowFunction = (args: RowFunctionArgs) => JSX.Element;
+
+export type RowFunction<T = any, C = any> = (args: RowFunctionArgs<T, C>) => React.ReactElement;
 
 export type VirtualBodyProps = {
   customData?: any;
-  Row: RowFunction | React.ComponentClass<any, any> | React.ComponentType<any>;
+  Row: RowFunction;
   height: number;
   isScrolling: boolean;
   onChildScroll: (...args) => any;
@@ -351,15 +382,17 @@ export type TableProps = {
   filters?: { [key: string]: any };
   Header: (...args) => any[];
   loadError?: string | Object;
-  Row?: RowFunction | React.ComponentClass<any, any> | React.ComponentType<any>;
+  Row?: RowFunction;
   Rows?: (...args) => any[];
   'aria-label': string;
+  onSelect?: OnSelect;
   virtualize?: boolean;
   NoDataEmptyMsg?: React.ComponentType<{}>;
   EmptyMsg?: React.ComponentType<{}>;
   loaded?: boolean;
   reduxID?: string;
   reduxIDs?: string[];
+  label?: string;
 };
 
 type TablePropsFromState = {};
@@ -370,6 +403,14 @@ type TableOptionProps = {
   UI: any;
 };
 
+type ComponentProps = {
+  data?: any[];
+  filters?: Object;
+  selected?: any;
+  match?: any;
+  kindObj?: K8sResourceKindReference;
+};
+
 export const Table = connect<
   TablePropsFromState,
   TablePropsFromDispatch,
@@ -415,7 +456,7 @@ export const Table = connect<
 
     constructor(props) {
       super(props);
-      const componentProps: any = _.pick(props, [
+      const componentProps: ComponentProps = _.pick(props, [
         'data',
         'filters',
         'selected',
@@ -442,24 +483,25 @@ export const Table = connect<
           sortBy = { index: columnIndex + this._columnShift, direction: currentSortOrder };
         }
       }
-      this.state = { columns, sortBy };
+      this.state = { sortBy };
     }
 
     componentDidMount() {
-      const { columns } = this.state;
+      const componentProps: ComponentProps = _.pick(this.props, [
+        'data',
+        'filters',
+        'selected',
+        'match',
+        'kindObj',
+      ]);
+      const columns = this.props.Header(componentProps);
       const sp = new URLSearchParams(window.location.search);
       const columnIndex = _.findIndex(columns, { title: sp.get('sortBy') });
 
       if (columnIndex > -1) {
         const sortOrder = sp.get('orderBy') || SortByDirection.asc;
         const column = columns[columnIndex];
-        this._applySort(
-          column.sortField,
-          column.sortFunc,
-          column.sortAsNumber,
-          sortOrder,
-          column.title,
-        );
+        this._applySort(column.sortField, column.sortFunc, sortOrder, column.title);
         this.setState({
           sortBy: {
             index: columnIndex + this._columnShift,
@@ -480,22 +522,24 @@ export const Table = connect<
       this.forceUpdate();
     }
 
-    _applySort(sortField, sortFunc, sortAsNumber, direction, columnTitle) {
+    _applySort(sortField, sortFunc, direction, columnTitle) {
       const { sortList, listId, currentSortFunc } = this.props;
       const applySort = _.partial(sortList, listId);
-      applySort(sortField, sortFunc || currentSortFunc, sortAsNumber, direction, columnTitle);
+      applySort(sortField, sortFunc || currentSortFunc, direction, columnTitle);
     }
 
     _onSort(event, index, direction) {
       event.preventDefault();
-      const sortColumn = this.state.columns[index - this._columnShift];
-      this._applySort(
-        sortColumn.sortField,
-        sortColumn.sortFunc,
-        sortColumn.sortAsNumber,
-        direction,
-        sortColumn.title,
-      );
+      const componentProps: ComponentProps = _.pick(this.props, [
+        'data',
+        'filters',
+        'selected',
+        'match',
+        'kindObj',
+      ]);
+      const columns = this.props.Header(componentProps);
+      const sortColumn = columns[index - this._columnShift];
+      this._applySort(sortColumn.sortField, sortColumn.sortFunc, direction, sortColumn.title);
       this.setState({
         sortBy: {
           index,
@@ -518,8 +562,9 @@ export const Table = connect<
         virtualize = true,
         customData,
         gridBreakPoint = TableGridBreakpoint.none,
+        Header,
       } = this.props;
-      const { sortBy, columns } = this.state;
+      const { sortBy } = this.state;
       const componentProps: any = _.pick(this.props, [
         'data',
         'filters',
@@ -527,6 +572,7 @@ export const Table = connect<
         'match',
         'kindObj',
       ]);
+      const columns = Header(componentProps);
       const ariaRowCount = componentProps.data && componentProps.data.length;
       const scrollNode = typeof scrollElement === 'function' ? scrollElement() : scrollElement;
       const renderVirtualizedTable = (scrollContainer) => (
@@ -618,17 +664,10 @@ export type TableInnerProps = {
   namespace?: string;
   reduxID?: string;
   reduxIDs?: string[];
-  Row?: RowFunction | React.ComponentClass<any, any> | React.ComponentType<any>;
+  Row?: RowFunction;
   Rows?: (...args) => any[];
   selector?: Object;
-  sortList?: (
-    listId: string,
-    field: string,
-    func: any,
-    sortAsNumber: boolean,
-    orderBy: string,
-    column: string,
-  ) => any;
+  sortList?: (listId: string, field: string, func: any, orderBy: string, column: string) => any;
   selectedResourcesForKind?: string[];
   onSelect?: (
     event: React.MouseEvent,
@@ -645,6 +684,5 @@ export type TableInnerProps = {
 };
 
 export type TableInnerState = {
-  columns?: any[];
   sortBy: object;
 };
