@@ -12,7 +12,7 @@ import { MachineAutoscalerModel, MachineModel, MachineSetModel } from '../models
 import { K8sKind, MachineDeploymentKind, MachineSetKind, referenceForModel } from '../module/k8s';
 import { MachinePage } from './machine';
 import { configureMachineAutoscalerModal, configureReplicaCountModal } from './modals';
-import { DetailsPage, ListPage, Table, TableRow, TableData } from './factory';
+import { DetailsPage, ListPage, Table, TableRow, TableData, RowFunction } from './factory';
 import {
   Kebab,
   KebabAction,
@@ -35,6 +35,7 @@ const machineReplicasModal = (
   configureReplicaCountModal({
     resourceKind,
     resource,
+    title: 'Edit Machine Count',
     message: `${resourceKind.labelPlural} maintain the proper number of healthy machines.`,
   });
 
@@ -42,7 +43,7 @@ export const editCountAction: KebabAction = (
   kind: K8sKind,
   resource: MachineSetKind | MachineDeploymentKind,
 ) => ({
-  label: 'Edit Count',
+  label: 'Edit Machine Count',
   callback: () => machineReplicasModal(kind, resource),
   accessReview: {
     group: kind.apiGroup,
@@ -121,7 +122,7 @@ const MachineSetTableHeader = () => {
 };
 MachineSetTableHeader.displayName = 'MachineSetTableHeader';
 
-const MachineSetTableRow: React.FC<MachineSetTableRowProps> = ({ obj, index, key, style }) => {
+const MachineSetTableRow: RowFunction<MachineSetKind> = ({ obj, index, key, style }) => {
   return (
     <TableRow id={obj.metadata.uid} index={index} trKey={key} style={style}>
       <TableData className={tableColumnClasses[0]}>
@@ -151,13 +152,6 @@ const MachineSetTableRow: React.FC<MachineSetTableRowProps> = ({ obj, index, key
     </TableRow>
   );
 };
-MachineSetTableRow.displayName = 'MachineSetTableRow';
-type MachineSetTableRowProps = {
-  obj: MachineSetKind;
-  index: number;
-  key?: string;
-  style: object;
-};
 
 export const MachineCounts: React.SFC<MachineCountsProps> = ({
   resourceKind,
