@@ -2,7 +2,6 @@ import * as React from 'react';
 import * as _ from 'lodash-es';
 import { connect } from 'react-redux';
 import {
-  ArrowCircleUpIcon,
   BellIcon,
   CaretDownIcon,
   EllipsisVIcon,
@@ -14,27 +13,25 @@ import {
   ApplicationLauncherGroup,
   ApplicationLauncherItem,
   ApplicationLauncherSeparator,
-  Button,
   NotificationBadge,
   Toolbar,
   ToolbarGroup,
   ToolbarItem,
+  TooltipPosition,
+  Tooltip,
 } from '@patternfly/react-core';
-import classNames from 'classnames';
+import { Link } from 'react-router-dom';
 import { FLAGS, YellowExclamationTriangleIcon } from '@console/shared';
 import { formatNamespacedRouteForResource } from '@console/shared/src/utils';
+import CloudShellMastheadButton from '@console/app/src/components/cloud-shell/CloudShellMastheadButton';
 import * as UIActions from '../actions/ui';
 import { connectToFlags, flagPending, featureReducerName } from '../reducers/features';
 import { authSvc } from '../module/auth';
 import { getOCMLink } from '../module/k8s';
-import { history, Firehose } from './utils';
+import { Firehose } from './utils';
 import { openshiftHelpBase } from './utils/documentation';
 import { AboutModal } from './about-modal';
-import {
-  clusterVersionReference,
-  getAvailableClusterUpdates,
-  getReportBugLink,
-} from '../module/k8s/cluster-settings';
+import { clusterVersionReference, getReportBugLink } from '../module/k8s/cluster-settings';
 import * as redhatLogoImg from '../imgs/logos/redhat.svg';
 
 const SystemStatusButton = ({ statuspageData, className }) =>
@@ -52,17 +49,6 @@ const SystemStatusButton = ({ statuspageData, className }) =>
     </ToolbarItem>
   ) : null;
 
-const UpdatesAvailableButton = ({ cv, onClick, systemStatusButtonPresent }) => {
-  const updatesAvailable = !_.isEmpty(getAvailableClusterUpdates(cv));
-  return updatesAvailable ? (
-    <ToolbarItem className={classNames({ 'hidden-sm': systemStatusButtonPresent })}>
-      <Button variant="plain" aria-label="Cluster Updates Available" onClick={onClick}>
-        <ArrowCircleUpIcon color="#08c" className="co-masthead-icon" />
-      </Button>
-    </ToolbarItem>
-  ) : null;
-};
-
 class MastheadToolbarContents_ extends React.Component {
   constructor(props) {
     super(props);
@@ -77,20 +63,19 @@ class MastheadToolbarContents_ extends React.Component {
     };
 
     this._getStatuspageData = this._getStatuspageData.bind(this);
+    this._getImportYAMLPath = this._getImportYAMLPath.bind(this);
     this._updateUser = this._updateUser.bind(this);
     this._onUserDropdownToggle = this._onUserDropdownToggle.bind(this);
     this._onUserDropdownSelect = this._onUserDropdownSelect.bind(this);
     this._onKebabDropdownToggle = this._onKebabDropdownToggle.bind(this);
     this._onKebabDropdownSelect = this._onKebabDropdownSelect.bind(this);
     this._renderMenu = this._renderMenu.bind(this);
-    this._onClusterUpdatesAvailable = this._onClusterUpdatesAvailable.bind(this);
     this._onApplicationLauncherDropdownSelect = this._onApplicationLauncherDropdownSelect.bind(
       this,
     );
     this._onApplicationLauncherDropdownToggle = this._onApplicationLauncherDropdownToggle.bind(
       this,
     );
-    this._onImportYAML = this._onImportYAML.bind(this);
     this._onHelpDropdownSelect = this._onHelpDropdownSelect.bind(this);
     this._onHelpDropdownToggle = this._onHelpDropdownToggle.bind(this);
     this._onAboutModal = this._onAboutModal.bind(this);
@@ -121,6 +106,10 @@ class MastheadToolbarContents_ extends React.Component {
       .then((statuspageData) => this.setState({ statuspageData }));
   }
 
+  _getImportYAMLPath() {
+    return formatNamespacedRouteForResource('import', this.props.activeNamespace);
+  }
+
   _updateUser() {
     const { flags, user } = this.props;
     if (!flags[FLAGS.OPENSHIFT]) {
@@ -156,10 +145,6 @@ class MastheadToolbarContents_ extends React.Component {
     });
   }
 
-  _onClusterUpdatesAvailable() {
-    history.push('/settings/cluster');
-  }
-
   _onApplicationLauncherDropdownSelect() {
     this.setState({
       isApplicationLauncherDropdownOpen: !this.state.isApplicationLauncherDropdownOpen,
@@ -172,12 +157,6 @@ class MastheadToolbarContents_ extends React.Component {
     });
   }
 
-  _onImportYAML(e) {
-    e.preventDefault();
-    const importYAMLPath = formatNamespacedRouteForResource('import', this.props.activeNamespace);
-    history.push(importYAMLPath);
-  }
-
   _onHelpDropdownSelect() {
     this.setState({
       isHelpDropdownOpen: !this.state.isHelpDropdownOpen,
@@ -199,16 +178,6 @@ class MastheadToolbarContents_ extends React.Component {
     this.setState({ showAboutModal: false });
   }
 
-  _onCommandLineTools(e) {
-    e.preventDefault();
-    history.push('/command-line-tools');
-  }
-
-  _openLink(e, url) {
-    e.preventDefault();
-    window.open(url, '_blank').opener = null;
-  }
-
   _getAdditionalLinks(links, type) {
     return _.sortBy(
       _.filter(links, (link) => link.spec.location === type),
@@ -306,8 +275,7 @@ class MastheadToolbarContents_ extends React.Component {
         ...(flags[FLAGS.CONSOLE_CLI_DOWNLOAD]
           ? [
               {
-                label: 'Command Line Tools',
-                callback: this._onCommandLineTools,
+                component: <Link to="/command-line-tools">Command Line Tools</Link>,
               },
             ]
           : []),
@@ -316,13 +284,14 @@ class MastheadToolbarContents_ extends React.Component {
               {
                 label: reportBugLink.label,
                 externalLink: true,
-                callback: (e) => this._openLink(e, reportBugLink.href),
+                href: reportBugLink.href,
               },
             ]
           : []),
         {
           label: 'About',
           callback: this._onAboutModal,
+          component: 'button',
         },
       ],
     });
@@ -337,12 +306,9 @@ class MastheadToolbarContents_ extends React.Component {
   _getAdditionalActions(links) {
     const actions = _.map(links, (link) => {
       return {
-        callback: (e) => {
-          e.preventDefault();
-          window.open(link.spec.href, '_blank').opener = null;
-        },
         label: link.spec.text,
         externalLink: true,
+        href: link.spec.href,
       };
     });
 
@@ -357,26 +323,27 @@ class MastheadToolbarContents_ extends React.Component {
     action.externalLink ? { isExternal: true, target: '_blank', rel: 'noopener noreferrer' } : {};
 
   _renderApplicationItems(actions) {
-    return _.map(actions, (action, index) => {
+    return _.map(actions, (action, groupIndex) => {
       if (action.isSection) {
         return (
-          <ApplicationLauncherGroup key={`group_${index}`} label={action.name}>
+          <ApplicationLauncherGroup key={groupIndex} label={action.name}>
             <>
-              {_.map(action.actions, (sectionAction) => {
+              {_.map(action.actions, (sectionAction, itemIndex) => {
                 return (
                   <ApplicationLauncherItem
-                    key={sectionAction.label}
+                    key={itemIndex}
                     icon={sectionAction.image}
                     href={sectionAction.href || '#'}
                     onClick={sectionAction.callback}
+                    component={sectionAction.component}
                     {...this._externalProps(sectionAction)}
                   >
                     {sectionAction.label}
                   </ApplicationLauncherItem>
                 );
               })}
-              {index < actions.length - 1 && (
-                <ApplicationLauncherSeparator key={`separator-${index}`} />
+              {groupIndex < actions.length - 1 && (
+                <ApplicationLauncherSeparator key={`separator-${groupIndex}`} />
               )}
             </>
           </ApplicationLauncherGroup>
@@ -384,19 +351,20 @@ class MastheadToolbarContents_ extends React.Component {
       }
 
       return (
-        <ApplicationLauncherGroup key={`group_${index}`}>
+        <ApplicationLauncherGroup key={groupIndex}>
           <>
             <ApplicationLauncherItem
               key={action.label}
               icon={action.image}
               href={action.href || '#'}
               onClick={action.callback}
+              component={action.component}
               {...this._externalProps(action)}
             >
               {action.label}
             </ApplicationLauncherItem>
-            {index < actions.length - 1 && (
-              <ApplicationLauncherSeparator key={`separator-${index}`} />
+            {groupIndex < actions.length - 1 && (
+              <ApplicationLauncherSeparator key={`separator-${groupIndex}`} />
             )}
           </>
         </ApplicationLauncherGroup>
@@ -439,7 +407,7 @@ class MastheadToolbarContents_ extends React.Component {
       if (window.SERVER_FLAGS.requestTokenURL) {
         userActions.push({
           label: 'Copy Login Command',
-          callback: (e) => this._openLink(e, window.SERVER_FLAGS.requestTokenURL),
+          href: window.SERVER_FLAGS.requestTokenURL,
           externalLink: true,
         });
       }
@@ -447,6 +415,7 @@ class MastheadToolbarContents_ extends React.Component {
       userActions.push({
         label: 'Log out',
         callback: logout,
+        component: 'button',
       });
 
       actions.push({
@@ -468,8 +437,7 @@ class MastheadToolbarContents_ extends React.Component {
         isSection: true,
         actions: [
           {
-            label: 'Import YAML',
-            callback: this._onImportYAML,
+            component: <Link to={this._getImportYAMLPath()}>Import YAML</Link>,
           },
         ],
       });
@@ -527,7 +495,7 @@ class MastheadToolbarContents_ extends React.Component {
       showAboutModal,
       statuspageData,
     } = this.state;
-    const { consoleLinks, cv, drawerToggle, notificationsRead, canAccessNS } = this.props;
+    const { consoleLinks, drawerToggle, notificationsRead, canAccessNS } = this.props;
     const launchActions = this._launchActions();
     const alertAccess = canAccessNS && !!window.SERVER_FLAGS.prometheusBaseURL;
     return (
@@ -536,14 +504,6 @@ class MastheadToolbarContents_ extends React.Component {
           <ToolbarGroup className="hidden-xs">
             {/* desktop -- (system status button) */}
             <SystemStatusButton statuspageData={statuspageData} />
-            {/* desktop -- (updates button) */}
-            {cv && cv.data && (
-              <UpdatesAvailableButton
-                cv={cv.data}
-                onClick={this._onClusterUpdatesAvailable}
-                systemStatusButtonPresent={!_.isEmpty(_.get(statuspageData, 'incidents'))}
-              />
-            )}
             {/* desktop -- (application launcher dropdown), import yaml, help dropdown [documentation, about] */}
             {!_.isEmpty(launchActions) && (
               <ToolbarItem>
@@ -572,10 +532,17 @@ class MastheadToolbarContents_ extends React.Component {
               </ToolbarItem>
             )}
             <ToolbarItem>
-              <Button variant="plain" aria-label="Import YAML" onClick={this._onImportYAML}>
-                <PlusCircleIcon className="co-masthead-icon" />
-              </Button>
+              <Tooltip content="Import YAML" position={TooltipPosition.bottom}>
+                <Link
+                  to={this._getImportYAMLPath()}
+                  className="pf-c-button pf-m-plain"
+                  aria-label="Import YAML"
+                >
+                  <PlusCircleIcon className="co-masthead-icon" />
+                </Link>
+              </Tooltip>
             </ToolbarItem>
+            <CloudShellMastheadButton />
             <ToolbarItem>
               <ApplicationLauncher
                 aria-label="Help menu"
