@@ -27,11 +27,12 @@ import {
 } from '@patternfly/react-core';
 import { ChartLineIcon } from '@patternfly/react-icons';
 import { connect } from 'react-redux';
+import { APIError } from '@console/shared';
 import { withFallback } from '@console/shared/src/components/error/error-boundary';
 
 import * as UIActions from '../../actions/ui';
 import { RootState } from '../../redux';
-import { PrometheusResponse } from '../graphs';
+import { PrometheusLabels, PrometheusResponse, PrometheusResult, PrometheusValue } from '../graphs';
 import { GraphEmpty } from '../graphs/graph-empty';
 import { getPrometheusURL, PrometheusEndpoint } from '../graphs/helpers';
 import { queryBrowserTheme } from '../graphs/themes';
@@ -119,6 +120,7 @@ const SpanControls: React.FC<SpanControlsProps> = React.memo(
           value={text}
         />
         <Dropdown
+          ariaLabel="graph timespan"
           buttonClassName="dropdown-button--icon-only"
           items={dropdownItems}
           menuClassName="query-browser__span-dropdown-menu"
@@ -155,7 +157,8 @@ const tooltipStateToProps = ({ UI }: RootState, { seriesIndex }) => {
 };
 
 const TooltipInner_: React.FC<TooltipInnerProps> = ({
-  datum,
+  datumX,
+  datumY,
   labels,
   query,
   seriesIndex,
@@ -187,15 +190,15 @@ const TooltipInner_: React.FC<TooltipInnerProps> = ({
               className="query-browser__series-btn"
               style={{ backgroundColor: colors[seriesIndex % colors.length] }}
             />
-            {datum.x && (
+            {datumX && (
               <div className="query-browser__tooltip-time">
-                {twentyFourHourTimeWithSeconds(datum.x)}
+                {twentyFourHourTimeWithSeconds(datumX)}
               </div>
             )}
           </div>
           <div className="query-browser__tooltip-group">
             <div className="co-nowrap co-truncate">{query}</div>
-            <div className="query-browser__tooltip-value">{formatValue(datum.y)}</div>
+            <div className="query-browser__tooltip-value">{formatValue(datumY)}</div>
           </div>
           {_.map(labels, (v, k) => (
             <div className="co-nowrap co-truncate" key={k}>
@@ -214,7 +217,7 @@ const TooltipInner = connect(tooltipStateToProps)(TooltipInner_);
 
 const Tooltip_: React.FC<TooltipProps> = ({ datum, x, y }) =>
   datum && _.isFinite(datum.y) && _.isFinite(x) && _.isFinite(y) ? (
-    <TooltipInner datum={datum} seriesIndex={datum._stack - 1} x={x} y={y} />
+    <TooltipInner datumX={datum.x} datumY={datum.y} seriesIndex={datum._stack - 1} x={x} y={y} />
   ) : null;
 const Tooltip = withFallback(Tooltip_);
 
@@ -245,9 +248,7 @@ const LegendContainer = ({ children }: { children?: React.ReactNode }) => {
 };
 
 const Graph: React.FC<GraphProps> = React.memo(
-  ({ allSeries, disabledSeries, formatLegendLabel, isStack, span, xDomain }) => {
-    const [containerRef, width] = useRefWidth();
-
+  ({ allSeries, disabledSeries, formatLegendLabel, isStack, span, width, xDomain }) => {
     // Remove any disabled series
     const data = _.flatMap(allSeries, (series, i) => {
       return _.map(series, ([metric, values]) => {
@@ -310,47 +311,43 @@ const Graph: React.FC<GraphProps> = React.memo(
       : undefined;
 
     return (
-      <div ref={containerRef} style={{ width: '100%' }}>
-        {width > 0 && (
-          <Chart
-            containerComponent={graphContainer}
-            domain={domain}
-            domainPadding={{ y: 1 }}
-            height={200}
-            scale={{ x: 'time', y: 'linear' }}
-            theme={chartTheme}
-            width={width}
-          >
-            <ChartAxis style={xAxisStyle} tickCount={5} tickFormat={xTickFormat} />
-            <ChartAxis crossAxis={false} dependentAxis tickCount={6} tickFormat={yTickFormat} />
-            {isStack ? (
-              <ChartStack>
-                {_.map(data, (values, i) => (
-                  <ChartArea key={i} data={values} />
-                ))}
-              </ChartStack>
-            ) : (
-              <ChartGroup>
-                {_.map(data, (values, i) => (
-                  <ChartLine key={i} data={values} />
-                ))}
-              </ChartGroup>
-            )}
-            {legendData && (
-              <ChartLegend
-                data={legendData}
-                groupComponent={<LegendContainer />}
-                itemsPerRow={4}
-                orientation="vertical"
-                style={{
-                  labels: { fontSize: 11 },
-                }}
-                symbolSpacer={4}
-              />
-            )}
-          </Chart>
+      <Chart
+        containerComponent={graphContainer}
+        domain={domain}
+        domainPadding={{ y: 1 }}
+        height={200}
+        scale={{ x: 'time', y: 'linear' }}
+        theme={chartTheme}
+        width={width}
+      >
+        <ChartAxis style={xAxisStyle} tickCount={5} tickFormat={xTickFormat} />
+        <ChartAxis crossAxis={false} dependentAxis tickCount={6} tickFormat={yTickFormat} />
+        {isStack ? (
+          <ChartStack>
+            {_.map(data, (values, i) => (
+              <ChartArea key={i} data={values} />
+            ))}
+          </ChartStack>
+        ) : (
+          <ChartGroup>
+            {_.map(data, (values, i) => (
+              <ChartLine key={i} data={values} />
+            ))}
+          </ChartGroup>
         )}
-      </div>
+        {legendData && (
+          <ChartLegend
+            data={legendData}
+            groupComponent={<LegendContainer />}
+            itemsPerRow={4}
+            orientation="vertical"
+            style={{
+              labels: { fontSize: 11 },
+            }}
+            symbolSpacer={4}
+          />
+        )}
+      </Chart>
     );
   },
 );
@@ -416,6 +413,7 @@ const ZoomableGraph: React.FC<ZoomableGraphProps> = ({
   isStack,
   onZoom,
   span,
+  width,
   xDomain,
 }) => {
   const [isZooming, setIsZooming] = React.useState(false);
@@ -444,10 +442,10 @@ const ZoomableGraph: React.FC<ZoomableGraphProps> = ({
       return;
     }
 
-    const { width } = e.currentTarget.getBoundingClientRect();
+    const zoomWidth = e.currentTarget.getBoundingClientRect().width;
     const oldFrom = _.get(xDomain, '[0]', Date.now() - span);
-    let from = oldFrom + (span * xMin) / width;
-    let to = oldFrom + (span * xMax) / width;
+    let from = oldFrom + (span * xMin) / zoomWidth;
+    let to = oldFrom + (span * xMax) / zoomWidth;
     let newSpan = to - from;
 
     if (newSpan < minSpan) {
@@ -475,6 +473,7 @@ const ZoomableGraph: React.FC<ZoomableGraphProps> = ({
         formatLegendLabel={formatLegendLabel}
         isStack={isStack}
         span={span}
+        width={width}
         xDomain={xDomain}
       />
     </div>
@@ -514,13 +513,15 @@ const QueryBrowser_: React.FC<QueryBrowserProps> = ({
   const maxSamplesForSpan =
     defaultSamples || _.clamp(Math.round(span / minStep), minSamples, maxSamples);
 
-  const [xDomain, setXDomain] = React.useState();
-  const [error, setError] = React.useState();
+  const [xDomain, setXDomain] = React.useState<AxisDomain>();
+  const [error, setError] = React.useState<QueryBrowserError>();
   const [isDatasetTooBig, setIsDatasetTooBig] = React.useState(false);
-  const [graphData, setGraphData] = React.useState();
+  const [graphData, setGraphData] = React.useState(null);
   const [samples, setSamples] = React.useState(maxSamplesForSpan);
   const [updating, setUpdating] = React.useState(true);
 
+  const [containerRef, width] = useRefWidth();
+
   const endTime = _.get(xDomain, '[1]');
 
   const safeFetch = useSafeFetch();
@@ -583,7 +584,7 @@ const QueryBrowser_: React.FC<QueryBrowserProps> = ({
             ) {
               setSamples(newSamples);
             } else {
-              const newGraphData = _.map(newResults, (result) => {
+              const newGraphData = _.map(newResults, (result: PrometheusResult[]) => {
                 return _.map(result, ({ metric, values }) => {
                   // If filterLabels is specified, ignore all series that don't match
                   return filterLabels &&
@@ -634,7 +635,18 @@ const QueryBrowser_: React.FC<QueryBrowserProps> = ({
   );
 
   if (hideGraphs) {
-    return error && !isRangeVector ? <Error error={error} /> : null;
+    // Still render the graph containers so that `width` continues to be tracked while the graph is
+    // hidden. This ensures we can render at the correct width when the graph is shown again.
+    return (
+      <>
+        {error && !isRangeVector && <Error error={error} />}
+        <div className="query-browser__wrapper query-browser__wrapper--hidden">
+          <div className="graph-wrapper graph-wrapper--query-browser">
+            <div ref={containerRef} style={{ width: '100%' }}></div>
+          </div>
+        </div>
+      </>
+    );
   }
 
   if (isRangeVector) {
@@ -693,26 +705,34 @@ const QueryBrowser_: React.FC<QueryBrowserProps> = ({
             />
           )}
           <div className="graph-wrapper graph-wrapper--query-browser">
-            {hideControls ? (
-              <Graph
-                allSeries={graphData}
-                disabledSeries={disabledSeries}
-                formatLegendLabel={formatLegendLabel}
-                isStack={stack}
-                span={span}
-                xDomain={xDomain}
-              />
-            ) : (
-              <ZoomableGraph
-                allSeries={graphData}
-                disabledSeries={disabledSeries}
-                formatLegendLabel={formatLegendLabel}
-                isStack={stack}
-                onZoom={onZoom}
-                span={span}
-                xDomain={xDomain}
-              />
-            )}
+            <div ref={containerRef} style={{ width: '100%' }}>
+              {width > 0 && (
+                <>
+                  {hideControls ? (
+                    <Graph
+                      allSeries={graphData}
+                      disabledSeries={disabledSeries}
+                      formatLegendLabel={formatLegendLabel}
+                      isStack={stack}
+                      span={span}
+                      width={width}
+                      xDomain={xDomain}
+                    />
+                  ) : (
+                    <ZoomableGraph
+                      allSeries={graphData}
+                      disabledSeries={disabledSeries}
+                      formatLegendLabel={formatLegendLabel}
+                      isStack={stack}
+                      onZoom={onZoom}
+                      span={span}
+                      width={width}
+                      xDomain={xDomain}
+                    />
+                  )}
+                </>
+              )}
+            </div>
           </div>
         </>
       )}
@@ -732,27 +752,29 @@ type GraphDataPoint = {
   y: number;
 };
 
-export type Labels = { [key: string]: string };
-
-type Series = [Labels, GraphDataPoint[][]];
+type Series = [PrometheusLabels, GraphDataPoint[][]];
 
 export type QueryObj = {
-  disabledSeries?: Labels[];
+  disabledSeries?: PrometheusLabels[];
   isEnabled?: boolean;
   isExpanded?: boolean;
   query?: string;
-  series?: Labels[];
+  series?: PrometheusLabels[];
   text?: string;
 };
 
-type PrometheusValue = [number, string];
-
-export type FormatLegendLabel = (labels: Labels, i: number) => string;
+export type FormatLegendLabel = (labels: PrometheusLabels, i: number) => string;
 
 export type PatchQuery = (index: number, patch: QueryObj) => any;
 
+type QueryBrowserError = {
+  json?: {
+    error?: string;
+  };
+} & APIError;
+
 type ErrorProps = {
-  error: any;
+  error: QueryBrowserError;
   title?: string;
 };
 
@@ -763,28 +785,21 @@ type GraphEmptyStateProps = {
 
 type GraphProps = {
   allSeries: Series[][];
-  disabledSeries?: Labels[][];
+  disabledSeries?: PrometheusLabels[][];
   formatLegendLabel?: FormatLegendLabel;
   isStack?: boolean;
   span: number;
+  width: number;
   xDomain?: AxisDomain;
 };
 
-type ZoomableGraphProps = {
-  allSeries: Series[][];
-  disabledSeries?: Labels[][];
-  formatLegendLabel?: FormatLegendLabel;
-  isStack?: boolean;
-  onZoom: (from: number, to: number) => void;
-  span: number;
-  xDomain?: AxisDomain;
-};
+type ZoomableGraphProps = GraphProps & { onZoom: (from: number, to: number) => void };
 
 export type QueryBrowserProps = {
   defaultSamples?: number;
   defaultTimespan?: number;
-  disabledSeries?: Labels[][];
-  filterLabels?: Labels;
+  disabledSeries?: PrometheusLabels[][];
+  filterLabels?: PrometheusLabels;
   formatLegendLabel?: FormatLegendLabel;
   GraphLink?: React.ComponentType<{}>;
   hideControls?: boolean;
@@ -806,8 +821,9 @@ type SpanControlsProps = {
 type TooltipDatum = { _stack: number; x: Date; y: number };
 
 type TooltipInnerProps = {
-  datum: TooltipDatum;
-  labels?: Labels;
+  datumX: Date;
+  datumY: number;
+  labels?: PrometheusLabels;
   query?: string;
   seriesIndex: number;
   x: number;
