@@ -5,9 +5,13 @@ import { Helmet } from 'react-helmet';
 import { ActionGroup, Alert, Button, Tooltip } from '@patternfly/react-core';
 import { safeLoad } from 'js-yaml';
 import * as classNames from 'classnames';
-import { BlueInfoCircleIcon } from '@console/shared/src';
 
-import { ButtonBar, Dropdown, Firehose, history, StatusBox } from '../../utils';
+import { BlueInfoCircleIcon, APIError } from '@console/shared';
+import { ButtonBar } from '../../utils/button-bar';
+import { Dropdown } from '../../utils/dropdown';
+import { Firehose } from '../../utils/firehose';
+import { history } from '../../utils/router';
+import { StatusBox } from '../../utils/status-box';
 import {
   getAlertmanagerConfig,
   patchAlertmanagerConfig,
@@ -18,6 +22,7 @@ import {
   AlertmanagerConfig,
   AlertmanagerReceiver,
   AlertmanagerRoute,
+  InitialReceivers,
 } from '../alert-manager-config';
 import { RoutingLabelEditor } from './routing-labels-editor';
 import * as PagerDutyForm from './pagerduty-receiver-form';
@@ -173,6 +178,32 @@ const getRouteLabelsForEditor = (
     : routeLabels;
 };
 
+const alertMsg = (type: string) => {
+  switch (type) {
+    case InitialReceivers.Default:
+      return 'Your default receiver will automatically receive all alerts from this cluster that are not caught by other receivers first.';
+    case InitialReceivers.Critical:
+      return 'The routing labels for this receiver are configured to capture critical alerts.  Finish setting up this receiver by selecting a "Receiver Type" to choose a destination for these alerts.  If this receiver is deleted, critical alerts will go to the default receiver instead.';
+    case InitialReceivers.Watchdog:
+      return 'The Watchdog alert fires constantly to confirm that your alerting stack is functioning correctly. This receiver is configured to prevent it from creating unnecessary notifications. You can edit this receiver if you plan to use the information that Watchdog provides, otherwise this receiver should remain in its current state with no set receiver type.';
+    default:
+      return 'unknown receiver type'; // should never get here
+  }
+};
+
+const ReceiverInfoTip: React.FC<ReceiverInfoTipProps> = ({ type }) => {
+  return (
+    <Alert
+      isInline
+      className="co-alert co-alert--scrollable"
+      variant="info"
+      title={`${type} Receiver`}
+    >
+      <div className="co-pre-line">{alertMsg(type)}</div>
+    </Alert>
+  );
+};
+
 const ReceiverBaseForm: React.FC<ReceiverBaseFormProps> = ({
   obj: secret, // Secret "alertmanager-main" which contains alertmanager.yaml config
   titleVerb,
@@ -196,8 +227,25 @@ const ReceiverBaseForm: React.FC<ReceiverBaseFormProps> = ({
 
   const { route, global } = config || {};
 
+  // there is no api to get default values for these adv. config props
+  const advancedConfigGlobals = {
+    ['pagerduty_send_resolved']: true,
+    ['pagerduty_client']: '{{ template "pagerduty.default.client" . }}',
+    ['pagerduty_client_url']: '{{ template "pagerduty.default.clientURL" . }}',
+    ['pagerduty_description']: '{{ template "pagerduty.default.description" .}}',
+    ['pagerduty_severity']: 'error',
+    ['email_send_resolved']: false,
+    ['email_html']: '{{ template "email.default.html" . }}',
+    ['slack_send_resolved']: false,
+    ['slack_username']: '{{ template "slack.default.username" . }}',
+    ['slack_icon_emoji']: '{{ template "slack.default.iconemoji" .}}',
+    ['slack_icon_url']: '{{ template "slack.default.iconurl" .}}',
+    ['slack_link_names']: false,
+    ['webhook_send_resolved']: true,
+  };
+
   // default globals to config.global props first, then alertmanagerGlobals
-  const defaultGlobals = { ...alertmanagerGlobals, ...global };
+  const defaultGlobals = { ...alertmanagerGlobals, ...global, ...advancedConfigGlobals };
 
   const INITIAL_STATE = {
     receiverName: '',
@@ -328,19 +376,12 @@ const ReceiverBaseForm: React.FC<ReceiverBaseFormProps> = ({
           {titleVerb} {receiverTypes[formValues.receiverType]} {isDefaultReceiver && 'Default'}{' '}
           Receiver
         </h1>
-        {isDefaultReceiver && !formValues.receiverType && (
-          <Alert
-            isInline
-            className="co-alert co-alert--scrollable"
-            variant="info"
-            title="Default Receiver"
-          >
-            <div className="co-pre-line">
-              Because this is your first receiver, it will automatically receive all alerts from
-              this cluster. You can route specific alerts to subsequent receivers that you create.
-              You can also edit your default receiver at a later time.
-            </div>
-          </Alert>
+        {isDefaultReceiver && <ReceiverInfoTip type={InitialReceivers.Default} />}
+        {formValues.receiverName === 'Critical' && !formValues.receiverType && (
+          <ReceiverInfoTip type={InitialReceivers.Critical} />
+        )}
+        {formValues.receiverName === 'Watchdog' && !formValues.receiverType && (
+          <ReceiverInfoTip type={InitialReceivers.Watchdog} />
         )}
         <div
           className={classNames('form-group', {
@@ -441,10 +482,10 @@ export const SaveAsDefaultCheckbox: React.FC<SaveAsDefaultCheckboxProps> = ({
 }) => {
   const saveAsDefaultLabelClass = classNames('checkbox', { 'co-no-bold': disabled });
   return (
-    <label className={saveAsDefaultLabelClass}>
+    <label className={saveAsDefaultLabelClass} htmlFor={formField}>
       <input
         type="checkbox"
-        name={formField}
+        id={formField}
         data-test-id="save-as-default"
         onChange={(e) =>
           dispatchFormChange({
@@ -465,11 +506,34 @@ export const SaveAsDefaultCheckbox: React.FC<SaveAsDefaultCheckboxProps> = ({
   );
 };
 
+export const SendResolvedAlertsCheckbox = ({ formField, formValues, dispatchFormChange }) => {
+  return (
+    <div className="checkbox">
+      <label className="control-label" htmlFor={formField}>
+        <input
+          type="checkbox"
+          id={formField}
+          data-test-id="send-resolved-alerts"
+          onChange={(e) =>
+            dispatchFormChange({
+              type: 'setFormValues',
+              payload: { [formField]: e.target.checked },
+            })
+          }
+          checked={formValues[formField]}
+          aria-checked={formValues[formField]}
+        />
+        Send resolved alerts to this receiver?
+      </label>
+    </div>
+  );
+};
+
 const ReceiverWrapper: React.FC<ReceiverFormsWrapperProps> = React.memo(({ obj, ...props }) => {
   const { alertManagerBaseURL } = window.SERVER_FLAGS;
   const [alertmanagerGlobals, setAlertmanagerGlobals] = React.useState();
   const [loaded, setLoaded] = React.useState(false);
-  const [loadError, setLoadError] = React.useState();
+  const [loadError, setLoadError] = React.useState<APIError>();
 
   React.useEffect(() => {
     if (!alertManagerBaseURL) {
@@ -581,3 +645,7 @@ type SaveAsDefaultCheckboxProps = {
   dispatchFormChange: Function;
   tooltip: string;
 };
+
+type ReceiverInfoTipProps = {
+  type: InitialReceivers;
+};
