@@ -2,8 +2,9 @@ import * as React from 'react';
 import { connect } from 'react-redux';
 import { NavItemSeparator } from '@patternfly/react-core';
 
+import { FLAGS } from '@console/shared';
+import { formatNamespacedRouteForResource } from '@console/shared/src/utils';
 import { featureReducerName } from '../../reducers/features';
-import { FLAGS } from '../../const';
 import { monitoringReducerName, MonitoringRoutes } from '../../reducers/monitoring';
 
 import {
@@ -25,13 +26,14 @@ import {
 import { referenceForModel } from '../../module/k8s';
 import { ExternalLink, HrefLink, ResourceNSLink, ResourceClusterLink } from './items';
 import { NavSection } from './section';
-import { formatNamespacedRouteForResource } from '../../actions/ui';
 
 type SeparatorProps = {
+  name: string;
   required?: string;
 };
+
 // Wrap `NavItemSeparator` so we can use `required` without prop type errors.
-const Separator: React.FC<SeparatorProps> = () => <NavItemSeparator />;
+const Separator: React.FC<SeparatorProps> = ({ name }) => <NavItemSeparator name={name} />;
 
 const searchStartsWith = ['search'];
 const provisionedServicesStartsWith = ['serviceinstances', 'servicebindings'];
@@ -57,31 +59,29 @@ const apiExplorerStartsWith = ['api-explorer', 'api-resource'];
 
 const monitoringNavSectionStateToProps = (state) => ({
   canAccess: !!state[featureReducerName].get(FLAGS.CAN_GET_NS),
-  grafanaURL: state[monitoringReducerName].get(MonitoringRoutes.Grafana),
   kibanaURL: state[monitoringReducerName].get(MonitoringRoutes.Kibana),
 });
 
-const MonitoringNavSection_ = ({ grafanaURL, canAccess, kibanaURL }) => {
-  const showAlerts = canAccess && !!window.SERVER_FLAGS.prometheusBaseURL;
+const MonitoringNavSection_ = ({ canAccess, kibanaURL }) => {
+  const canAccessPrometheus = canAccess && !!window.SERVER_FLAGS.prometheusBaseURL;
   const showSilences = canAccess && !!window.SERVER_FLAGS.alertManagerBaseURL;
-  const showGrafana = canAccess && !!grafanaURL;
-  return showAlerts || showSilences || showGrafana || kibanaURL ? (
+  return canAccessPrometheus || showSilences || kibanaURL ? (
     <NavSection title="Monitoring">
-      {showAlerts && (
+      {canAccessPrometheus && (
         <HrefLink
           href="/monitoring/alerts"
           name="Alerting"
           startsWith={monitoringAlertsStartsWith}
         />
       )}
-      {showAlerts && (
+      {canAccessPrometheus && (
         <HrefLink
           href="/monitoring/query-browser?query0="
           name="Metrics"
           startsWith={['monitoring/query-browser']}
         />
       )}
-      {showGrafana && <ExternalLink href={grafanaURL} name="Dashboards" />}
+      {canAccessPrometheus && <HrefLink href="/monitoring/dashboards" name="Dashboards" />}
       {kibanaURL && <ExternalLink href={kibanaURL} name="Logging" />}
     </NavSection>
   ) : null;
@@ -94,8 +94,8 @@ const AdminNav = () => (
       <HrefLink
         href="/dashboards"
         activePath="/dashboards/"
-        name="Dashboards"
-        required={[FLAGS.CAN_LIST_NS, FLAGS.OPENSHIFT]}
+        name="Overview"
+        required={[FLAGS.CAN_GET_NS, FLAGS.OPENSHIFT]}
       />
       <ResourceClusterLink resource="projects" name="Projects" required={FLAGS.OPENSHIFT} />
       <HrefLink href="/search" name="Search" startsWith={searchStartsWith} />
@@ -116,7 +116,7 @@ const AdminNav = () => (
       <ResourceNSLink resource="statefulsets" name="Stateful Sets" />
       <ResourceNSLink resource="secrets" name="Secrets" />
       <ResourceNSLink resource="configmaps" name="Config Maps" />
-      <Separator />
+      <Separator name="WorkloadsSeparator" />
       <ResourceNSLink resource="cronjobs" name="Cron Jobs" />
       <ResourceNSLink resource="jobs" name="Jobs" />
       <ResourceNSLink resource="daemonsets" name="Daemon Sets" />
@@ -211,7 +211,7 @@ const AdminNav = () => (
         name="Machine Health Checks"
         required={FLAGS.MACHINE_HEALTH_CHECK}
       />
-      <Separator required={FLAGS.MACHINE_CONFIG} />
+      <Separator required={FLAGS.MACHINE_CONFIG} name="ComputeSeparator" />
       <ResourceClusterLink
         resource={referenceForModel(MachineConfigModel)}
         name="Machine Configs"
