@@ -8,11 +8,17 @@ import { Link } from 'react-router-dom';
 import {
   DEFAULT_GROUP_NAME,
   METRICS_POLL_INTERVAL,
-  TransformResourceData,
   OverviewItem,
   getResourceList,
+  createDaemonSetItems,
+  createDeploymentConfigItems,
+  createDeploymentItems,
+  createPodItems,
+  createStatefulSetItems,
+  formatNamespacedRouteForResource,
 } from '@console/shared';
-import { formatNamespacedRouteForResource } from '@console/shared/src/utils';
+import { OverviewCRD } from '@console/plugin-sdk';
+import { ClusterServiceVersionKind } from '@console/operator-lifecycle-manager';
 import { coFetchJSON } from '../../co-fetch';
 import { PROMETHEUS_TENANCY_BASE_PATH } from '../graphs';
 import { TextFilter } from '../factory';
@@ -23,7 +29,6 @@ import { ProjectOverview } from './project-overview';
 import { ResourceOverviewPage } from './resource-overview-page';
 import { OverviewSpecialGroup } from './constants';
 import * as plugins from '../../plugins';
-import { OverviewCRD } from '@console/plugin-sdk';
 
 const asOverviewGroups = (keyedItems: { [name: string]: OverviewItem[] }): OverviewGroup[] => {
   const compareGroups = (a: OverviewGroup, b: OverviewGroup) => {
@@ -127,11 +132,7 @@ class OverviewHeading_ extends React.Component<OverviewHeadingProps> {
           />
         </div>
         <div className="co-m-pane__filter-bar-group co-m-pane__filter-bar-group--filter">
-          <TextFilter
-            defaultValue={filterValue}
-            label="by name"
-            onChange={(e) => changeFilter(e.target.value)}
-          />
+          <TextFilter defaultValue={filterValue} label="by name" onChange={changeFilter} />
         </div>
       </div>
     );
@@ -165,7 +166,6 @@ class OverviewMainContent_ extends React.Component<
   OverviewMainContentState
 > {
   private metricsInterval: any = null;
-  private transformResourceData;
 
   readonly state: OverviewMainContentState = {
     items: [],
@@ -315,7 +315,6 @@ class OverviewMainContent_ extends React.Component<
       updateSelectedGroup,
       updateResources,
     } = this.props;
-    this.transformResourceData = new TransformResourceData(this.props, this.props.utils);
     if (!loaded) {
       return;
     }
@@ -325,11 +324,31 @@ class OverviewMainContent_ extends React.Component<
     }
 
     const items = [
-      ...this.transformResourceData.createDaemonSetItems(this.props.daemonSets.data),
-      ...this.transformResourceData.createDeploymentItems(this.props.deployments.data),
-      ...this.transformResourceData.createDeploymentConfigItems(this.props.deploymentConfigs.data),
-      ...this.transformResourceData.createStatefulSetItems(this.props.statefulSets.data),
-      ...this.transformResourceData.createPodItems(),
+      ...createDaemonSetItems(
+        this.props.daemonSets.data,
+        this.props,
+        this.props?.clusterServiceVersions?.data,
+        this.props.utils,
+      ),
+      ...createDeploymentItems(
+        this.props.deployments.data,
+        this.props,
+        this.props?.clusterServiceVersions?.data,
+        this.props.utils,
+      ),
+      ...createDeploymentConfigItems(
+        this.props.deploymentConfigs.data,
+        this.props,
+        this.props?.clusterServiceVersions?.data,
+        this.props.utils,
+      ),
+      ...createStatefulSetItems(
+        this.props.statefulSets.data,
+        this.props,
+        this.props?.clusterServiceVersions?.data,
+        this.props.utils,
+      ),
+      ...createPodItems(this.props),
     ];
 
     updateResources(items);
@@ -354,8 +373,8 @@ class OverviewMainContent_ extends React.Component<
   }
 
   render() {
-    const { loaded, loadError, project, namespace } = this.props;
-    const { filteredItems, groupedItems } = this.state;
+    const { loaded, loadError, project, namespace, EmptyMsg, emptyBodyClass } = this.props;
+    const { items, filteredItems, groupedItems } = this.state;
     const OverviewEmptyState = () => (
       <MsgBox
         title="No Workloads Found."
@@ -377,17 +396,22 @@ class OverviewMainContent_ extends React.Component<
       </div>
     );
 
+    const hasItems = items?.length > 0;
     return (
       <div className="co-m-pane">
-        <OverviewHeading project={_.get(project, 'data')} />
-        <div className="co-m-pane__body co-m-pane__body--no-top-margin">
+        {hasItems && <OverviewHeading project={_.get(project, 'data')} />}
+        <div
+          className={
+            (!hasItems && emptyBodyClass) || 'co-m-pane__body co-m-pane__body--no-top-margin'
+          }
+        >
           <StatusBox
             skeleton={skeletonOverview}
             data={filteredItems}
             label="Resources"
             loaded={loaded}
             loadError={loadError}
-            EmptyMsg={OverviewEmptyState}
+            EmptyMsg={EmptyMsg || OverviewEmptyState}
           >
             <ProjectOverview groups={groupedItems} />
           </StatusBox>
@@ -429,6 +453,8 @@ const Overview_: React.SFC<OverviewProps> = ({
   resourceList,
   title,
   dismissDetails,
+  EmptyMsg,
+  emptyBodyClass,
 }) => {
   const namespace = _.get(match, 'params.name');
   const sidebarOpen = !_.isEmpty(selectedItem);
@@ -468,6 +494,8 @@ const Overview_: React.SFC<OverviewProps> = ({
               selectedItem={selectedItem}
               title={title}
               utils={utils}
+              EmptyMsg={EmptyMsg}
+              emptyBodyClass={emptyBodyClass}
             />
           </Firehose>
         </div>
@@ -565,7 +593,10 @@ type OverviewMainContentOwnProps = {
   selectedItem: OverviewItem;
   statefulSets?: FirehoseResult;
   title?: string;
+  clusterServiceVersions?: FirehoseResult<ClusterServiceVersionKind[]>;
   utils?: Function[];
+  EmptyMsg?: React.ComponentType;
+  emptyBodyClass?: string;
 };
 
 export type OverviewMainContentProps = OverviewMainContentPropsFromState &
@@ -591,6 +622,8 @@ type OverviewOwnProps = {
   mock: boolean;
   match: any;
   title: string;
+  EmptyMsg?: React.ComponentType;
+  emptyBodyClass?: string;
 };
 
 type OverviewProps = OverviewPropsFromState & OverviewPropsFromDispatch & OverviewOwnProps;
