@@ -20,11 +20,12 @@ import {
   LabelList,
   ResourceKebab,
   OwnerReferences,
+  Timestamp,
+  PodsComponent,
 } from './utils';
 import { ResourceEventStream } from './events';
 import { VolumesTable } from './volumes-table';
 import { ReplicaSetModel } from '../models';
-import { fromNow } from './utils/datetime';
 
 const { ModifyCount, AddStorage, common } = Kebab.factory;
 
@@ -89,6 +90,8 @@ const environmentComponent = (props) => (
   />
 );
 
+const ReplicaSetPods = (props) => <PodsComponent {...props} customData={{ showNodes: true }} />;
+
 const { details, editYaml, pods, envEditor, events } = navFactory;
 const ReplicaSetsDetailsPage = (props) => (
   <DetailsPage
@@ -97,7 +100,7 @@ const ReplicaSetsDetailsPage = (props) => (
     pages={[
       details(Details),
       editYaml(),
-      pods(),
+      pods(ReplicaSetPods),
       envEditor(environmentComponent),
       events(ResourceEventStream),
     ]}
@@ -149,7 +152,7 @@ const ReplicaSetTableRow = ({ obj, index, key, style }) => {
         <OwnerReferences resource={obj} />
       </TableData>
       <TableData className={tableColumnClasses[5]}>
-        {fromNow(obj.metadata.creationTimestamp)}
+        <Timestamp timestamp={obj.metadata.creationTimestamp} />
       </TableData>
       <TableData className={tableColumnClasses[6]}>
         <ResourceKebab actions={replicaSetMenuActions} kind={kind} resource={obj} />
@@ -157,7 +160,6 @@ const ReplicaSetTableRow = ({ obj, index, key, style }) => {
     </TableRow>
   );
 };
-ReplicaSetTableRow.displayName = 'ReplicaSetTableRow';
 
 const ReplicaSetTableHeader = () => {
   return [
