@@ -4,10 +4,10 @@ import * as classNames from 'classnames';
 import { History, Location } from 'history';
 import { Route, Switch, Link, withRouter, match, matchPath } from 'react-router-dom';
 
-import { EmptyBox, StatusBox } from '.';
+import { EmptyBox, StatusBox } from './status-box';
 import { PodsPage } from '../pod';
 import { AsyncComponent } from './async';
-import { K8sResourceKind } from '../../module/k8s';
+import { K8sResourceKind, K8sResourceCommon } from '../../module/k8s';
 import { referenceForModel, referenceFor } from '../../module/k8s/k8s';
 import { useExtensions, HorizontalNavTab, isHorizontalNavTab } from '@console/plugin-sdk';
 
@@ -22,12 +22,13 @@ export const viewYamlComponent = (props) => (
   />
 );
 
-class PodsComponent extends React.PureComponent<PodsComponentProps> {
+export class PodsComponent extends React.PureComponent<PodsComponentProps> {
   render() {
     const {
       metadata: { namespace },
       spec: { selector },
     } = this.props.obj;
+    const { customData } = this.props;
     if (_.isEmpty(selector)) {
       return <EmptyBox label="Pods" />;
     }
@@ -36,7 +37,13 @@ class PodsComponent extends React.PureComponent<PodsComponentProps> {
     // Otherwise it might seem like you click "Create Pod" to add replicas instead
     // of scaling the owner.
     return (
-      <PodsPage showTitle={false} namespace={namespace} selector={selector} canCreate={false} />
+      <PodsPage
+        showTitle={false}
+        namespace={namespace}
+        selector={selector}
+        canCreate={false}
+        customData={customData}
+      />
     );
   }
 }
@@ -147,7 +154,9 @@ export const NavBar = withRouter<NavBarProps>(({ pages, basePath }) => {
         });
         return (
           <li className={klass} key={name}>
-            <Link to={`${basePath}/${href}`}>{name}</Link>
+            <Link to={`${basePath}/${href}`} data-test-id={`horizontal-link-${name}`}>
+              {name}
+            </Link>
           </li>
         );
       })}
@@ -195,7 +204,7 @@ export const HorizontalNav = React.memo((props: HorizontalNavProps) => {
   };
 
   const componentProps = {
-    ..._.pick(props, ['filters', 'selected', 'match']),
+    ..._.pick(props, ['filters', 'selected', 'match', 'loaded']),
     obj: _.get(props.obj, 'data'),
   };
   const extraResources = _.reduce(
@@ -204,19 +213,24 @@ export const HorizontalNav = React.memo((props: HorizontalNavProps) => {
     {},
   );
 
-  const navTabExtensions = useExtensions<HorizontalNavTab>(isHorizontalNavTab).filter(
-    (tab) =>
-      props.obj?.data && referenceForModel(tab.properties.model) === referenceFor(props.obj.data),
-  );
-  const pages = (props.pages || props.pagesFor(props.obj?.data)).concat(
-    navTabExtensions.map((tab) => ({
-      ...tab.properties.page,
-      component: (params: PageComponentProps) => (
-        <AsyncComponent {...params} loader={tab.properties.loader} />
-      ),
-    })),
+  const objReference = props.obj?.data ? referenceFor(props.obj.data) : '';
+  const navTabExtensions = useExtensions<HorizontalNavTab>(isHorizontalNavTab);
+
+  const pluginPages = React.useMemo(
+    () =>
+      navTabExtensions
+        .filter((tab) => referenceForModel(tab.properties.model) === objReference)
+        .map((tab) => ({
+          ...tab.properties.page,
+          component: (params: PageComponentProps) => (
+            <AsyncComponent {...params} loader={tab.properties.loader} />
+          ),
+        })),
+    [navTabExtensions, objReference],
   );
 
+  const pages = (props.pages || props.pagesFor(props.obj?.data)).concat(pluginPages);
+
   const routes = pages.map((p) => {
     const path = `${props.match.url}/${p.path || p.href}`;
     const render = (params) => {
@@ -244,6 +258,7 @@ export const HorizontalNav = React.memo((props: HorizontalNavProps) => {
 
 export type PodsComponentProps = {
   obj: K8sResourceKind;
+  customData?: any;
 };
 
 export type NavBarProps = {
@@ -268,11 +283,11 @@ export type HorizontalNavProps = {
   customData?: any;
 };
 
-export type PageComponentProps = {
+export type PageComponentProps<R extends K8sResourceCommon = K8sResourceKind> = {
   filters?: any;
   selected?: any;
   match?: any;
-  obj?: K8sResourceKind;
+  obj?: R;
   params?: any;
   customData?: any;
   showTitle?: boolean;
