@@ -4,7 +4,7 @@ import * as classNames from 'classnames';
 import * as _ from 'lodash-es';
 import { K8sResourceKindReference, kindForReference } from '../../module/k8s';
 
-const Label: React.SFC<LabelProps> = ({ kind, name, value, expand }) => {
+export const Label: React.SFC<LabelProps> = ({ kind, name, value, expand }) => {
   const href = `/search?kind=${kind}&q=${value ? encodeURIComponent(`${name}=${value}`) : name}`;
   const klass = classNames('co-m-label', { 'co-m-label--expand': expand });
 
