@@ -21,6 +21,7 @@ import {
 } from '@patternfly/react-core';
 
 import { history } from './router';
+import { isModalOpen } from '../modals';
 import { Dropdown } from '../utils';
 
 export const FilterTypes = {
@@ -219,6 +220,9 @@ const filterByGroup = (items, filters) => {
         );
 
         filtered[key] = _.filter(items, (item) => {
+          if (Array.isArray(item[key])) {
+            return item[key].some((f) => values.includes(f));
+          }
           return values.includes(item[key]);
         });
       }
@@ -316,6 +320,7 @@ const getActiveFilters = (
   keywordFilter,
   groupFilters,
   activeFilters,
+  categoryFilter = null,
   storeFilterKey = null,
   filterRetentionPreference = null,
 ) => {
@@ -342,6 +347,14 @@ const getActiveFilters = (
       console.error('Failed parsing user filter settings.');
     }
   }
+
+  if (categoryFilter) {
+    // removing default and localstore filters if category filters are present over URL
+    _.each(_.keys(activeFilters.kind), (key) =>
+      _.set(activeFilters, ['kind', key, 'active'], false),
+    );
+  }
+
   _.forOwn(groupFilters, (filterValues, filterType) => {
     // removing default and localstore filters if Filters are present over URL
     _.each(_.keys(activeFilters[filterType]), (key) =>
@@ -413,6 +426,10 @@ const getFilterGroupCounts = (
       ];
 
       const matchedItems = _.filter(activeItems, (item) => {
+        if (Array.isArray(item[filterGroup])) {
+          return item[filterGroup].some((f) => filterValues.includes(f));
+        }
+
         return filterValues.includes(item[filterGroup]);
       });
 
@@ -487,6 +504,7 @@ const getActiveValuesFromURL = (
     keywordFilter,
     groupFilters,
     availableFilters,
+    categoryParam,
     storeFilterKey,
     filterRetentionPreference,
   );
@@ -649,6 +667,18 @@ export class TileViewPage extends React.Component {
     }
   }
 
+  storeFilters(filters) {
+    if (this.props.storeFilterKey && this.props.filterRetentionPreference) {
+      const storeFilters = {};
+      _.each(this.props.filterRetentionPreference, (filterGroup) => {
+        if (filters[filterGroup]) {
+          storeFilters[filterGroup] = filters[filterGroup];
+        }
+      });
+      localStorage.setItem(this.props.storeFilterKey, JSON.stringify(storeFilters));
+    }
+  }
+
   clearFilters() {
     const { filterGroups } = this.props;
     const { activeFilters, categories, selectedCategoryId } = this.state;
@@ -659,10 +689,12 @@ export class TileViewPage extends React.Component {
 
     this.updateMountedState(this.getUpdatedState(categories, selectedCategoryId, clearedFilters));
 
-    this.filterByKeywordInput.focus({ preventScroll: true });
-    if (this.props.storeFilterKey) {
-      localStorage.removeItem(this.props.storeFilterKey);
+    // Don't take focus if a modal was opened while the page was loading.
+    if (!isModalOpen()) {
+      this.filterByKeywordInput.focus({ preventScroll: true });
     }
+
+    this.storeFilters(clearedFilters);
   }
 
   selectCategory(categoryId) {
@@ -692,15 +724,7 @@ export class TileViewPage extends React.Component {
 
     this.updateMountedState(this.getUpdatedState(categories, selectedCategoryId, updatedFilters));
 
-    if (this.props.storeFilterKey && this.props.filterRetentionPreference) {
-      const storeFilters = {};
-      _.each(this.props.filterRetentionPreference, (filterGroup) => {
-        if (updatedFilters[filterGroup]) {
-          storeFilters[filterGroup] = updatedFilters[filterGroup];
-        }
-      });
-      localStorage.setItem(this.props.storeFilterKey, JSON.stringify(storeFilters));
-    }
+    this.storeFilters(updatedFilters);
   }
 
   onKeywordChange(value) {
@@ -898,6 +922,7 @@ export class TileViewPage extends React.Component {
                   bsClass="pf-c-form-control"
                   value={activeFilters.keyword.value}
                   onChange={(e) => this.onKeywordChange(e.target.value)}
+                  aria-label="Filter by keyword..."
                 />
                 {groupItems && (
                   <Dropdown
