@@ -8,6 +8,7 @@ import * as VirtualModulesPlugin from 'webpack-virtual-modules';
 
 import { resolvePluginPackages, getActivePluginsModule } from '@console/plugin-sdk/src/codegen';
 import { Configuration as WebpackDevServerConfiguration } from 'webpack-dev-server';
+import { CircularDependencyPreset } from './webpack.circular-deps';
 
 interface Configuration extends webpack.Configuration {
   devServer?: WebpackDevServerConfiguration;
@@ -15,8 +16,9 @@ interface Configuration extends webpack.Configuration {
 
 const MonacoWebpackPlugin = require('monaco-editor-webpack-plugin');
 
-const NODE_ENV = process.env.NODE_ENV;
-const HOT_RELOAD = process.env.HOT_RELOAD;
+const NODE_ENV = process.env.NODE_ENV || 'development';
+const HOT_RELOAD = process.env.HOT_RELOAD || 'true';
+const CHECK_CYCLES = process.env.CHECK_CYCLES || 'false';
 
 /* Helpers */
 const extractCSS = new MiniCssExtractPlugin({ filename: 'app-bundle.[contenthash].css' });
@@ -163,6 +165,16 @@ const config: Configuration = {
   stats: 'minimal',
 };
 
+if (CHECK_CYCLES === 'true') {
+  new CircularDependencyPreset({
+    exclude: /node_modules|public\/dist/,
+    reportFile: '.webpack-cycles',
+    thresholds: {
+      minLengthCycles: 17,
+    },
+  }).apply(config.plugins);
+}
+
 /* Production settings */
 if (NODE_ENV === 'production') {
   config.output.filename = '[name]-bundle-[hash].min.js';
