@@ -1,6 +1,7 @@
 package server
 
 import (
+	"crypto/tls"
 	"fmt"
 	"html/template"
 	"io"
@@ -17,6 +18,7 @@ import (
 	helmhandlerspkg "github.com/openshift/console/pkg/helm/handlers"
 	"github.com/openshift/console/pkg/proxy"
 	"github.com/openshift/console/pkg/serverutils"
+	"github.com/openshift/console/pkg/terminal"
 	"github.com/openshift/console/pkg/version"
 )
 
@@ -97,8 +99,10 @@ type Server struct {
 	ThanosTenancyProxyConfig *proxy.Config
 	AlertManagerProxyConfig  *proxy.Config
 	MeteringProxyConfig      *proxy.Config
+	TerminalProxyTLSConfig   *tls.Config
 	// A lister for resource listing of a particular kind
-	MonitoringDashboardConfigMapLister *ResourceLister
+	MonitoringDashboardConfigMapLister ResourceLister
+	KnativeEventSourceCRDLister        ResourceLister
 	HelmChartRepoProxyConfig           *proxy.Config
 	GOARCH                             string
 	GOOS                               string
@@ -219,6 +223,14 @@ func (s *Server) HTTPHandler() http.Handler {
 		})),
 	)
 
+	terminalProxy := terminal.NewProxy(
+		s.TerminalProxyTLSConfig,
+		s.K8sProxyConfig.TLSClientConfig,
+		s.K8sProxyConfig.Endpoint)
+
+	handle(terminal.ProxyEndpoint, authHandlerWithUser(terminalProxy.HandleProxy))
+	handleFunc(terminal.AvailableEndpoint, terminalProxy.HandleProxyEnabled)
+
 	if s.prometheusProxyEnabled() {
 		// Only proxy requests to the Prometheus API, not the UI.
 		var (
@@ -311,14 +323,33 @@ func (s *Server) HTTPHandler() http.Handler {
 	}
 
 	handle("/api/console/monitoring-dashboard-config", authHandler(s.handleMonitoringDashboardConfigmaps))
+	handle("/api/console/knative-event-sources", authHandler(s.handleKnativeEventSourceCRDs))
 	handle("/api/console/version", authHandler(s.versionHandler))
 
 	// Helm Endpoints
 	helmHandlers := helmhandlerspkg.New(s.KubeAPIServerURL, s.K8sClient.Transport)
 	handle("/api/helm/template", authHandlerWithUser(helmHandlers.HandleHelmRenderManifests))
 	handle("/api/helm/releases", authHandlerWithUser(helmHandlers.HandleHelmList))
-	handle("/api/helm/release", authHandlerWithUser(helmHandlers.HandleHelmInstall))
 	handle("/api/helm/chart", authHandlerWithUser(helmHandlers.HandleChartGet))
+	handle("/api/helm/release/history", authHandlerWithUser(helmHandlers.HandleGetReleaseHistory))
+
+	handle("/api/helm/release", authHandlerWithUser(func(user *auth.User, w http.ResponseWriter, r *http.Request) {
+		switch r.Method {
+		case http.MethodGet:
+			helmHandlers.HandleGetRelease(user, w, r)
+		case http.MethodPost:
+			helmHandlers.HandleHelmInstall(user, w, r)
+		case http.MethodDelete:
+			helmHandlers.HandleUninstallRelease(user, w, r)
+		case http.MethodPatch:
+			helmHandlers.HandleRollbackRelease(user, w, r)
+		case http.MethodPut:
+			helmHandlers.HandleUpgradeRelease(user, w, r)
+		default:
+			w.Header().Set("Allow", "GET, POST, PATCH, PUT, DELETE")
+			serverutils.SendResponse(w, http.StatusMethodNotAllowed, serverutils.ApiError{Err: "Unsupported method, supported methods are GET, POST, PATCH, PUT, DELETE"})
+		}
+	}))
 
 	helmChartRepoProxy := proxy.NewProxy(s.HelmChartRepoProxyConfig)
 
@@ -333,7 +364,11 @@ func (s *Server) HTTPHandler() http.Handler {
 }
 
 func (s *Server) handleMonitoringDashboardConfigmaps(w http.ResponseWriter, r *http.Request) {
-	s.MonitoringDashboardConfigMapLister.handleResources(w, r)
+	s.MonitoringDashboardConfigMapLister.HandleResources(w, r)
+}
+
+func (s *Server) handleKnativeEventSourceCRDs(w http.ResponseWriter, r *http.Request) {
+	s.KnativeEventSourceCRDLister.HandleResources(w, r)
 }
 
 func (s *Server) indexHandler(w http.ResponseWriter, r *http.Request) {
